@@ -43,7 +43,7 @@ struct _BstApp
 
   SfiProxy        project;
 
-  GtkWidget      *main_vbox;
+  GxkGadget      *box;
   GtkNotebook    *notebook;
 
   GtkWidget      *rack_dialog;
@@ -60,10 +60,12 @@ struct _BstAppClass
 
 /* --- actions --- */
 enum {
+  BST_ACTION_APP_NONE,
   /* dialogs */
-  BST_ACTION_SHOW_PREFERENCES   = BST_ACTION_APP_FIRST,
+  BST_ACTION_SHOW_PREFERENCES,
   BST_ACTION_SHOW_PROC_BROWSER,
   BST_ACTION_SHOW_DEVICE_MONITOR,
+  BST_ACTION_EXTRA_VIEW,
   /* help dialogs */
 #define BST_ACTION_HELP_FIRST   BST_ACTION_HELP_FAQ
   BST_ACTION_HELP_FAQ,
@@ -79,6 +81,7 @@ enum {
   BST_ACTION_NEW_PROJECT,
   BST_ACTION_OPEN_PROJECT,
   BST_ACTION_MERGE_PROJECT,
+  BST_ACTION_IMPORT_MIDI,
   BST_ACTION_SAVE_PROJECT,
   BST_ACTION_SAVE_PROJECT_AS,
   BST_ACTION_CLOSE_PROJECT,
@@ -115,8 +118,9 @@ void            bst_app_reload_supers           (BstApp         *app);
 void            bst_app_create_default          (BstApp         *app);
 GtkWidget*      bst_app_get_current_shell       (BstApp         *app);
 SfiProxy        bst_app_get_current_super       (BstApp         *app);
-GtkItemFactory* bst_app_menu_factory            (BstApp         *app);
 BstApp*         bst_app_find                    (SfiProxy        project);
+void            bst_app_trigger_action          (BstApp         *app,
+                                                 gulong          action);
 
 G_END_DECLS
 
