@@ -17,31 +17,31 @@
  */
 #include "bstcanvassource.h"
 
-#include "PKG_config.h"
-
+#include "topconfig.h"
 #include "bstparamview.h"
 #include "bstgconfig.h"
+#include <string.h>
 
 
 /* --- defines --- */
-#define	ICON_WIDTH		((gdouble) 64)
-#define	ICON_HEIGHT		((gdouble) 64)
-#define CHANNEL_WIDTH		((gdouble) 10)
-#define CHANNEL_HEIGHT		((gdouble) ICON_HEIGHT)
-#define	ICON_X			((gdouble) CHANNEL_WIDTH)
-#define	ICON_Y			((gdouble) 0)
-#define ICHANNEL_realX		((gdouble) 0)
-#define OCHANNEL_realX		((gdouble) CHANNEL_WIDTH + ICON_WIDTH)
-#define ICHANNEL_X(cs)		(cs->swap_channels ? OCHANNEL_realX : ICHANNEL_realX)
-#define OCHANNEL_X(cs)		(cs->swap_channels ? ICHANNEL_realX : OCHANNEL_realX)
+#define	ICON_WIDTH(cs)		((gdouble) 64)
+#define	ICON_HEIGHT(cs)		((gdouble) 64)
+#define CHANNEL_WIDTH(cs)	((gdouble) 10)
+#define CHANNEL_HEIGHT(cs)	((gdouble) ICON_HEIGHT (cs))
+#define	ICON_X(cs)		((gdouble) CHANNEL_WIDTH (cs))
+#define	ICON_Y(cs)		((gdouble) 0)
+#define ICHANNEL_realX(cs)	((gdouble) 0)
+#define OCHANNEL_realX(cs)	((gdouble) CHANNEL_WIDTH (cs) + ICON_WIDTH (cs))
+#define ICHANNEL_X(cs)		(cs->swap_channels ? OCHANNEL_realX (cs) : ICHANNEL_realX (cs))
+#define OCHANNEL_X(cs)		(cs->swap_channels ? ICHANNEL_realX (cs) : OCHANNEL_realX (cs))
 #define CHANNEL_EAST(cs,isinp)	(cs->swap_channels ^ !isinp)
 #define	BORDER_PAD		((gdouble) 1)
-#define ICHANNEL_Y		((gdouble) 0)
-#define OCHANNEL_Y		((gdouble) 0)
-#define	TOTAL_WIDTH		((gdouble) CHANNEL_WIDTH + ICON_WIDTH + CHANNEL_WIDTH)
-#define	TOTAL_HEIGHT		((gdouble) ICON_HEIGHT)
-#define TEXT_X			((gdouble) CHANNEL_WIDTH + ICON_WIDTH / 2) /* for anchor: center */
-#define TEXT_Y			((gdouble) ICON_HEIGHT)			   /* for anchor: north */
+#define ICHANNEL_Y(cs)		((gdouble) 0)
+#define OCHANNEL_Y(cs)		((gdouble) 0)
+#define	TOTAL_WIDTH(cs)		((gdouble) CHANNEL_WIDTH (cs) + ICON_WIDTH (cs) + CHANNEL_WIDTH (cs))
+#define	TOTAL_HEIGHT(cs)	((gdouble) ICON_HEIGHT (cs))
+#define TEXT_X(cs)		((gdouble) CHANNEL_WIDTH (cs) + ICON_WIDTH (cs) / 2)    /* for anchor: center */
+#define TEXT_Y(cs)		((gdouble) ICON_HEIGHT (cs))                            /* for anchor: north */
 #define TEXT_HEIGHT		((gdouble) FONT_HEIGHT + 2)
 #define	CHANNEL_FONT		("Sans")
 #define	TEXT_FONT		("Serif")
@@ -71,7 +71,8 @@ static gboolean bst_canvas_source_child_event	(BstCanvasSource	*csource,
 						 GnomeCanvasItem        *child);
 static void     bst_canvas_source_changed       (BstCanvasSource        *csource);
 static void	bst_canvas_icon_set		(GnomeCanvasItem	*item,
-						 BseIcon         	*icon);
+						 BseIcon         	*icon,
+                                                 const gchar            *module_type);
 static void	csource_info_update		(BstCanvasSource	*csource);
 
 
@@ -82,29 +83,26 @@ static guint                 csource_signals[SIGNAL_LAST] = { 0 };
 
 
 /* --- functions --- */
-GtkType
+GType
 bst_canvas_source_get_type (void)
 {
-  static GtkType canvas_source_type = 0;
-  
-  if (!canvas_source_type)
+  static GType type = 0;
+  if (!type)
     {
-      GtkTypeInfo canvas_source_info =
-      {
-	"BstCanvasSource",
-	sizeof (BstCanvasSource),
-	sizeof (BstCanvasSourceClass),
-	(GtkClassInitFunc) bst_canvas_source_class_init,
-	(GtkObjectInitFunc) bst_canvas_source_init,
-        /* reserved_1 */ NULL,
-	/* reserved_2 */ NULL,
-	(GtkClassInitFunc) NULL,
+      static const GTypeInfo type_info = {
+        sizeof (BstCanvasSourceClass),
+        (GBaseInitFunc) NULL,
+        (GBaseFinalizeFunc) NULL,
+        (GClassInitFunc) bst_canvas_source_class_init,
+        NULL,   /* class_finalize */
+        NULL,   /* class_data */
+        sizeof (BstCanvasSource),
+        0,      /* n_preallocs */
+        (GInstanceInitFunc) bst_canvas_source_init,
       };
-      
-      canvas_source_type = gtk_type_unique (GNOME_TYPE_CANVAS_GROUP, &canvas_source_info);
+      type = g_type_register_static (GNOME_TYPE_CANVAS_GROUP, "BstCanvasSource", &type_info, 0);
     }
-  
-  return canvas_source_type;
+  return type;
 }
 
 static void
@@ -136,7 +134,7 @@ bst_canvas_source_init (BstCanvasSource *csource)
   GtkObject *object = GTK_OBJECT (csource);
   
   csource->source = 0;
-  csource->source_view = NULL;
+  csource->params_dialog = NULL;
   csource->source_info = NULL;
   csource->icon_item = NULL;
   csource->text = NULL;
@@ -223,9 +221,9 @@ source_name_changed (BstCanvasSource *csource)
   if (csource->text)
     g_object_set (csource->text, "text", name, NULL);
 
-  if (csource->source_view)
+  if (csource->params_dialog)
     {
-      gxk_dialog_set_title (GXK_DIALOG (csource->source_view), name);
+      gxk_dialog_set_title (GXK_DIALOG (csource->params_dialog), name);
       csource_info_update (csource);
     }
 
@@ -242,7 +240,7 @@ source_icon_changed (BstCanvasSource *csource)
   /* update icon in group, revert to a stock icon if none is available
    */
   icon = bse_item_get_icon (csource->source);
-  bst_canvas_icon_set (csource->icon_item, icon);
+  bst_canvas_icon_set (csource->icon_item, icon, bse_item_get_type (csource->source));
 }
 
 static void
@@ -325,36 +323,53 @@ bst_canvas_source_update_links (BstCanvasSource *csource)
     gtk_signal_emit (GTK_OBJECT (csource), csource_signals[SIGNAL_UPDATE_LINKS]);
 }
 
-void
-bst_canvas_source_popup_view (BstCanvasSource *csource)
+static inline void
+canvas_source_create_params (BstCanvasSource *csource)
 {
-  g_return_if_fail (BST_IS_CANVAS_SOURCE (csource));
-
-  if (!csource->source_view)
+  if (!csource->params_dialog)
     {
       GtkWidget *param_view;
 
       param_view = bst_param_view_new (csource->source);
-      gtk_widget_show (param_view);
-      csource->source_view = gxk_dialog_new (&csource->source_view,
-					     GTK_OBJECT (csource),
-					     GXK_DIALOG_POPUP_POS,
-					     bse_item_get_name_or_type (csource->source),
-					     param_view);
+      csource->params_dialog = gxk_dialog_new (&csource->params_dialog,
+                                               GTK_OBJECT (csource),
+                                               GXK_DIALOG_POPUP_POS,
+                                               bse_item_get_name_or_type (csource->source),
+                                               param_view);
       source_name_changed (csource);
     }
-  gxk_widget_showraise (csource->source_view);
 }
 
 void
-bst_canvas_source_toggle_view (BstCanvasSource *csource)
+bst_canvas_source_reset_params (BstCanvasSource *csource)
+{
+  GtkWidget *param_view;
+
+  g_return_if_fail (BST_IS_CANVAS_SOURCE (csource));
+
+  canvas_source_create_params (csource);
+  param_view = gxk_dialog_get_child (GXK_DIALOG (csource->params_dialog));
+  bst_param_view_apply_defaults (BST_PARAM_VIEW (param_view));
+}
+
+void
+bst_canvas_source_popup_params (BstCanvasSource *csource)
 {
   g_return_if_fail (BST_IS_CANVAS_SOURCE (csource));
 
-  if (!csource->source_view || !GTK_WIDGET_VISIBLE (csource->source_view))
-    bst_canvas_source_popup_view (csource);
+  canvas_source_create_params (csource);
+  gxk_widget_showraise (csource->params_dialog);
+}
+
+void
+bst_canvas_source_toggle_params (BstCanvasSource *csource)
+{
+  g_return_if_fail (BST_IS_CANVAS_SOURCE (csource));
+
+  if (!csource->params_dialog || !GTK_WIDGET_VISIBLE (csource->params_dialog))
+    bst_canvas_source_popup_params (csource);
   else
-    gtk_widget_hide (csource->source_view);
+    gtk_widget_hide (csource->params_dialog);
 }
 
 void
@@ -377,13 +392,11 @@ bst_canvas_source_set_channel_hints (BstCanvasSource *csource,
 static void
 csource_info_update (BstCanvasSource *csource)
 {
-  GtkWidget *frame = (csource->source_info // && (force_update || GTK_WIDGET_VISIBLE (csource->source_info))
-		      ? gxk_dialog_get_child (GXK_DIALOG (csource->source_info))
-		      : NULL);
-
-  if (frame)
+  GtkWidget *text = (csource->source_info // && (force_update || GTK_WIDGET_VISIBLE (csource->source_info))
+                     ? gxk_dialog_get_child (GXK_DIALOG (csource->source_info))
+                     : NULL);
+  if (text)
     {
-      GtkWidget *text = GTK_BIN (frame)->child;
       const gchar *string;
       guint i;
 
@@ -441,13 +454,23 @@ csource_info_update (BstCanvasSource *csource)
 
       /* description */
       string = bse_item_get_type_blurb (csource->source);
-      if (string)
+      if (string && string[0])
 	{
 	  gxk_scroll_text_aprintf (text, "\nDescription:\n");
 	  gxk_scroll_text_push_indent (text);
 	  gxk_scroll_text_aprintf (text, "%s\n", string);
 	  gxk_scroll_text_pop_indent (text);
 	}
+
+      /* authors */
+      string = bse_item_get_type_authors (csource->source);
+      if (string && string[0])
+        gxk_scroll_text_aprintf (text, "\nAuthors: %s\n", string);
+      
+      /* license */
+      string = bse_item_get_type_license (csource->source);
+      if (string && string[0])
+        gxk_scroll_text_aprintf (text, "\nLicense: %s\n", string);
     }
 }
 
@@ -458,16 +481,23 @@ bst_canvas_source_popup_info (BstCanvasSource *csource)
 
   if (!csource->source_info)
     {
+      GtkWidget *sctext = gxk_scroll_text_create (GXK_SCROLL_TEXT_WIDGET_LOOK, NULL);
+      GtkWidget *frame = gtk_widget_new (GTK_TYPE_FRAME,
+                                         "visible", TRUE,
+                                         "label", _("Module Info"),
+                                         "border_width", 5,
+                                         NULL);
+      g_object_new (GTK_TYPE_ALIGNMENT,
+                    "visible", TRUE,
+                    "parent", frame,
+                    "border_width", 2,
+                    "child", sctext,
+                    NULL),
       csource->source_info = gxk_dialog_new (&csource->source_info,
 					     GTK_OBJECT (csource),
 					     GXK_DIALOG_POPUP_POS,
 					     bse_item_get_name_or_type (csource->source),
-					     gtk_widget_new (GTK_TYPE_FRAME,
-							     "visible", TRUE,
-							     "border_width", 5,
-							     "label", "Module Info",
-							     "child", gxk_scroll_text_create (GXK_SCROLL_TEXT_WIDGET_LOOK, NULL),
-							     NULL));
+                                             sctext);
     }
   csource_info_update (csource);
   source_name_changed (csource);
@@ -530,11 +560,11 @@ bst_canvas_source_ichannel_pos (BstCanvasSource *csource,
   
   g_return_if_fail (BST_IS_CANVAS_SOURCE (csource));
   
-  x = ICHANNEL_X (csource) + CHANNEL_WIDTH / 2;
+  x = ICHANNEL_X (csource) + CHANNEL_WIDTH (csource) / 2;
   if (csource->source)
-    y = CHANNEL_HEIGHT / bse_source_n_ichannels (csource->source);
+    y = CHANNEL_HEIGHT (csource) / bse_source_n_ichannels (csource->source);
   y *= ochannel + 0.5;
-  y += ICHANNEL_Y;
+  y += ICHANNEL_Y (csource);
   gnome_canvas_item_i2w (GNOME_CANVAS_ITEM (csource), &x, &y);
   if (x_p)
     *x_p = x;
@@ -552,11 +582,11 @@ bst_canvas_source_ochannel_pos (BstCanvasSource *csource,
   
   g_return_if_fail (BST_IS_CANVAS_SOURCE (csource));
   
-  x = OCHANNEL_X (csource) + CHANNEL_WIDTH / 2;
+  x = OCHANNEL_X (csource) + CHANNEL_WIDTH (csource) / 2;
   if (csource->source)
-    y = CHANNEL_HEIGHT / bse_source_n_ochannels (csource->source);
+    y = CHANNEL_HEIGHT (csource) / bse_source_n_ochannels (csource->source);
   y *= ichannel + 0.5;
-  y += OCHANNEL_Y;
+  y += OCHANNEL_Y (csource);
   gnome_canvas_item_i2w (GNOME_CANVAS_ITEM (csource), &x, &y);
   if (x_p)
     *x_p = x;
@@ -576,12 +606,12 @@ bst_canvas_source_ichannel_at (BstCanvasSource *csource,
   gnome_canvas_item_w2i (GNOME_CANVAS_ITEM (csource), &x, &y);
 
   x -= ICHANNEL_X (csource);
-  y -= ICHANNEL_Y;
-  if (x > 0 && x < CHANNEL_WIDTH &&
-      y > 0 && y < CHANNEL_HEIGHT &&
+  y -= ICHANNEL_Y (csource);
+  if (x > 0 && x < CHANNEL_WIDTH (csource) &&
+      y > 0 && y < CHANNEL_HEIGHT (csource) &&
       bse_source_n_ichannels (csource->source))
     {
-      y /= CHANNEL_HEIGHT / bse_source_n_ichannels (csource->source);
+      y /= CHANNEL_HEIGHT (csource) / bse_source_n_ichannels (csource->source);
       channel = y;
     }
 
@@ -600,12 +630,12 @@ bst_canvas_source_ochannel_at (BstCanvasSource *csource,
   gnome_canvas_item_w2i (GNOME_CANVAS_ITEM (csource), &x, &y);
 
   x -= OCHANNEL_X (csource);
-  y -= OCHANNEL_Y;
-  if (x > 0 && x < CHANNEL_WIDTH &&
-      y > 0 && y < CHANNEL_HEIGHT &&
+  y -= OCHANNEL_Y (csource);
+  if (x > 0 && x < CHANNEL_WIDTH (csource) &&
+      y > 0 && y < CHANNEL_HEIGHT (csource) &&
       bse_source_n_ochannels (csource->source))
     {
-      y /= CHANNEL_HEIGHT / bse_source_n_ochannels (csource->source);
+      y /= CHANNEL_HEIGHT (csource) / bse_source_n_ochannels (csource->source);
       channel = y;
     }
 
@@ -614,7 +644,8 @@ bst_canvas_source_ochannel_at (BstCanvasSource *csource,
 
 static void
 bst_canvas_icon_set (GnomeCanvasItem *item,
-		     BseIcon         *icon)
+		     BseIcon         *icon,
+                     const gchar     *module_type)
 {
   GdkPixbuf *pixbuf;
   gboolean need_unref = FALSE;
@@ -632,6 +663,8 @@ bst_canvas_icon_set (GnomeCanvasItem *item,
 			      (GtkDestroyNotify) bse_icon_free);
       need_unref = TRUE;
     }
+  else if (module_type && strncmp (module_type, "BseLadspaModule_", 16) == 0)
+    pixbuf = bst_pixbuf_ladspa ();
   else
     pixbuf = bst_pixbuf_no_icon ();
 
@@ -679,18 +712,20 @@ bst_canvas_source_build_channels (BstCanvasSource *csource,
     {
       n_channels = bse_source_n_ichannels (csource->source);
       x1 = ICHANNEL_X (csource);
-      y1 = ICHANNEL_Y;
+      y1 = ICHANNEL_Y (csource);
     }
   else
     {
       n_channels = bse_source_n_ochannels (csource->source);
       x1 = OCHANNEL_X (csource);
-      y1 = OCHANNEL_Y;
+      y1 = OCHANNEL_Y (csource);
     }
-  x2 = x1 + CHANNEL_WIDTH;
-  y2 = y1 + CHANNEL_HEIGHT;
+  x2 = x1 + CHANNEL_WIDTH (csource);
+  y2 = y1 + CHANNEL_HEIGHT (csource);
   d_y = y2 - y1;
-  d_y /= n_channels;
+  if (n_channels)
+    d_y /= n_channels;
+
   if (n_channels > 1)
     {
       gint cd_red, cd_blue, cd_green;
@@ -751,7 +786,7 @@ bst_canvas_source_build_channels (BstCanvasSource *csource,
 				    "fill_color_rgba", (0x000000 << 8) | 0x80,
 				    "anchor", east_channel ? GTK_ANCHOR_WEST : GTK_ANCHOR_EAST,
 				    "justification", GTK_JUSTIFY_RIGHT,
-				    "x", east_channel ? TOTAL_WIDTH + BORDER_PAD * 2. : -BORDER_PAD,
+				    "x", east_channel ? TOTAL_WIDTH (csource) + BORDER_PAD * 2. : -BORDER_PAD,
 				    "y", (y1 + y2) / 2.,
 				    "font", CHANNEL_FONT,
 				    "text", csource->show_hints ? name : "",
@@ -782,10 +817,10 @@ bst_canvas_source_build (BstCanvasSource *csource)
    */
   csource->icon_item = g_object_connect (gnome_canvas_item_new (group,
 								GNOME_TYPE_CANVAS_PIXBUF,
-								"x", ICON_X,
-								"y", ICON_Y,
-								"width", ICON_WIDTH,
-								"height", ICON_HEIGHT,
+								"x", ICON_X (csource),
+								"y", ICON_Y (csource),
+								"width", ICON_WIDTH (csource),
+								"height", ICON_HEIGHT (csource),
 								NULL),
 					 "signal::destroy", gtk_widget_destroyed, &csource->icon_item,
 					 "swapped_signal::event", bst_canvas_source_child_event, csource,
@@ -799,8 +834,8 @@ bst_canvas_source_build (BstCanvasSource *csource)
 					 "fill_color", "black",
 					 "anchor", GTK_ANCHOR_NORTH,
 					 "justification", GTK_JUSTIFY_CENTER,
-					 "x", TEXT_X,
-					 "y", TEXT_Y,
+					 "x", TEXT_X (csource),
+					 "y", TEXT_Y (csource),
 					 "font", TEXT_FONT,
 					 NULL);
   g_object_connect (csource->text,
@@ -829,7 +864,7 @@ bst_canvas_source_build (BstCanvasSource *csource)
    */
   if (0)
     {
-      gpoints = gnome_canvas_points_newv (2, ICON_X, ICON_Y, ICON_X + ICON_WIDTH, ICON_Y);
+      gpoints = gnome_canvas_points_newv (2, ICON_X (csource), ICON_Y (csource), ICON_X (csource) + ICON_WIDTH (csource), ICON_Y (csource));
       item = g_object_connect (gnome_canvas_item_new (group,
 						      GNOME_TYPE_CANVAS_LINE,
 						      "fill_color_rgba", RGBA_BLACK,
@@ -837,8 +872,8 @@ bst_canvas_source_build (BstCanvasSource *csource)
 						      NULL),
 			       "swapped_signal::event", bst_canvas_source_child_event, csource,
 			       NULL);
-      gpoints->coords[1] += ICON_HEIGHT;
-      gpoints->coords[3] += ICON_HEIGHT;
+      gpoints->coords[1] += ICON_HEIGHT (csource);
+      gpoints->coords[3] += ICON_HEIGHT (csource);
       item = g_object_connect (gnome_canvas_item_new (group,
 						      GNOME_TYPE_CANVAS_LINE,
 						      "fill_color_rgba", RGBA_BLACK,
@@ -855,8 +890,8 @@ bst_canvas_source_build (BstCanvasSource *csource)
    * text bounding rectangle
    */
   gpoints = gnome_canvas_points_newv (2,
-				      CHANNEL_WIDTH, ICON_BOTTOM,
-				      CHANNEL_WIDTH + ICON_WIDTH, ICON_BOTTOM);
+				      CHANNEL_WIDTH (csource), ICON_BOTTOM,
+				      CHANNEL_WIDTH (csource) + ICON_WIDTH, ICON_BOTTOM);
   item = g_object_connect (gnome_canvas_item_new (group,
 						  GNOME_TYPE_CANVAS_LINE,
 						  "fill_color_rgba", RGBA_BLACK,
@@ -875,8 +910,8 @@ bst_canvas_source_build (BstCanvasSource *csource)
 						  "outline_color_rgba", RGBA_BLACK, /* covers buggy canvas lines */
 						  "x1", 0.0,
 						  "y1", 0.0,
-						  "x2", TOTAL_WIDTH,
-						  "y2", TOTAL_HEIGHT,
+						  "x2", TOTAL_WIDTH (csource),
+						  "y2", TOTAL_HEIGHT (csource),
 						  (GNOME_CANVAS_ITEM (csource)->canvas->aa
 						   ? "fill_color_rgba"
 						   : NULL), 0x00000000,
@@ -948,7 +983,7 @@ bst_canvas_source_event (GnomeCanvasItem *item,
 	    {
 	      name = bse_source_ichannel_name (csource->source, channel);
 	      cname = bse_source_ichannel_ident (csource->source, channel);
-	      prefix = "Input";
+	      prefix = _("Input");
 	    }
 	  else
 	    {
@@ -957,11 +992,11 @@ bst_canvas_source_event (GnomeCanvasItem *item,
 		{
 		  name = bse_source_ochannel_name (csource->source, channel);
 		  cname = bse_source_ochannel_ident (csource->source, channel);
-		  prefix = "Output";
+		  prefix = _("Output");
 		}
 	    }
 	  if (name)
-	    gxk_status_printf (GXK_STATUS_IDLE_HINT, "(Hint)", "%s[%s]: %s", prefix, cname, name);
+	    gxk_status_printf (GXK_STATUS_IDLE_HINT, _("(Hint)"), "%s[%s]: %s", prefix, cname, name);
 	  else
 	    gxk_status_set (GXK_STATUS_IDLE_HINT, NULL, NULL);
 	}
