@@ -20,27 +20,12 @@
 
 #include <gxk/gxk.h>
 #include <libintl.h>
-#include "glewidgets.h"
 #include "bstzoomedwindow.h"
-#include "bstfreeradiobutton.h"
 
 G_BEGIN_DECLS
 
 
-/* --- BEAST mainmenu operations --- */
-typedef enum
-{
-  BST_ACTION_NONE,
-  /* app actions */
-  BST_ACTION_APP_FIRST          = 0x0001 << 16,
-  /* wave view actions */
-  BST_ACTION_WAVE_FIRST         = 0x0002 << 16,
-  /* (song) part view actions */
-  BST_ACTION_PART_FIRST         = 0x0003 << 16,
-  /* (song) track view actions */
-  BST_ACTION_TRACK_FIRST        = 0x0004 << 16,
-} BstActionRegions;
-
+/* --- generic constants --- */
 typedef enum {
   BST_QUANTIZE_NONE		= 0,
   BST_QUANTIZE_NOTE_1		= 1,
@@ -54,11 +39,12 @@ typedef enum {
   BST_QUANTIZE_TACT		= 65535
 } BstQuantizationType;
 
+/* choose IDs that are unlikely to clash with category IDs */
+#define BST_GENERIC_ROLL_TOOL_FIRST	(G_MAXINT - 100000)
 typedef enum /*< skip >*/
 {
   BST_GENERIC_ROLL_TOOL_NONE,
-  /* choose IDs that are unlikely to clash with category IDs */
-  BST_GENERIC_ROLL_TOOL_INSERT            = G_MAXINT - 1000,
+  BST_GENERIC_ROLL_TOOL_INSERT            = BST_GENERIC_ROLL_TOOL_FIRST,
   BST_GENERIC_ROLL_TOOL_RESIZE,
   BST_GENERIC_ROLL_TOOL_LINK,
   BST_GENERIC_ROLL_TOOL_RENAME,
@@ -98,16 +84,13 @@ typedef enum /*< skip >*/
 
 
 /* --- i18n and gettext helpers --- */
-#define CKEY(x) x
-#define _(str)		dgettext (NULL, str)
-#ifdef gettext_noop
-#  define N_(str)	gettext_noop (str)
-#else
-#  define N_(str)	(str)
-#endif
+#define _(str)	dgettext (NULL, str)
+#define T_(str)	dgettext (NULL, str)
+#define N_(str)	(str)
 
 
 /* --- internal stuff --- */
+void    beast_show_about_box (void);
 extern gboolean bst_developer_hints;
 extern gboolean bst_debug_extensions;
 extern gboolean bst_main_loop_running;
