@@ -27,7 +27,7 @@ static void	bst_log_adjustment_init			(BstLogAdjustment	*ladj);
 static void	bst_log_adjustment_destroy		(GtkObject		*object);
 static void	bst_log_adjustment_changed		(GtkAdjustment		*adj);
 static void	bst_log_adjustment_value_changed	(GtkAdjustment		*adj);
-static void	ladj_client_changed			(BstLogAdjustment	*ladj);
+static void	ladj_adjust_ranges			(BstLogAdjustment	*ladj);
 static void	ladj_client_value_changed		(BstLogAdjustment	*ladj);
 
 
@@ -95,7 +95,6 @@ static void
 bst_log_adjustment_init (BstLogAdjustment *ladj)
 {
   ladj->block_client = 0;
-  ladj->client_owned = FALSE;
   ladj->client = NULL;
   bst_log_adjustment_setup (ladj, 10000, 10, 4);
 }
@@ -119,30 +118,11 @@ bst_log_adjustment_from_adj (GtkAdjustment *client)
   g_return_val_if_fail (GTK_IS_ADJUSTMENT (client), NULL);
 
   ladj = g_object_new (BST_TYPE_LOG_ADJUSTMENT, NULL);
-  g_object_ref (ladj);
-  gtk_object_sink (GTK_OBJECT (ladj));
   bst_log_adjustment_set_client (ladj, client);
-  ladj->client_owned = TRUE;
   
   return GTK_ADJUSTMENT (ladj);
 }
 
-static void
-ladj_weak_notify (gpointer data,
-	       GObject *where_the_object_was)
-{
-  BstLogAdjustment *ladj = BST_LOG_ADJUSTMENT (data);
-
-  g_signal_handlers_disconnect_by_func (ladj->client, ladj_client_changed, ladj);
-  g_signal_handlers_disconnect_by_func (ladj->client, ladj_client_value_changed, ladj);
-  ladj->client = NULL;
-  if (ladj->client_owned)
-    {
-      ladj->client_owned = FALSE;
-      g_object_unref (ladj);
-    }
-}
-
 void
 bst_log_adjustment_set_client (BstLogAdjustment *ladj,
 			       GtkAdjustment    *client)
@@ -154,18 +134,19 @@ bst_log_adjustment_set_client (BstLogAdjustment *ladj,
   g_object_ref (ladj);
   if (ladj->client)
     {
-      g_object_weak_unref (G_OBJECT (ladj->client), ladj_weak_notify, ladj);
-      ladj_weak_notify (ladj, NULL);
+      g_signal_handlers_disconnect_by_func (ladj->client, ladj_adjust_ranges, ladj);
+      g_signal_handlers_disconnect_by_func (ladj->client, ladj_client_value_changed, ladj);
+      g_object_unref (G_OBJECT (ladj->client));
     }
   ladj->client = client;
   if (ladj->client)
     {
-      g_object_weak_ref (G_OBJECT (ladj->client), ladj_weak_notify, ladj);
+      g_object_ref (G_OBJECT (ladj->client));
       g_object_connect (ladj->client,
-			"swapped_signal::changed", ladj_client_changed, ladj,
+			"swapped_signal::changed", ladj_adjust_ranges, ladj,
 			"swapped_signal::value_changed", ladj_client_value_changed, ladj,
 			NULL);
-      ladj_client_changed (ladj);
+      ladj_adjust_ranges (ladj);
     }
   g_object_unref (ladj);
 }
@@ -174,18 +155,25 @@ void
 bst_log_adjustment_setup (BstLogAdjustment *ladj,
 			  gdouble           center,
 			  gdouble           base,
-			  guint             n_steps)
+			  gdouble           n_steps)
 {
+  GtkAdjustment *adj;
+
   g_return_if_fail (BST_IS_LOG_ADJUSTMENT (ladj));
   g_return_if_fail (n_steps > 0);
   g_return_if_fail (base > 0);
 
+  adj = GTK_ADJUSTMENT (ladj);
   ladj->center = center;
   ladj->n_steps = n_steps;
   ladj->base = base;
   ladj->base_ln = log (ladj->base);
   ladj->ulimit = pow (ladj->base, ladj->n_steps);
   ladj->llimit = 1.0 / ladj->ulimit;
+
+  adj->value = ladj->center;
+  ladj_adjust_ranges (ladj);
+  gtk_adjustment_value_changed (adj);
 }
 
 static void
@@ -193,14 +181,13 @@ bst_log_adjustment_changed (GtkAdjustment *adj)
 {
   BstLogAdjustment *ladj = BST_LOG_ADJUSTMENT (adj);
   GtkAdjustment *client = ladj->client;
-
-  if (client)
-    if (!ladj->block_client)
-      {
-        ladj->block_client++;
-	gtk_adjustment_changed (client);
-        ladj->block_client--;
-      }
+  
+  if (client && !ladj->block_client)
+    {
+      ladj->block_client++;
+      gtk_adjustment_changed (client);
+      ladj->block_client--;
+    }
 }
 
 static void
@@ -208,22 +195,21 @@ bst_log_adjustment_value_changed (GtkAdjustment *adj)
 {
   BstLogAdjustment *ladj = BST_LOG_ADJUSTMENT (adj);
   GtkAdjustment *client = ladj->client;
-
-  if (client)
-    if (!ladj->block_client)
-      {
-	client->value = call_exp (ladj, adj->value) * ladj->center;
-	ladj->block_client++;
-	gtk_adjustment_value_changed (client);
-	ladj->block_client--;
-      }
+  
+  adj->value = CLAMP (adj->value, adj->lower, adj->upper);
+  if (client && !ladj->block_client)
+    {
+      client->value = call_exp (ladj, adj->value) * ladj->center;
+      ladj->block_client++;
+      gtk_adjustment_value_changed (client);
+      ladj->block_client--;
+    }
 }
 
 static void
-ladj_client_changed (BstLogAdjustment *ladj)
+ladj_adjust_ranges (BstLogAdjustment *ladj)
 {
   GtkAdjustment *adj = GTK_ADJUSTMENT (ladj);
-  GtkAdjustment *client = ladj->client;
 
   adj->upper = ladj->n_steps;
   adj->lower = -ladj->n_steps;
@@ -232,11 +218,14 @@ ladj_client_changed (BstLogAdjustment *ladj)
   adj->page_size = 0;
 
   if (0)
-    g_print ("SETUP: [%f %f] (%f %f %f) center: %g   CLIENT: [%f %f]\n",
-	     adj->lower, adj->upper,
-	     adj->step_increment, adj->page_increment, adj->page_size,
-	     ladj->center,
-	     client->lower, client->upper);
+    {
+      GtkAdjustment *client = ladj->client;
+      g_printerr ("ladj: client-changed: [%f %f] (%f %f %f) center: %g   CLIENT: [%f %f]\n",
+                  adj->lower, adj->upper,
+                  adj->step_increment, adj->page_increment, adj->page_size,
+                  ladj->center,
+                  client ? client->lower : -99.777, client ? client->upper : -99.777);
+    }
 
   if (!ladj->block_client)
     {
@@ -252,12 +241,14 @@ ladj_client_value_changed (BstLogAdjustment *ladj)
   GtkAdjustment *adj = GTK_ADJUSTMENT (ladj);
   GtkAdjustment *client = ladj->client;
 
-  adj->value = call_log (ladj, client->value / ladj->center);
+  if (client)
+    adj->value = call_log (ladj, client->value / ladj->center);
+  adj->value = CLAMP (adj->value, adj->lower, adj->upper);
 
   if (0)
-    g_print ("LOG: [%f %f] %g   CLIENT: [%f %f] %g\n",
-	     adj->lower, adj->upper, adj->value,
-	     client->lower, client->upper, client->value);
+    g_printerr ("ladj: client-value-changed: [%f %f] %g   CLIENT: [%f %f] %g\n",
+                adj->lower, adj->upper, adj->value,
+                client->lower, client->upper, client->value);
   
   if (!ladj->block_client)
     {
