@@ -20,10 +20,8 @@
 #include "bstapp.h"
 #include "bstsplash.h"
 #include "bstxkb.h"
-#include "bstactivatable.h"
 #include "bstgconfig.h"
 #include "bstusermessage.h"
-#include "bstcatalog.h"
 #include "bstparam.h"
 #include "bstpreferences.h"
 #include "topconfig.h"
@@ -45,6 +43,7 @@ static void			bst_exit_print_version	(void);
 gboolean            bst_developer_hints = FALSE;
 gboolean            bst_debug_extensions = FALSE;
 gboolean            bst_main_loop_running = TRUE;
+static GtkWidget   *beast_splash = NULL;
 static gboolean     registration_done = FALSE;
 static gboolean     arg_force_xkb = FALSE;
 static gboolean     register_core_plugins = TRUE;
@@ -85,7 +84,6 @@ main (int   argc,
       char *argv[])
 {
   GdkPixbufAnimation *anim;
-  GtkWidget *splash;
   BstApp *app = NULL;
   SfiRec *bseconfig;
   gchar *string;
@@ -132,55 +130,54 @@ main (int   argc,
 
   /* now, we can popup the splash screen
    */
-  splash = bst_splash_new (_("BEAST Startup"), BST_SPLASH_WIDTH, BST_SPLASH_HEIGHT, 15);
-  gtk_object_set_user_data (GTK_OBJECT (splash), NULL);	/* fix for broken user_data in 2.2 */
-  bst_splash_set_text (splash,
+  beast_splash = bst_splash_new ("BEAST-Splash", BST_SPLASH_WIDTH, BST_SPLASH_HEIGHT, 15);
+  bst_splash_set_title (beast_splash, _("BEAST Startup"));
+  gtk_object_set_user_data (GTK_OBJECT (beast_splash), NULL);	/* fix for broken user_data in 2.2 */
+  bst_splash_set_text (beast_splash,
 		       "<b><big>BEAST</big></b>\n"
 		       "<b>The Bedevilled Audio System</b>\n"
 		       "<b>Version %s (%s)</b>\n",
 		       BST_VERSION, BST_VERSION_HINT);
-  bst_splash_update_entity (splash, _("Startup"));
-  bst_splash_show_now (splash);
+  bst_splash_update_entity (beast_splash, _("Startup"));
+  bst_splash_show_grab (beast_splash);
 
   /* BEAST initialization
    */
-  bst_splash_update_item (splash, _("Objects"));
+  bst_splash_update_item (beast_splash, _("Objects"));
   _bst_init_utils ();
   _bst_init_params ();
   _bst_gconfig_init ();
-  bst_splash_update_item (splash, _("Language"));
-  _bst_catalog_init ();
+  bst_splash_update_item (beast_splash, _("Language"));
 
   /* GUI patchups
    */
   gtk_rc_parse_string (bst_rc_string);
-  g_type_name (bst_free_radio_button_get_type ());	/* urg, GCC_CONST */
 
   /* parse rc file
    */
   if (TRUE)
     {
       gchar *file_name = BST_STRDUP_RC_FILE ();
-      bst_splash_update_item (splash, _("RC File"));
+      bst_splash_update_item (beast_splash, _("RC File"));
       bst_rc_parse (file_name);
       g_free (file_name);
     }
 
   /* show splash images
    */
-  bst_splash_update_item (splash, _("Splash Image"));
+  bst_splash_update_item (beast_splash, _("Splash Image"));
   string = g_strconcat (BST_PATH_IMAGES, G_DIR_SEPARATOR_S, BST_SPLASH_IMAGE, NULL);
   anim = gdk_pixbuf_animation_new_from_file (string, NULL);
   g_free (string);
   bst_splash_update ();
   if (anim)
     {
-      bst_splash_set_animation (splash, anim);
+      bst_splash_set_animation (beast_splash, anim);
       g_object_unref (anim);
     }
 
   /* start BSE core and connect */
-  bst_splash_update_item (splash, _("BSE Core"));
+  bst_splash_update_item (beast_splash, _("BSE Core"));
   bse_init_async (&argc, &argv, bseconfig);
   sfi_rec_unref (bseconfig);
   sfi_glue_context_push (bse_init_glue_context ("BEAST"));
@@ -193,13 +190,13 @@ main (int   argc,
 
   /* watch registration notifications on server */
   bse_proxy_connect (BSE_SERVER,
-		     "signal::registration", server_registration, splash,
+		     "signal::registration", server_registration, beast_splash,
 		     NULL);
 
   /* register core plugins */
   if (register_core_plugins)
     {
-      bst_splash_update_entity (splash, _("Plugins"));
+      bst_splash_update_entity (beast_splash, _("Plugins"));
 
       /* plugin registration, this is done asyncronously,
        * so we wait until all are done
@@ -218,7 +215,7 @@ main (int   argc,
   /* register LADSPA plugins */
   if (register_ladspa_plugins)
     {
-      bst_splash_update_entity (splash, _("LADSPA Plugins"));
+      bst_splash_update_entity (beast_splash, _("LADSPA Plugins"));
 
       /* plugin registration, this is done asyncronously,
        * so we wait until all are done
@@ -238,7 +235,7 @@ main (int   argc,
   string = g_getenv ("BEAST_SLEEP4GDB");
   if (string && atoi (string) > 0)
     {
-      bst_splash_update_entity (splash, "Debugging Hook");
+      bst_splash_update_entity (beast_splash, "Debugging Hook");
       g_message ("going into sleep mode due to debugging request (pid=%u)", getpid ());
       g_usleep (2147483647);
     }
@@ -246,7 +243,7 @@ main (int   argc,
   /* register BSE scripts */
   if (register_scripts)
     {
-      bst_splash_update_entity (splash, _("Scripts"));
+      bst_splash_update_entity (beast_splash, _("Scripts"));
 
       /* script registration, this is done asyncronously,
        * so we wait until all are done
@@ -264,19 +261,14 @@ main (int   argc,
 
   /* listen to BseServer notification
    */
-  bst_splash_update_entity (splash, _("Dialogs"));
+  bst_splash_update_entity (beast_splash, _("Dialogs"));
   bst_catch_scripts_and_msgs ();
-
-  /* grab events on the splash to keep the user away
-   * from application windows during loading.
-   * we hide the splash as soon as a real app window appears.
-   */
-  gtk_grab_add (splash);
+  _bst_init_gadgets ();
 
   /* open files given on command line
    */
   if (argc > 1)
-    bst_splash_update_entity (splash, _("Loading..."));
+    bst_splash_update_entity (beast_splash, _("Loading..."));
   for (i = 1; i < argc; i++)
     {
       SfiProxy project, wrepo;
@@ -297,7 +289,7 @@ main (int   argc,
 		  app = bst_app_new (project);
 		  gxk_idle_show_widget (GTK_WIDGET (app));
 		  bse_item_unuse (project);
-		  gtk_widget_hide (splash);
+		  gtk_widget_hide (beast_splash);
 		  continue;
 		}
 	      bse_item_unuse (project);
@@ -320,7 +312,7 @@ main (int   argc,
 	{
 	  app = bst_app_new (project);
 	  gxk_idle_show_widget (GTK_WIDGET (app));
-	  gtk_widget_hide (splash);
+	  gtk_widget_hide (beast_splash);
 	}
       bse_item_unuse (project);
       
@@ -338,7 +330,7 @@ main (int   argc,
       app = bst_app_new (project);
       bse_item_unuse (project);
       gxk_idle_show_widget (GTK_WIDGET (app));
-      gtk_widget_hide (splash);
+      gtk_widget_hide (beast_splash);
     }
   /* splash screen is definitely hidden here (still grabbing) */
 
@@ -346,12 +338,13 @@ main (int   argc,
    */
   if (!BST_RC_VERSION || strcmp (BST_RC_VERSION, BST_VERSION))
     {
-      bst_activatable_activate (BST_ACTIVATABLE (app), BST_ACTION_HELP_RELEASE_NOTES);
+      bst_app_trigger_action (app, BST_ACTION_HELP_RELEASE_NOTES);
       bst_gconfig_set_rc_version (BST_VERSION);
     }
 
-  /* destroy splash to release grab */
-  gtk_widget_destroy (splash);
+  /* release splash grab */
+  gtk_widget_hide (beast_splash);
+  bst_splash_release_grab (beast_splash);
   /* away into the main loop */
   while (bst_main_loop_running)
     {
@@ -480,7 +473,7 @@ bst_early_parse_args (int    *argc_p,
 	}
       else if (strcmp ("--debug-list", argv[i]) == 0)
 	{
-	  const gchar **keys = bst_log_scan_keys ();
+	  const gchar **keys = _bst_log_scan_keys ();
 	  guint i;
 	  g_print ("debug keys: all");
 	  for (i = 0; keys[i]; i++)
@@ -557,7 +550,8 @@ bst_early_parse_args (int    *argc_p,
 	  exit (0);
 	}
     }
-  
+  gxk_param_set_devel_tips (bst_developer_hints);
+
   e = 0;
   for (i = 1; i < argc; i++)
     {
@@ -576,7 +570,7 @@ bst_early_parse_args (int    *argc_p,
     *argc_p = e;
 }
 
-static void
+static void G_GNUC_NORETURN
 bst_exit_print_version (void)
 {
   const gchar *c;
@@ -623,11 +617,12 @@ static void
 bst_print_blurb (void)
 {
   g_print ("Usage: beast [options] [files...]\n");
-  g_print ("  --devel                 enrich the GUI with hints usefull for (script) developers\n");
 #ifdef BST_WITH_XKB
   g_print ("  --force-xkb             force XKB keytable queries\n");
 #endif
   g_print ("  --print-dir[=RESOURCE]  print the directory for a specific resource\n");
+  g_print ("  --devel                 enrich the GUI with hints usefull for developers,\n");
+  g_print ("                          enable unstable plugins and experimental code\n");
   g_print ("  -h, --help              show this help message\n");
   g_print ("  -v, --version           print version and file paths\n");
   g_print ("  --display=DISPLAY       X server for the GUI; see X(1)\n");
@@ -642,8 +637,8 @@ bst_print_blurb (void)
   g_print ("                          l - enable LADSPA plugin registration\n");
   g_print ("                          L - disable LADSPA plugin registration\n");
   g_print ("                          s - enable script registration\n");
-  g_print ("                          S - enable script registration\n");
-  g_print ("                          d - developer and debugging extensions (harmfull)\n");
+  g_print ("                          S - disable script registration\n");
+  g_print ("                          d - enable debugging extensions (harmfull)\n");
   if (!BST_VERSION_STABLE)
     {
       g_print ("Gtk+ Options:\n");
@@ -656,3 +651,51 @@ bst_print_blurb (void)
       g_print ("  --sync                  do all X calls synchronously\n");
     }
 }
+
+void
+beast_show_about_box (void)
+{
+  /* contributor/author names do not get i18n markup. instead, their names are to be
+   * written using utf-8 encoding, where non-ascii characters are entered using
+   * hexadecimal escape sequences. for instance: "Ville P\xc3\xa4tsi"
+   */
+  const gchar *contributors[] = {
+    /* graphics */
+    "Cyria Arweiler",
+    "Tuomas Kuosmanen",
+    "Jakub Steiner",
+    "Ville P\xc3\xa4tsi",
+    /* general code and fixes */
+    "Sam Hocevar",
+    "Alper Ersoy",
+    "Ben Collver",
+    "Tim Janik",
+    "Stefan Westerfeld",
+    /* plugins */
+    "David A. Bartold",
+    //"Tim Janik",
+    //"Stefan Westerfeld",
+    /* languages */
+    "Metin Amiroff",
+    "Alexandre Prokoudine",
+    "Danilo Segan",
+    "Christian Rose",
+    "Christian Neumair",
+    "Miloslav Trmac",
+    "Duarte Loreto",
+    "Vincent van Adrighem",
+    "Danilo Segan",
+    "Xavier Conde Rueda",
+    "Kostas Papadimas",
+    "Ismael Andres Rubio Rojas",
+    NULL
+  };
+  if (!GTK_WIDGET_VISIBLE (beast_splash))
+    {
+      bst_splash_set_title (beast_splash, _("BEAST About"));
+      bst_splash_update_entity (beast_splash, _("BEAST Version %s"), BST_VERSION);
+      bst_splash_update_item (beast_splash, _("Contributions made by:"));
+      bst_splash_animate_strings (beast_splash, contributors);
+    }
+  gxk_widget_showraise (beast_splash);
+}
