@@ -287,7 +287,48 @@ bst_marshal_VOID__UINT_UINT_FLOAT (GClosure     *closure,
             data2);
 }
 
-/* NONE:UINT,UINT,INT,BOXED (./bstmarshal.list:34) */
+/* NONE:UINT,UINT,FLOAT,BOXED (./bstmarshal.list:34) */
+void
+bst_marshal_VOID__UINT_UINT_FLOAT_BOXED (GClosure     *closure,
+                                         GValue       *return_value,
+                                         guint         n_param_values,
+                                         const GValue *param_values,
+                                         gpointer      invocation_hint,
+                                         gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__UINT_UINT_FLOAT_BOXED) (gpointer     data1,
+                                                            guint        arg_1,
+                                                            guint        arg_2,
+                                                            gfloat       arg_3,
+                                                            gpointer     arg_4,
+                                                            gpointer     data2);
+  register GMarshalFunc_VOID__UINT_UINT_FLOAT_BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 5);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__UINT_UINT_FLOAT_BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_uint (param_values + 1),
+            g_marshal_value_peek_uint (param_values + 2),
+            g_marshal_value_peek_float (param_values + 3),
+            g_marshal_value_peek_boxed (param_values + 4),
+            data2);
+}
+
+/* NONE:UINT,UINT,INT,BOXED (./bstmarshal.list:35) */
 void
 bst_marshal_VOID__UINT_UINT_INT_BOXED (GClosure     *closure,
                                        GValue       *return_value,
@@ -328,7 +369,7 @@ bst_marshal_VOID__UINT_UINT_INT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* NONE:UINT,UINT,BOXED (./bstmarshal.list:35) */
+/* NONE:UINT,UINT,BOXED (./bstmarshal.list:36) */
 void
 bst_marshal_VOID__UINT_UINT_BOXED (GClosure     *closure,
                                    GValue       *return_value,
@@ -367,7 +408,7 @@ bst_marshal_VOID__UINT_UINT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* NONE:UINT,INT,BOXED (./bstmarshal.list:36) */
+/* NONE:UINT,INT,BOXED (./bstmarshal.list:37) */
 void
 bst_marshal_VOID__UINT_INT_BOXED (GClosure     *closure,
                                   GValue       *return_value,
@@ -406,7 +447,7 @@ bst_marshal_VOID__UINT_INT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* BOOL:BOOL (./bstmarshal.list:37) */
+/* BOOL:BOOL (./bstmarshal.list:38) */
 void
 bst_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                               GValue       *return_value,
@@ -445,9 +486,9 @@ bst_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* NONE:UINT,POINTER (./bstmarshal.list:38) */
+/* NONE:UINT,POINTER (./bstmarshal.list:39) */
 
-/* NONE:OBJECT,OBJECT (./bstmarshal.list:39) */
+/* NONE:OBJECT,OBJECT (./bstmarshal.list:40) */
 void
 bst_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                  GValue       *return_value,
@@ -484,11 +525,11 @@ bst_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* NONE:STRING (./bstmarshal.list:40) */
+/* NONE:STRING (./bstmarshal.list:41) */
 
-/* NONE:BOOLEAN (./bstmarshal.list:41) */
+/* NONE:BOOLEAN (./bstmarshal.list:42) */
 
-/* BOOLEAN:UINT (./bstmarshal.list:42) */
+/* BOOLEAN:UINT (./bstmarshal.list:43) */
 void
 bst_marshal_BOOLEAN__UINT (GClosure     *closure,
                            GValue       *return_value,
@@ -527,5 +568,5 @@ bst_marshal_BOOLEAN__UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* NONE:BOXED (./bstmarshal.list:43) */
+/* NONE:BOXED (./bstmarshal.list:44) */
 
