@@ -76,37 +76,34 @@ bst_param_view_class_init (BstParamViewClass *class)
 }
 
 static void
-bst_param_view_init (BstParamView *param_view)
+bst_param_view_init (BstParamView *self)
 {
-  param_view->item = 0;
-  param_view->bparams = NULL;
+  self->item = 0;
+  self->params = NULL;
 
-  param_view->first_base_type = g_strdup ("BseObject");
-  param_view->last_base_type = NULL;
-  param_view->reject_pattern = NULL;
-  param_view->match_pattern = NULL;
+  self->first_base_type = g_strdup ("BseObject");
+  self->last_base_type = NULL;
+  self->reject_pattern = NULL;
+  self->match_pattern = NULL;
+  gtk_widget_show (GTK_WIDGET (self));
 }
 
 static void
-bst_param_view_destroy_contents (BstParamView *param_view)
+bst_param_view_destroy_contents (BstParamView *self)
 {
-  gtk_container_foreach (GTK_CONTAINER (param_view), (GtkCallback) gtk_widget_destroy, NULL);
-  while (param_view->bparams)
-    bst_param_destroy (g_slist_pop_head (&param_view->bparams));
+  gtk_container_foreach (GTK_CONTAINER (self), (GtkCallback) gtk_widget_destroy, NULL);
+  while (self->params)
+    gxk_param_destroy (g_slist_pop_head (&self->params));
 }
 
 static void
 bst_param_view_destroy (GtkObject *object)
 {
-  BstParamView *param_view;
+  BstParamView *self = BST_PARAM_VIEW (object);
 
-  g_return_if_fail (object != NULL);
+  bst_param_view_destroy_contents (self);
 
-  param_view = BST_PARAM_VIEW (object);
-
-  bst_param_view_destroy_contents (param_view);
-
-  bst_param_view_set_item (param_view, 0);
+  bst_param_view_set_item (self, 0);
 
   GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
@@ -114,22 +111,22 @@ bst_param_view_destroy (GtkObject *object)
 static void
 bst_param_view_finalize (GObject *object)
 {
-  BstParamView *param_view = BST_PARAM_VIEW (object);
+  BstParamView *self = BST_PARAM_VIEW (object);
 
-  bst_param_view_set_item (param_view, 0);
+  bst_param_view_set_item (self, 0);
 
-  g_free (param_view->first_base_type);
-  g_free (param_view->last_base_type);
+  g_free (self->first_base_type);
+  g_free (self->last_base_type);
 
-  if (param_view->reject_pattern)
+  if (self->reject_pattern)
     {
-      g_pattern_spec_free (param_view->reject_pattern);
-      param_view->reject_pattern = NULL;
+      g_pattern_spec_free (self->reject_pattern);
+      self->reject_pattern = NULL;
     }
-  if (param_view->match_pattern)
+  if (self->match_pattern)
     {
-      g_pattern_spec_free (param_view->match_pattern);
-      param_view->match_pattern = NULL;
+      g_pattern_spec_free (self->match_pattern);
+      self->match_pattern = NULL;
     }
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -138,22 +135,21 @@ bst_param_view_finalize (GObject *object)
 GtkWidget*
 bst_param_view_new (SfiProxy item)
 {
-  GtkWidget *param_view;
+  GtkWidget *self = gtk_widget_new (BST_TYPE_PARAM_VIEW, NULL);
 
   if (item)
     g_return_val_if_fail (BSE_IS_ITEM (item), NULL);
 
-  param_view = gtk_widget_new (BST_TYPE_PARAM_VIEW, NULL);
   if (item)
-    bst_param_view_set_item (BST_PARAM_VIEW (param_view), item);
+    bst_param_view_set_item (BST_PARAM_VIEW (self), item);
 
-  return param_view;
+  return self;
 }
 
 static void
-param_view_reset_item (BstParamView *param_view)
+param_view_reset_item (BstParamView *self)
 {
-  bst_param_view_set_item (param_view, 0);
+  bst_param_view_set_item (self, 0);
 }
 
 void
@@ -176,7 +172,7 @@ bst_param_view_set_item (BstParamView *self,
 			    NULL);
       self->item = 0;
       
-      for (slist = self->bparams; slist; slist = slist->next)
+      for (slist = self->params; slist; slist = slist->next)
 	bst_param_set_proxy (slist->data, 0);
     }
 
@@ -213,6 +209,21 @@ bst_param_view_set_mask (BstParamView *param_view,
   param_view->last_base_type = g_strdup (last_base_type);
 }
 
+void
+bst_param_view_apply_defaults (BstParamView *self)
+{
+  g_return_if_fail (BST_IS_PARAM_VIEW (self));
+
+  if (self->item)
+    {
+      GSList *slist;
+      bse_item_group_undo (self->item, "Reset to defaults");
+      for (slist = self->params; slist; slist = slist->next)
+        gxk_param_apply_default (slist->data);
+      bse_item_ungroup_undo (self->item);
+    }
+}
+
 void
 bst_param_view_rebuild (BstParamView *self)
 {
@@ -237,26 +248,25 @@ bst_param_view_rebuild (BstParamView *self)
     if ((!self->reject_pattern || !g_pattern_match_string (self->reject_pattern, pstrings[i])) &&
 	(!self->match_pattern || g_pattern_match_string (self->reject_pattern, pstrings[i])))
       {
-	GParamSpec *pspec = bse_proxy_get_pspec (self->item, pstrings[i]);
+        GParamSpec *pspec = bse_proxy_get_pspec (self->item, pstrings[i]);
 	const gchar *param_group = sfi_pspec_get_group (pspec);
-
-	if (sfi_pspec_test_hint (pspec, SFI_PARAM_SERVE_GUI) && (pspec->flags & G_PARAM_READABLE) &&
+	if (sfi_pspec_check_option (pspec, "G") && /* GUI representable */
             ((pspec->flags & G_PARAM_WRITABLE) || BST_DVL_HINTS))
 	  {
-	    BstParam *bparam = bst_param_proxy_create (pspec, FALSE, NULL, self->item);
-	    if (param_group)
-	      {
-		if (!gcontainer)
-		  gcontainer = g_object_new (GTK_TYPE_VBOX, NULL);
-		bst_param_pack_property (bparam, gcontainer);
-	      }
-	    else
-	      {
-		if (!ncontainer)
-		  ncontainer = g_object_new (GTK_TYPE_VBOX, NULL);
-		bst_param_pack_property (bparam, ncontainer);
-	      }
-	    self->bparams = g_slist_prepend (self->bparams, bparam);
+            GxkParam *param = bst_param_new_proxy (pspec, self->item);
+            if (param_group)
+              {
+                if (!gcontainer)
+                  gcontainer = g_object_new (GTK_TYPE_VBOX, NULL);
+                bst_param_create_gmask (param, NULL, gcontainer);
+              }
+            else
+              {
+                if (!ncontainer)
+                  ncontainer = g_object_new (GTK_TYPE_VBOX, NULL);
+                bst_param_create_gmask (param, NULL, ncontainer);
+              }
+            self->params = g_slist_prepend (self->params, param);
 	  }
       }
 
@@ -304,6 +314,6 @@ bst_param_view_rebuild (BstParamView *self)
     }
 
   /* refresh parameter fields */
-  for (slist = self->bparams; slist; slist = slist->next)
-    bst_param_update (slist->data);
+  for (slist = self->params; slist; slist = slist->next)
+    gxk_param_update (slist->data);
 }
