@@ -19,8 +19,8 @@
 #include "bsteventrollctrl.h"
 
 
-#define NOTE_LENGTH(self)       ((self)->note_rtools->tool_id)
-#define QUANTIZATION(self)      ((self)->quant_rtools->tool_id)
+#define NOTE_LENGTH(self)       ((self)->note_rtools->action_id)
+#define QUANTIZATION(self)      ((self)->quant_rtools->action_id)
 #define HAVE_OBJECT             (1 << 31)
 
 
@@ -38,6 +38,73 @@ static BsePartNoteSeq *clipboard_pseq = NULL;
 
 
 /* --- functions --- */
+GxkActionList*
+bst_piano_roll_controller_canvas_actions (BstPianoRollController *self)
+{
+  GxkActionList *alist = gxk_action_list_create_grouped (self->canvas_rtools);
+  static const GxkStockAction actions[] = {
+    { N_("Insert"),           "I",    N_("Insert/resize/move notes (mouse button 1 and 2)"),
+      BST_GENERIC_ROLL_TOOL_INSERT,   BST_STOCK_PART_TOOL },
+    { N_("Delete"),           "D",    N_("Delete note (mouse button 1)"),
+      BST_GENERIC_ROLL_TOOL_DELETE,   BST_STOCK_TRASHCAN },
+    { N_("Align Events"),     "A",    N_("Draw a line to align events to"),
+      BST_GENERIC_ROLL_TOOL_ALIGN,    BST_STOCK_EVENT_CONTROL },
+    { N_("Select"),           "S",    N_("Rectangle select notes"),
+      BST_GENERIC_ROLL_TOOL_SELECT,   BST_STOCK_RECT_SELECT },
+    { N_("Vertical Select"),  "V",    N_("Select tick range vertically"),
+      BST_GENERIC_ROLL_TOOL_VSELECT,  BST_STOCK_VERT_SELECT },
+  };
+  gxk_action_list_add_actions (alist, G_N_ELEMENTS (actions), actions,
+                               NULL /*i18n_domain*/, NULL /*acheck*/, NULL /*aexec*/, NULL);
+  return alist;
+}
+
+GxkActionList*
+bst_piano_roll_controller_note_actions (BstPianoRollController *self)
+{
+  GxkActionList *alist = gxk_action_list_create_grouped (self->note_rtools);
+  static const GxkStockAction actions[] = {
+    { N_("1\\/1"),              "1",    N_("Insert full notes"),
+      1,                        BST_STOCK_NOTE_1, },
+    { N_("1\\/2"),              "2",    N_("Insert half notes"),
+      2,                        BST_STOCK_NOTE_2, },
+    { N_("1\\/4"),              "4",    N_("Insert quarter notes"),
+      4,                        BST_STOCK_NOTE_4, },
+    { N_("1\\/8"),              "8",    N_("Insert eighths note"),
+      8,                        BST_STOCK_NOTE_8, },
+    { N_("1\\/16"),             "6",    N_("Insert sixteenth note"),
+      16,                       BST_STOCK_NOTE_16, },
+  };
+  gxk_action_list_add_actions (alist, G_N_ELEMENTS (actions), actions,
+                               NULL /*i18n_domain*/, NULL /*acheck*/, NULL /*aexec*/, NULL);
+  return alist;
+}
+
+GxkActionList*
+bst_piano_roll_controller_quant_actions (BstPianoRollController *self)
+{
+  GxkActionList *alist = gxk_action_list_create_grouped (self->quant_rtools);
+  static const GxkStockAction actions[] = {
+      { N_("Q: Tact"),          "<ctrl>T",      N_("Quantize to tact boundaries"),
+        BST_QUANTIZE_TACT,      BST_STOCK_QTACT, },
+      { N_("Q: None"),          "<ctrl>0",      N_("No quantization selected"),
+        BST_QUANTIZE_NONE,      BST_STOCK_QNOTE_NONE, },
+      { N_("Q: 1\\/1"),         "<ctrl>1",      N_("Quantize to full note boundaries"),
+        BST_QUANTIZE_NOTE_1,    BST_STOCK_QNOTE_1, },
+      { N_("Q: 1\\/2"),         "<ctrl>2",      N_("Quantize to half note boundaries"),
+        BST_QUANTIZE_NOTE_2,    BST_STOCK_QNOTE_2, },
+      { N_("Q: 1\\/4"),         "<ctrl>4",      N_("Quantize to quarter note boundaries"),
+        BST_QUANTIZE_NOTE_4,    BST_STOCK_QNOTE_4, },
+      { N_("Q: 1\\/8"),         "<ctrl>8",      N_("Quantize to eighths note boundaries"),
+        BST_QUANTIZE_NOTE_8,    BST_STOCK_QNOTE_8, },
+      { N_("Q: 1\\/16"),        "<ctrl>6",      N_("Quantize to sixteenth note boundaries"),
+        BST_QUANTIZE_NOTE_16,   BST_STOCK_QNOTE_16, },
+  };
+  gxk_action_list_add_actions (alist, G_N_ELEMENTS (actions), actions,
+                               NULL /*i18n_domain*/, NULL /*acheck*/, NULL /*aexec*/, NULL);
+  return alist;
+}
+
 void
 bst_piano_roll_controller_set_clipboard (BsePartNoteSeq *pseq)
 {
@@ -54,6 +121,12 @@ bst_piano_roll_controller_get_clipboard (void)
   return clipboard_pseq;
 }
 
+static void
+controller_reset_canvas_cursor (BstPianoRollController *self)
+{
+  controller_update_canvas_cursor (self, self->canvas_rtools->action_id);
+}
+
 BstPianoRollController*
 bst_piano_roll_controller_new (BstPianoRoll *proll)
 {
@@ -74,51 +147,19 @@ bst_piano_roll_controller_new (BstPianoRoll *proll)
 			 G_CALLBACK (controller_piano_drag),
 			 self, NULL,
 			 G_CONNECT_SWAPPED);
-  /* register canvas tools */
-  self->canvas_rtools = bst_radio_tools_new ();
-  {
-    BstTool radio_tools[] = {
-      { CKEY ("PianoRoll/Insert"),      BST_GENERIC_ROLL_TOOL_INSERT,     BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("PianoRoll/Delete"),      BST_GENERIC_ROLL_TOOL_DELETE,     BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("PianoRoll/Align"),       BST_GENERIC_ROLL_TOOL_ALIGN,      BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("PianoRoll/Select"),      BST_GENERIC_ROLL_TOOL_SELECT,     BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("PianoRoll/VSelect"),     BST_GENERIC_ROLL_TOOL_VSELECT,    BST_RADIO_TOOLS_EVERYWHERE },
-    };
-    bst_radio_tools_add_tools (self->canvas_rtools, G_N_ELEMENTS (radio_tools), radio_tools);
-    bst_radio_tools_set_tool (self->canvas_rtools, BST_GENERIC_ROLL_TOOL_INSERT);
-  }
-  /* register note length tools */
-  self->note_rtools = bst_radio_tools_new ();
-  {
-    BstTool radio_tools[] = {
-      { CKEY ("Note/1"),                1,    BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("Note/2"),                2,    BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("Note/4"),                4,    BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("Note/8"),                8,    BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("Note/16"),               16,   BST_RADIO_TOOLS_EVERYWHERE },
-    };
-    bst_radio_tools_add_tools (self->note_rtools, G_N_ELEMENTS (radio_tools), radio_tools);
-    bst_radio_tools_set_tool (self->note_rtools, 4);
-  }
-  /* register quantization tools */
-  self->quant_rtools = bst_radio_tools_new ();
-  {
-    BstTool radio_tools[] = {
-      { CKEY ("Quant/None"),    BST_QUANTIZE_NONE,      BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("Quant/1"),       BST_QUANTIZE_NOTE_1,    BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("Quant/2"),       BST_QUANTIZE_NOTE_2,    BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("Quant/4"),       BST_QUANTIZE_NOTE_4,    BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("Quant/8"),       BST_QUANTIZE_NOTE_8,    BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("Quant/16"),      BST_QUANTIZE_NOTE_16,   BST_RADIO_TOOLS_EVERYWHERE },
-    };
-    bst_radio_tools_add_tools (self->quant_rtools, G_N_ELEMENTS (radio_tools), radio_tools);
-    bst_radio_tools_set_tool (self->quant_rtools, BST_QUANTIZE_NOTE_8);
-  }
-  /* update from rtools */
-  g_object_connect (self->canvas_rtools,
-                    "swapped_signal::set_tool", controller_update_canvas_cursor, self,
-                    NULL);
-  controller_update_canvas_cursor (self, self->canvas_rtools->tool_id);
+  /* canvas tools */
+  self->canvas_rtools = gxk_action_group_new ();
+  gxk_action_group_select (self->canvas_rtools, BST_GENERIC_ROLL_TOOL_INSERT);
+  /* note length selection */
+  self->note_rtools = gxk_action_group_new ();
+  gxk_action_group_select (self->note_rtools, 4);
+  /* quantization selection */
+  self->quant_rtools = gxk_action_group_new ();
+  gxk_action_group_select (self->quant_rtools, BST_QUANTIZE_NOTE_8);
+  /* update from action group */
+  g_signal_connect_swapped (self->canvas_rtools, "changed",
+                            G_CALLBACK (controller_reset_canvas_cursor), self);
+  controller_reset_canvas_cursor (self);
   return self;
 }
 
@@ -142,11 +183,11 @@ bst_piano_roll_controller_unref (BstPianoRollController *self)
   self->ref_count--;
   if (!self->ref_count)
     {
-      bst_radio_tools_dispose (self->canvas_rtools);
+      gxk_action_group_dispose (self->canvas_rtools);
       g_object_unref (self->canvas_rtools);
-      bst_radio_tools_dispose (self->note_rtools);
+      gxk_action_group_dispose (self->note_rtools);
       g_object_unref (self->note_rtools);
-      bst_radio_tools_dispose (self->quant_rtools);
+      gxk_action_group_dispose (self->quant_rtools);
       g_object_unref (self->quant_rtools);
       g_free (self);
     }
@@ -157,7 +198,7 @@ piano_canvas_button_tool (BstPianoRollController *self,
                           guint                   button,
                           guint                   have_object)
 {
-  switch (self->canvas_rtools->tool_id | /* user selected tool */
+  switch (self->canvas_rtools->action_id | /* user selected tool */
           (have_object ? HAVE_OBJECT : 0))
     {
     case BST_GENERIC_ROLL_TOOL_INSERT: /* background */
@@ -337,21 +378,24 @@ guint
 bst_piano_roll_controller_quantize (BstPianoRollController *self,
                                     guint                   fine_tick)
 {
+  BseSongTiming *timing;
+  guint quant, tick, qtick;
   g_return_val_if_fail (self != NULL, fine_tick);
 
-  /* quantize tick */
-  if (QUANTIZATION (self) && self->proll)
-    {
-      guint quant = self->proll->ppqn * 4 / QUANTIZATION (self);
-      guint qtick = fine_tick / quant;
-      qtick *= quant;
-      if (fine_tick - qtick > quant / 2 &&
-          qtick + quant > fine_tick)
-        fine_tick = qtick + quant;
-      else
-        fine_tick = qtick;
-    }
-  return fine_tick;
+  timing = bse_part_get_timing (self->proll->proxy, fine_tick);
+  if (QUANTIZATION (self) == BST_QUANTIZE_NONE)
+    quant = 1;
+  else if (QUANTIZATION (self) == BST_QUANTIZE_TACT)
+    quant = timing->tpt;
+  else
+    quant = timing->tpqn * 4 / QUANTIZATION (self);
+  tick = fine_tick - timing->tick;
+  qtick = tick / quant;
+  qtick *= quant;
+  if (tick - qtick > quant / 2)
+    qtick += quant;
+  tick = timing->tick + qtick;
+  return tick;
 }
 
 static void
@@ -787,7 +831,7 @@ controller_canvas_drag (BstPianoRollController *self,
     }
   if (drag->type == BST_DRAG_DONE ||
       drag->type == BST_DRAG_ABORT)
-    controller_update_canvas_cursor (self, self->canvas_rtools->tool_id);
+    controller_reset_canvas_cursor (self);
 }
 
 void
