@@ -17,16 +17,15 @@
  */
 #include "bstplayback.h"
 #include "bstapp.h"
-#include "bststatusbar.h"
 
-#include "../PKG_config.h"	/* BST_HAVE_BIRNET */
 
 
 
 /* --- prototypes --- */
 static void wave_oscillator_pcm_notify (BstPlayBackHandle *handle,
+					SfiNum             tick_stamp,
 					guint		   pcm_position,
-					BswProxy	   wosc);
+					SfiProxy	   wosc);
 
 
 /* --- functions --- */
@@ -36,19 +35,19 @@ bst_play_back_handle_new (void)
   BstPlayBackHandle *handle;
 
   handle = g_new0 (BstPlayBackHandle, 1);
-  handle->project = bsw_server_use_new_project (BSW_SERVER, "# BEAST Play Back");
-  if (BST_DVL_EXT)
-    gtk_idle_show_widget (GTK_WIDGET (bst_app_new (handle->project)));
+  handle->project = bse_server_use_new_project (BSE_SERVER, "# BEAST Play Back");
+  if (BST_DBG_EXT)
+    gxk_idle_show_widget (GTK_WIDGET (bst_app_new (handle->project)));
 
-  handle->snet = bsw_project_create_snet (handle->project, NULL);
-  bsw_proxy_set (handle->snet, "auto_activate", TRUE, NULL);
-  handle->speaker = bsw_snet_create_source (handle->snet, "BsePcmOutput");
-  handle->wosc = bsw_snet_create_source (handle->snet, "BseWaveOsc");
-  bsw_source_set_input_by_id (handle->speaker, 0, handle->wosc, 0);
-  bsw_source_set_input_by_id (handle->speaker, 1, handle->wosc, 0);
-  handle->constant = bsw_snet_create_source (handle->snet, "BseConstant");
-  bsw_source_set_input_by_id (handle->wosc, 0, handle->constant, 0);
-  bsw_proxy_connect (handle->wosc,
+  handle->snet = bse_project_create_csynth (handle->project, NULL);
+  bse_proxy_set (handle->snet, "auto_activate", TRUE, NULL);
+  handle->speaker = bse_snet_create_source (handle->snet, "BsePcmOutput");
+  handle->wosc = bse_snet_create_source (handle->snet, "BseWaveOsc");
+  bse_source_set_input_by_id (handle->speaker, 0, handle->wosc, 0);
+  bse_source_set_input_by_id (handle->speaker, 1, handle->wosc, 0);
+  handle->constant = bse_snet_create_source (handle->snet, "BseConstant");
+  bse_source_set_input_by_id (handle->wosc, 0, handle->constant, 0);
+  bse_proxy_connect (handle->wosc,
 		     "swapped_signal::notify_pcm_position", wave_oscillator_pcm_notify, handle,
 		     NULL);
   return handle;
@@ -56,15 +55,15 @@ bst_play_back_handle_new (void)
 
 void
 bst_play_back_handle_set (BstPlayBackHandle *handle,
-			  BswProxy	     esample,
+			  SfiProxy	     esample,
 			  gdouble            osc_freq)
 {
   g_return_if_fail (handle != NULL);
   if (esample)
-    g_return_if_fail (BSW_IS_EDITABLE_SAMPLE (esample));
+    g_return_if_fail (BSE_IS_EDITABLE_SAMPLE (esample));
 
-  bsw_proxy_set (handle->constant, "frequency_1", osc_freq, NULL);
-  bsw_proxy_set (handle->wosc, "editable_sample", esample, NULL);
+  bse_proxy_set (handle->constant, "frequency_1", osc_freq, NULL);
+  bse_wave_osc_set_from_editable_sample (handle->wosc, esample);
 }
 
 void
@@ -72,29 +71,31 @@ bst_play_back_handle_start (BstPlayBackHandle *handle)
 {
   BseErrorType error;
 
-  error = bsw_server_run_project (BSW_SERVER, handle->project);
+  error = bse_project_play (handle->project);
   if (error)
-    bst_status_eprintf (error, "Playback");
+    bst_status_eprintf (error, _("Playback"));
 }
 
 void
 bst_play_back_handle_seek_perc (BstPlayBackHandle *handle,
 				gfloat             perc)
 {
-  bsw_wave_osc_pcm_seek_perc (handle->wosc, perc);
+  bse_wave_osc_pcm_seek_perc (handle->wosc, perc);
+  if (handle->waiting_for_notify)
+    handle->discard_next_notify = TRUE;
 }
 
 void
 bst_play_back_handle_stop (BstPlayBackHandle *handle)
 {
-  bsw_server_halt_project (BSW_SERVER, handle->project);
+  bse_project_stop (handle->project);
   bst_play_back_handle_pcm_notify (handle, 0, NULL, NULL);
 }
 
 void
 bst_play_back_handle_toggle (BstPlayBackHandle *handle)
 {
-  if (bsw_project_is_playing (handle->project))
+  if (bse_project_is_playing (handle->project))
     bst_play_back_handle_stop (handle);
   else
     bst_play_back_handle_start (handle);
@@ -103,18 +104,23 @@ bst_play_back_handle_toggle (BstPlayBackHandle *handle)
 gboolean
 bst_play_back_handle_is_playing (BstPlayBackHandle *handle)
 {
-  return bsw_project_is_playing (handle->project);
+  return bse_project_is_playing (handle->project);
 }
 
 static void
 wave_oscillator_pcm_notify (BstPlayBackHandle *handle,
+			    SfiNum             tick_stamp,
 			    guint              pcm_position,
-			    BswProxy           wosc)
+			    SfiProxy           wosc)
 {
+  gboolean discard_next_notify = handle->discard_next_notify;
+
   g_assert (handle->wosc == wosc);
 
-  if (handle->pcm_notify)
-    handle->pcm_notify (handle->pcm_data, pcm_position);
+  handle->waiting_for_notify = FALSE;
+  handle->discard_next_notify = FALSE;
+  if (handle->pcm_notify && !discard_next_notify)
+    handle->pcm_notify (handle->pcm_data, tick_stamp, pcm_position);
 }
 
 static gboolean
@@ -123,7 +129,11 @@ pcm_timer (gpointer data)
   BstPlayBackHandle *handle = data;
 
   GDK_THREADS_ENTER ();
-  bsw_wave_osc_request_pcm_position (handle->wosc);
+  if (!handle->waiting_for_notify)
+    {
+      bse_wave_osc_request_pcm_position (handle->wosc);
+      handle->waiting_for_notify = TRUE;
+    }
   GDK_THREADS_LEAVE ();
 
   return TRUE;
@@ -135,19 +145,38 @@ bst_play_back_handle_pcm_notify (BstPlayBackHandle *handle,
 				 BstPlayBackNotify  notify,
 				 gpointer           data)
 {
-  if (!bsw_project_is_playing (handle->project))
+  if (!bse_project_is_playing (handle->project))
     {
       notify = NULL;
       data = NULL;
     }
   handle->pcm_notify = notify;
   handle->pcm_data = data;
-  if (handle->pcm_notify && !handle->pcm_timeout)
-    handle->pcm_timeout = g_timeout_add_full (GTK_PRIORITY_HIGH, timeout, pcm_timer, handle, NULL);
-  else if (!handle->pcm_notify && handle->pcm_timeout)
+  if (handle->pcm_timeout)
     {
       g_source_remove (handle->pcm_timeout);
       handle->pcm_timeout = 0;
+      if (handle->waiting_for_notify)
+	handle->discard_next_notify = TRUE;
+    }
+  if (handle->pcm_notify)
+    {
+      handle->current_delay = timeout;
+      handle->pcm_timeout = g_timeout_add_full (GTK_PRIORITY_HIGH, handle->current_delay,
+						pcm_timer, handle, NULL);
+    }
+}
+
+void
+bst_play_back_handle_time_pcm_notify (BstPlayBackHandle *handle,
+				      guint              timeout)
+{
+  if (handle->current_delay != timeout && handle->pcm_timeout)
+    {
+      handle->current_delay = timeout;
+      g_source_remove (handle->pcm_timeout);
+      handle->pcm_timeout = g_timeout_add_full (GTK_PRIORITY_HIGH, handle->current_delay,
+						pcm_timer, handle, NULL);
     }
 }
 
@@ -158,13 +187,13 @@ bst_play_back_handle_destroy (BstPlayBackHandle *handle)
 
   bst_play_back_handle_stop (handle);
 
-  bsw_proxy_disconnect (handle->wosc,
+  bse_proxy_disconnect (handle->wosc,
 			"any_signal", wave_oscillator_pcm_notify, handle,
 			NULL);
 
   if (handle->pcm_timeout)
     g_source_remove (handle->pcm_timeout);
 
-  bsw_item_unuse (handle->project);
+  bse_item_unuse (handle->project);
   g_free (handle);
 }
