@@ -16,10 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "bsttrackview.h"
-#include "bstactivatable.h"
 #include "bstparam.h"
 #include "bsttracksynthdialog.h"
-
 #include <stdlib.h> /* strtol */
 #include <string.h>
 
@@ -29,11 +27,10 @@
 static void	bst_track_view_class_init	(BstTrackViewClass	*klass);
 static void	bst_track_view_init		(BstTrackView		*self);
 static void	bst_track_view_finalize		(GObject		*object);
-static void     bst_track_view_activate         (BstActivatable         *activatable,
+static gboolean track_view_action_check         (gpointer                data,
                                                  gulong                  action);
-static gboolean bst_track_view_can_activate     (BstActivatable         *activatable,
+static void     track_view_action_exec          (gpointer                data,
                                                  gulong                  action);
-static void	bst_track_view_create_tree	(BstItemView		*iview);
 static void     track_view_set_container        (BstItemView            *self,
 						 SfiProxy                new_container);
 static void	track_view_listen_on		(BstItemView		*iview,
@@ -56,14 +53,19 @@ enum {
 };
 
 
-/* --- track ops --- */
-static BstItemViewOp track_view_ops[] = {
-  { N_("Add"),		BST_ACTION_ADD_TRACK,   	BST_STOCK_TRACK,
-    N_("Add a new track to this song") },
-  { N_("Delete"),	BST_ACTION_DELETE_TRACK,	BST_STOCK_TRASHCAN,
-    N_("Delete the currently selected track") },
+/* --- track actions --- */
+enum {
+  ACTION_ADD_TRACK,
+  ACTION_DELETE_TRACK
+};
+static const GxkStockAction track_view_actions[] = {
+  { N_("Add"),            NULL,         N_("Add a new track to this song"),
+    ACTION_ADD_TRACK,     BST_STOCK_TRACK,
+  },
+  { N_("Delete"),         NULL,         N_("Delete the currently selected track"),
+    ACTION_DELETE_TRACK,  BST_STOCK_TRASHCAN,
+  },
 };
-static guint n_track_view_ops = sizeof (track_view_ops) / sizeof (track_view_ops[0]);
 
 
 /* --- variables --- */
@@ -89,10 +91,6 @@ bst_track_view_get_type (void)
         (GInstanceInitFunc) bst_track_view_init,
       };
       type = g_type_register_static (BST_TYPE_ITEM_VIEW, "BstTrackView", &type_info, 0);
-      bst_type_implement_activatable (type,
-                                      bst_track_view_activate,
-                                      bst_track_view_can_activate,
-                                      NULL);
     }
   return type;
 }
@@ -107,11 +105,6 @@ bst_track_view_class_init (BstTrackViewClass *class)
 
   gobject_class->finalize = bst_track_view_finalize;
 
-  item_view_class->n_ops = n_track_view_ops;
-  item_view_class->ops = track_view_ops;
-  item_view_class->horizontal_ops = TRUE;
-  item_view_class->show_properties = FALSE;
-  item_view_class->create_tree = bst_track_view_create_tree;
   item_view_class->set_container = track_view_set_container;
   item_view_class->listen_on = track_view_listen_on;
   item_view_class->unlisten_on = track_view_unlisten_on;
@@ -119,18 +112,13 @@ bst_track_view_class_init (BstTrackViewClass *class)
   item_view_class->item_type = "BseTrack";
 }
 
-static void
-bst_track_view_init (BstTrackView *self)
-{
-}
-
 static void
 bst_track_view_finalize (GObject *object)
 {
   BstTrackView *self = BST_TRACK_VIEW (object);
 
-  if (self->troll_ctrl)
-    bst_track_roll_controller_unref (self->troll_ctrl);
+  if (self->tctrl)
+    bst_track_roll_controller_unref (self->tctrl);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -445,15 +433,22 @@ track_view_repeat_changed (BstTrackView *self)
 }
 
 static void
-bst_track_view_create_tree (BstItemView *iview)
+bst_track_view_init (BstTrackView *self)
 {
-  BstTrackView *self = BST_TRACK_VIEW (iview);
-  GtkWidget *hscroll1, *hscroll2, *vscroll, *trframe, *tlframe, *vb1, *vb2, *vb3, *hb, *align1, *align2, *entry;
+  BstItemView *iview = BST_ITEM_VIEW (self);
+  GtkWidget *treehs, *trackhs, *vscroll;
   GtkObject *adjustment;
-  GtkPaned *paned;
+  GtkTreeView *tview;
   GtkTreeSelection *tsel;
   GtkTreeModel *smodel;
   GxkListWrapper *lwrapper;
+  GxkGadget *gadget;
+
+  /* create GUI */
+  gxk_widget_publish_actions (self, "track-view-actions",
+                              G_N_ELEMENTS (track_view_actions), track_view_actions,
+                              NULL, track_view_action_check, track_view_action_exec);
+  gadget = gxk_gadget_complete (GTK_WIDGET (self), "beast", "track-view", NULL);
 
   /* item list model */
   lwrapper = gxk_list_wrapper_new (N_COLS,
@@ -473,24 +468,15 @@ bst_track_view_create_tree (BstItemView *iview)
   g_object_unref (lwrapper);
   
   /* scrollbars */
-  hscroll1 = gtk_hscrollbar_new (NULL);
-  hscroll2 = gtk_hscrollbar_new (NULL);
-  vscroll = gtk_vscrollbar_new (NULL);
-  align1 = g_object_new (GTK_TYPE_ALIGNMENT, NULL);
-  align2 = g_object_new (GTK_TYPE_ALIGNMENT, NULL);
-
+  treehs = gxk_gadget_find (gadget, "tree-hscrollbar");
+  trackhs = gxk_gadget_find (gadget, "track-hscrollbar");
+  vscroll = gxk_gadget_find (gadget, "tree-vscrollbar");
+  
   /* tree view (track list) */
-  tlframe = g_object_new (GTK_TYPE_FRAME, "shadow_type", GTK_SHADOW_IN, NULL);
-  iview->tree = g_object_new (GTK_TYPE_TREE_VIEW,
-			      "can_focus", TRUE,
-			      "model", smodel,
-			      "parent", tlframe,
-			      "rules_hint", TRUE,
-			      "height_request", BST_ITEM_VIEW_TREE_HEIGHT,
-			      "width_request", 200,
-			      NULL);
-  gxk_nullify_on_destroy (iview->tree, &iview->tree);
-  gtk_tree_view_set_hadjustment (iview->tree, gtk_range_get_adjustment (GTK_RANGE (hscroll1)));
+  tview = gxk_gadget_find (gadget, "tree-view");
+  gtk_tree_view_set_model (tview, smodel);
+  bst_item_view_set_tree (iview, tview);
+  gtk_tree_view_set_hadjustment (iview->tree, gtk_range_get_adjustment (GTK_RANGE (treehs)));
   gtk_tree_view_set_vadjustment (iview->tree, gtk_range_get_adjustment (GTK_RANGE (vscroll)));
   tsel = gtk_tree_view_get_selection (iview->tree);
   gtk_tree_selection_set_mode (tsel, GTK_SELECTION_BROWSE);
@@ -498,16 +484,16 @@ bst_track_view_create_tree (BstItemView *iview)
   g_object_unref (smodel);
 
   /* track roll */
-  trframe = g_object_new (GTK_TYPE_FRAME, "shadow_type", GTK_SHADOW_IN, NULL);
   self->troll = g_object_new (BST_TYPE_TRACK_ROLL,
-			      "parent", trframe,
+                              "visible", TRUE,
+			      "parent", gxk_gadget_find (gadget, "track-area"),
 			      NULL);
   gxk_nullify_on_destroy (self->troll, &self->troll);
-  bst_track_roll_set_hadjustment (self->troll, gtk_range_get_adjustment (GTK_RANGE (hscroll2)));
+  bst_track_roll_set_hadjustment (self->troll, gtk_range_get_adjustment (GTK_RANGE (trackhs)));
   bst_track_roll_set_vadjustment (self->troll, gtk_range_get_adjustment (GTK_RANGE (vscroll)));
   bst_track_roll_set_track_callback (self->troll, self, get_track);
   track_view_marks_changed (self);
-  
+
   /* link track roll to tree view and list model */
   g_signal_connect_object (tsel, "changed",
 			   G_CALLBACK (update_selection),
@@ -534,84 +520,30 @@ bst_track_view_create_tree (BstItemView *iview)
 			   self->troll, G_CONNECT_SWAPPED);
 
   /* track roll controller */
-  self->troll_ctrl = bst_track_roll_controller_new (self->troll);
-  bst_track_roll_controller_set_song (self->troll_ctrl, iview->container);
-
-  /* create toolbar */
-  self->toolbar = gxk_toolbar_new (&self->toolbar);
-  /* add radio tools to toolbar */
-  bst_radio_tools_build_toolbar (self->troll_ctrl->canvas_rtools, self->toolbar);
-  gxk_toolbar_append_separator (self->toolbar);
-  bst_radio_tools_build_toolbar_choice (self->troll_ctrl->hpanel_rtools, self->toolbar);
+  self->tctrl = bst_track_roll_controller_new (self->troll);
+  bst_track_roll_controller_set_song (self->tctrl, iview->container);
+  gxk_widget_publish_action_list (self, "tctrl-canvas-tools", bst_track_roll_controller_canvas_actions (self->tctrl));
+  gxk_widget_publish_action_list (self, "tctrl-hpanel-tools", bst_track_roll_controller_hpanel_actions (self->tctrl));
+  gxk_widget_publish_action_list (self, "tctrl-quant-tools", bst_track_roll_controller_quant_actions (self->tctrl));
+  
   /* add repeat toggle */
-  self->repeat_toggle = gxk_toolbar_append_stock (self->toolbar, GXK_TOOLBAR_TOGGLE,
-						  "Repeat", "Repeat playback within loop points", BST_STOCK_REPEAT);
+  self->repeat_toggle = gxk_gadget_find (gadget, "repeat-toggle");
   gxk_nullify_on_destroy (self->repeat_toggle, &self->repeat_toggle);
   g_object_connect (self->repeat_toggle, "swapped_signal::toggled", track_view_repeat_toggled, self, NULL);
   track_view_repeat_changed (self);
-  /* add quantization tools to toolbar */
-  gxk_toolbar_append_separator (self->toolbar);
-  bst_radio_tools_build_toolbar_choice (self->troll_ctrl->quant_rtools, self->toolbar);
+
   /* add zoom spinner */
-  gxk_toolbar_append_separator (self->toolbar);
   adjustment = gtk_adjustment_new (50, 1, 100, 1, 5, 0);
   g_object_connect (adjustment,
 		    "swapped_signal_after::value_changed", track_view_hzoom_changed, self,
 		    NULL);
-  entry = g_object_new (GTK_TYPE_SPIN_BUTTON,
-			"visible", TRUE,
-			"adjustment", adjustment,
-			"digits", 0,
-			"width_request", 2 * gxk_size_width (BST_SIZE_TOOLBAR),
-			NULL);
-  gxk_toolbar_append (self->toolbar, GXK_TOOLBAR_EXTRA_WIDGET,
-		      "Zoom", "Horizontal Zoom", entry);
-
-  /* setup accelerators */
-  gxk_widget_activate_accel_group (GTK_WIDGET (self), self->troll_ctrl->canvas_rtools->accel_group);
-  gxk_widget_activate_accel_group (GTK_WIDGET (self), self->troll_ctrl->hpanel_rtools->accel_group);
-  gxk_widget_activate_accel_group (GTK_WIDGET (self), self->troll_ctrl->quant_rtools->accel_group);
-
-  /* tree view box */
-  vb1 = g_object_new (GTK_TYPE_VBOX, "spacing", SCROLLBAR_SPACING, NULL);
-  gtk_box_pack_start (GTK_BOX (vb1), iview->tools, FALSE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vb1), tlframe, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vb1), hscroll1, FALSE, TRUE, 0);
-  
-  /* track roll box */
-  vb2 = g_object_new (GTK_TYPE_VBOX, "spacing", SCROLLBAR_SPACING, NULL);
-  gtk_box_pack_start (GTK_BOX (vb2), GTK_WIDGET (self->toolbar), FALSE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vb2), trframe, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vb2), hscroll2, FALSE, TRUE, 0);
-
-  /* vscrollbar box */
-  vb3 = g_object_new (GTK_TYPE_VBOX, "spacing", SCROLLBAR_SPACING, NULL);
-  gtk_box_pack_start (GTK_BOX (vb3), align1, FALSE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vb3), vscroll, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vb3), align2, FALSE, TRUE, 0);
-
-  /* pack boxes and group sizes */
-  gxk_size_group (GTK_SIZE_GROUP_VERTICAL,
-		  iview->tools, self->toolbar, align1,
-		  NULL);
-  gxk_size_group (GTK_SIZE_GROUP_VERTICAL,
-		  tlframe, trframe, vscroll,
-		  NULL);
-  gxk_size_group (GTK_SIZE_GROUP_VERTICAL,
-		  hscroll1, hscroll2, align2,
-		  NULL);
-  paned = g_object_new (GTK_TYPE_HPANED,
-			"height_request", 120,
-			"border_width", 0,
-			"position", 240,
-			NULL);
-  gtk_paned_pack1 (paned, vb1, FALSE, TRUE);
-  gtk_paned_pack2 (paned, vb2, TRUE, TRUE);
-  hb = g_object_new (GTK_TYPE_HBOX,
-		     "child", paned,
-		     "spacing", SCROLLBAR_SPACING,
-		     NULL);
-  gtk_box_pack_start (GTK_BOX (hb), vb3, FALSE, TRUE, 0);
+  gxk_gadget_add (self, "hzoom-area",
+                  g_object_new (GTK_TYPE_SPIN_BUTTON,
+                                "visible", TRUE,
+                                "adjustment", adjustment,
+                                "digits", 0,
+                                "width_request", 2 * gxk_size_width (GXK_ICON_SIZE_TOOLBAR),
+                                NULL));
 
   /* add list view columns */
   if (BST_DVL_HINTS)
@@ -639,9 +571,6 @@ bst_track_view_create_tree (BstItemView *iview)
   gxk_tree_view_add_text_column (iview->tree, COL_BLURB, "",
 				 0.0, _("Comment"), NULL,
 				 bst_item_view_blurb_edited, self, G_CONNECT_SWAPPED);
-
-  /* make widgets visible */
-  gtk_widget_show_all (GTK_WIDGET (hb));
 }
 
 static void
@@ -677,7 +606,7 @@ track_view_set_container (BstItemView *iview,
   BST_ITEM_VIEW_CLASS (parent_class)->set_container (iview, new_container);
   if (BSE_IS_SONG (iview->container))
     {
-      bst_track_roll_controller_set_song (self->troll_ctrl, iview->container);
+      bst_track_roll_controller_set_song (self->tctrl, iview->container);
       bse_proxy_connect (iview->container,
 			 "swapped_signal::pointer-changed", track_view_pointer_changed, self,
 			 "swapped_signal::property-notify::loop-left", track_view_marks_changed, self,
@@ -729,17 +658,17 @@ track_view_unlisten_on (BstItemView *iview,
 }
 
 static void
-bst_track_view_activate (BstActivatable         *activatable,
-                         gulong                  action)
+track_view_action_exec (gpointer data,
+                        gulong   action)
 {
-  BstTrackView *self = BST_TRACK_VIEW (activatable);
+  BstTrackView *self = BST_TRACK_VIEW (data);
   BstItemView *item_view = BST_ITEM_VIEW (self);
   SfiProxy song = item_view->container;
 
   switch (action)
     {
       SfiProxy item;
-    case BST_ACTION_ADD_TRACK:
+    case ACTION_ADD_TRACK:
       bse_item_group_undo (song, "Add Track");
       item = bse_song_create_track (song);
       if (item)
@@ -751,27 +680,27 @@ bst_track_view_activate (BstActivatable         *activatable,
 	}
       bse_item_ungroup_undo (song);
       break;
-    case BST_ACTION_DELETE_TRACK:
+    case ACTION_DELETE_TRACK:
       item = bst_item_view_get_current (item_view);
       bse_song_remove_track (song, item);
       break;
     }
-  bst_widget_update_activatable (activatable);
+  gxk_widget_update_actions_downwards (self);
 }
 
 static gboolean
-bst_track_view_can_activate (BstActivatable *activatable,
-                             gulong          action)
+track_view_action_check (gpointer data,
+                         gulong   action)
 {
-  BstTrackView *self = BST_TRACK_VIEW (activatable);
+  BstTrackView *self = BST_TRACK_VIEW (data);
   BstItemView *item_view = BST_ITEM_VIEW (self);
   
   switch (action)
     {
       SfiProxy item;
-    case BST_ACTION_ADD_TRACK:
+    case ACTION_ADD_TRACK:
       return TRUE;
-    case BST_ACTION_DELETE_TRACK:
+    case ACTION_DELETE_TRACK:
       item = bst_item_view_get_current (item_view);
       return item != 0;
     default:
