@@ -132,54 +132,55 @@ gxk_dialog_class_init (GxkDialogClass *class)
 }
 
 static void
-gxk_dialog_init (GxkDialog *dialog)
+gxk_dialog_init (GxkDialog *self)
 {
-  GtkWindow *window = GTK_WINDOW (dialog);
-
-  dialog->flags = 0;
-  dialog->pointer_loc = NULL;
-  dialog->alive_object = NULL;
-  gxk_dialog_set_title (dialog, DEFAULT_TITLE);
-
+  GtkWindow *window = GTK_WINDOW (self);
+  
+  self->flags = 0;
+  self->pointer_loc = NULL;
+  self->alive_object = NULL;
+  gtk_window_set_role (window, G_OBJECT_TYPE_NAME (self));
+  gxk_dialog_set_title (self, DEFAULT_TITLE);
+  
   /* main box */
-  dialog->mbox = g_object_new (GTK_TYPE_VBOX,
-			       "visible", TRUE,
-			       "homogeneous", FALSE,
-			       "spacing", 0,
-			       "parent", window,
-			       NULL);
-  g_signal_connect_swapped (dialog->mbox, "destroy", G_CALLBACK (g_nullify_pointer), &dialog->mbox);
-
+  self->mbox = g_object_new (GTK_TYPE_VBOX,
+                             "visible", TRUE,
+                             "homogeneous", FALSE,
+                             "spacing", 0,
+                             "parent", window,
+                             NULL);
+  gxk_nullify_in_object (self->mbox, &self->mbox, self);
+  
   /* user vbox */
-  dialog->vbox = g_object_new (GTK_TYPE_VBOX,
-			       "visible", TRUE,
-			       "homogeneous", FALSE,
-			       "spacing", 0,
-			       "parent", dialog->mbox,
-			       NULL);
-  g_signal_connect_swapped (dialog->vbox, "destroy", G_CALLBACK (g_nullify_pointer), &dialog->vbox);
-
+  self->vbox = g_object_new (GTK_TYPE_VBOX,
+                             "visible", TRUE,
+                             "homogeneous", FALSE,
+                             "spacing", 0,
+                             "parent", self->mbox,
+                             NULL);
+  gxk_nullify_in_object (self->vbox, &self->vbox, self);
+  
   /* status bar */
-  dialog->status_bar = gxk_status_bar_create ();
-  g_signal_connect_swapped (dialog->status_bar, "destroy", G_CALLBACK (g_nullify_pointer), &dialog->status_bar);
-  gtk_box_pack_end (GTK_BOX (dialog->mbox), dialog->status_bar, FALSE, FALSE, 0);
-
+  self->status_bar = gxk_status_bar_create ();
+  gxk_nullify_in_object (self->status_bar, &self->status_bar, self);
+  gtk_box_pack_end (GTK_BOX (self->mbox), self->status_bar, FALSE, FALSE, 0);
+  
   /* button box */
-  dialog->hbox = g_object_new (GTK_TYPE_HBOX,
-			       "visible", FALSE,
-			       "homogeneous", TRUE,
-			       "spacing", GXK_INNER_PADDING,
-			       "border_width", GXK_INNER_PADDING,
-			       NULL);
-  g_signal_connect_swapped (dialog->hbox, "destroy", G_CALLBACK (g_nullify_pointer), &dialog->hbox);
-  gtk_box_pack_end (GTK_BOX (dialog->mbox), dialog->hbox, FALSE, TRUE, GXK_INNER_PADDING);
-
+  self->hbox = g_object_new (GTK_TYPE_HBOX,
+                             "visible", FALSE,
+                             "homogeneous", TRUE,
+                             "spacing", GXK_INNER_PADDING,
+                             "border_width", GXK_INNER_PADDING,
+                             NULL);
+  gxk_nullify_in_object (self->hbox, &self->hbox, self);
+  gtk_box_pack_end (GTK_BOX (self->mbox), self->hbox, FALSE, TRUE, GXK_INNER_PADDING);
+  
   /* separator */
-  dialog->sep = g_object_new (GTK_TYPE_HSEPARATOR,
-			      "visible", FALSE,
-			      NULL);
-  g_signal_connect_swapped (dialog->sep, "destroy", G_CALLBACK (g_nullify_pointer), &dialog->sep);
-  gtk_box_pack_end (GTK_BOX (dialog->mbox), dialog->sep, FALSE, FALSE, GXK_INNER_PADDING);
+  self->sep = g_object_new (GTK_TYPE_HSEPARATOR,
+                            "visible", FALSE,
+                            NULL);
+  gxk_nullify_in_object (self->sep, &self->sep, self);
+  gtk_box_pack_end (GTK_BOX (self->mbox), self->sep, FALSE, FALSE, GXK_INNER_PADDING);
 }
 
 static void
@@ -188,61 +189,67 @@ gxk_dialog_set_property (GObject      *object,
 			 const GValue *value,
 			 GParamSpec   *pspec)
 {
-  GxkDialog *dialog = GXK_DIALOG (object);
-
+  GxkDialog *self = GXK_DIALOG (object);
+  
   switch (prop_id)
     {
+      GtkWindow *window;
       const gchar *cstring;
       gchar *string;
       guint old_flags;
     case PROP_ALIVE_OBJECT:
-      if (dialog->alive_object)
-	g_signal_handlers_disconnect_by_func (dialog->alive_object, gtk_widget_destroy, dialog);
-      dialog->alive_object = g_value_get_object (value);
-      if (dialog->alive_object && G_OBJECT (dialog->alive_object)->ref_count)
-	g_signal_connect_swapped (dialog->alive_object, "destroy", G_CALLBACK (gtk_widget_destroy), dialog);
+      if (self->alive_object)
+	g_signal_handlers_disconnect_by_func (self->alive_object, gtk_widget_destroy, self);
+      self->alive_object = g_value_get_object (value);
+      if (self->alive_object && G_OBJECT (self->alive_object)->ref_count)
+	g_signal_connect_swapped (self->alive_object, "destroy", G_CALLBACK (gtk_widget_destroy), self);
       else
-	dialog->alive_object = NULL;
+	self->alive_object = NULL;
       break;
     case PROP_POINTER:
-      dialog->pointer_loc = g_value_get_pointer (value);
+      self->pointer_loc = g_value_get_pointer (value);
       break;
     case PROP_TITLE:
       cstring = g_value_get_string (value);
       if (!cstring)
 	cstring = "";
-      if (!GTK_WIDGET_VISIBLE (dialog))
-	{
-	  if (GTK_WIDGET_REALIZED (dialog))
-	    gtk_widget_unrealize (GTK_WIDGET (dialog));
-	  gtk_window_set_role (GTK_WINDOW (dialog), cstring);
-	}
-      string = g_strconcat (cstring, ": BEAST", NULL);
-      g_object_set (dialog, "GtkWindow::title", string, NULL);
+      string = g_strconcat (cstring, " - ", g_get_prgname (), NULL);
+      g_object_set (self, "GtkWindow::title", string, NULL);
       g_free (string);
       break;
     case PROP_FLAGS:
-      old_flags = dialog->flags;
-      dialog->flags = g_value_get_flags (value);
-      if (dialog->status_bar)
+      old_flags = self->flags;
+      self->flags = g_value_get_flags (value);
+      window = GTK_WINDOW (self);
+      if (!(old_flags & GXK_DIALOG_STATUS_SHELL) && (self->flags & GXK_DIALOG_STATUS_SHELL))
 	{
-	  if (dialog->flags & GXK_DIALOG_STATUS_SHELL)
-	    gtk_widget_show (dialog->status_bar);
-	  else
-	    gtk_widget_hide (dialog->status_bar);
+	  GtkWindowGroup *wgroup = gtk_window_group_new ();
+	  if (window->group)
+	    gtk_window_group_remove_window (window->group, window);
+	  /* gtk_window_group_add_window (wgroup, window); GTKFIX: Gtk+-2.2.1 window groups seem to be broken wrt menus */
+	  g_object_unref (wgroup);
+	  if (self->status_bar)
+	    gtk_widget_show (self->status_bar);
 	}
-      gtk_window_set_modal (GTK_WINDOW (dialog), dialog->flags & GXK_DIALOG_MODAL);
+      else if ((old_flags & GXK_DIALOG_STATUS_SHELL) && !(self->flags & GXK_DIALOG_STATUS_SHELL))
+	{
+	  if (window->group)
+	    gtk_window_group_remove_window (window->group, window);
+	  if (self->status_bar)
+	    gtk_widget_hide (self->status_bar);
+	}
+      gtk_window_set_modal (GTK_WINDOW (self), self->flags & GXK_DIALOG_MODAL);
       /* some flags can't be unset */
       if (!(old_flags & GXK_DIALOG_DELETE_BUTTON) &&
-	  (dialog->flags & GXK_DIALOG_DELETE_BUTTON))
+	  (self->flags & GXK_DIALOG_DELETE_BUTTON))
 	{
 	  /* we synthesize a delete event instead of hiding/destroying
 	   * directly, because derived classes may override delete_event
 	   */
-	  gxk_dialog_default_action (dialog, GTK_STOCK_CLOSE, gxk_toplevel_delete, NULL);
+	  gxk_dialog_default_action (self, GTK_STOCK_CLOSE, gxk_toplevel_delete, NULL);
 	}
       else if (old_flags & GXK_DIALOG_DELETE_BUTTON)
-	dialog->flags |= GXK_DIALOG_DELETE_BUTTON;
+	self->flags |= GXK_DIALOG_DELETE_BUTTON;
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -257,7 +264,7 @@ gxk_dialog_get_property (GObject     *object,
 			 GParamSpec  *pspec)
 {
   GxkDialog *dialog = GXK_DIALOG (object);
-
+  
   switch (prop_id)
     {
     case PROP_FLAGS:
@@ -299,7 +306,11 @@ gxk_dialog_destroy (GtkObject *object)
 static void
 gxk_dialog_finalize (GObject *object)
 {
-  // GxkDialog *dialog = GXK_DIALOG (object);
+  GxkDialog *dialog = GXK_DIALOG (object);
+
+  if (dialog->child)
+    g_object_unref (dialog->child);
+  dialog->child = NULL;
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -410,16 +421,9 @@ gxk_dialog_clear_flags (GxkDialog     *dialog,
 GtkWidget*
 gxk_dialog_get_child (GxkDialog *dialog)
 {
-  GtkBoxChild *child;
-  GtkBox *box;
-
   g_return_val_if_fail (GXK_IS_DIALOG (dialog), NULL);
-
   /* return the single child that was passed to gxk_dialog_new() if any */
-  box = dialog->vbox ? GTK_BOX (dialog->vbox) : NULL;
-  child = box && box->children ? box->children->data : NULL;
-
-  return child ? child->widget : NULL;
+  return dialog->child;
 }
 
 /**
@@ -437,38 +441,101 @@ gxk_dialog_set_child (GxkDialog *dialog,
   g_return_if_fail (GXK_IS_DIALOG (dialog));
 
   gtk_container_foreach (GTK_CONTAINER (dialog->vbox), (GtkCallback) gtk_widget_destroy, NULL);
-  if (child)
-    gtk_container_add (GTK_CONTAINER (dialog->vbox), child);
+  if (dialog->child)
+    g_object_unref (dialog->child);
+  dialog->child = child;
+  if (dialog->child)
+    {
+      g_object_ref (dialog->child);
+      gtk_container_add (GTK_CONTAINER (dialog->vbox), gtk_widget_get_toplevel (child));
+    }
+}
+
+/**
+ * gxk_dialog_set_focus
+ * @dialog:        valid #GxkDialog
+ * @focus_widget:  valid #GtkWidget
+ *
+ * A #GxkDialog will automatically unset the focus
+ * everytime it is shown, unless @focus_widget is
+ * a valid widget that can be focused each time.
+ */
+void
+gxk_dialog_set_focus (GxkDialog *self,
+		      GtkWidget *focus_widget)
+{
+  g_return_if_fail (GXK_IS_DIALOG (self));
+
+  if (self->focus_widget)
+    g_signal_handlers_disconnect_by_func (self->focus_widget, g_nullify_pointer, &self->focus_widget);
+  self->focus_widget = focus_widget;
+  g_signal_connect_swapped (self->focus_widget, "destroy", G_CALLBACK (g_nullify_pointer), &self->focus_widget);
+}
+
+/**
+ * gxk_dialog_set_default
+ * @dialog:         valid #GxkDialog
+ * @default_widget: valid #GtkWidget
+ *
+ * This function is similar to gxk_dialog_set_focus(),
+ * it just affects the widget taking the default
+ * activation.
+ */
+void
+gxk_dialog_set_default (GxkDialog *self,
+			GtkWidget *default_widget)
+{
+  g_return_if_fail (GXK_IS_DIALOG (self));
+
+  if (self->default_widget)
+    g_signal_handlers_disconnect_by_func (self->default_widget, g_nullify_pointer, &self->default_widget);
+  self->default_widget = default_widget;
+  g_signal_connect_swapped (self->default_widget, "destroy", G_CALLBACK (g_nullify_pointer), &self->default_widget);
 }
 
 static void
 gxk_dialog_show (GtkWidget *widget)
 {
-  GxkDialog *dialog = GXK_DIALOG (widget);
+  GxkDialog *self = GXK_DIALOG (widget);
   
-  if (dialog->flags & GXK_DIALOG_POPUP_POS)
-    g_object_set (dialog, "window_position", GTK_WIN_POS_MOUSE, NULL);
+  if (self->flags & GXK_DIALOG_POPUP_POS)
+    g_object_set (self, "window_position", GTK_WIN_POS_MOUSE, NULL);
   else
-    g_object_set (dialog, "window_position", GTK_WIN_POS_NONE, NULL);
-  
-  gtk_window_set_focus (GTK_WINDOW (dialog), NULL);
-  if (dialog->default_widget)
-    gtk_widget_grab_default (dialog->default_widget);
+    g_object_set (self, "window_position", GTK_WIN_POS_NONE, NULL);
 
-  if (dialog->status_bar &&
+  if (self->focus_widget && GTK_WIDGET_CAN_FOCUS (self->focus_widget) &&
+      gtk_widget_get_toplevel (self->focus_widget) == widget)
+    gtk_window_set_focus (GTK_WINDOW (self), self->focus_widget);
+  else
+    gtk_window_set_focus (GTK_WINDOW (self), NULL);
+  if (self->default_widget)
+    gtk_widget_grab_default (self->default_widget);
+
+  if (self->status_bar &&
       gxk_dialog_get_status_window () == NULL &&
-      !g_slist_find (enter_stack, dialog))
-    enter_stack = g_slist_prepend (enter_stack, dialog);
+      !g_slist_find (enter_stack, self))
+    enter_stack = g_slist_prepend (enter_stack, self);
 
   GTK_WIDGET_CLASS (parent_class)->show (widget);
+
+  gxk_widget_viewable_changed (widget);
+
+  /* GTKFIX: gtk doesn't take away focus from a widget on a hidden notebook page when realizing the window */
+  if (self->focus_widget && !gxk_widget_viewable (self->focus_widget))
+    gtk_window_set_focus (GTK_WINDOW (self), NULL);
 }
 
 static void
 gxk_dialog_hide (GtkWidget *widget)
 {
-  // GxkDialog *dialog = GXK_DIALOG (widget);
+  GxkDialog *self = GXK_DIALOG (widget);
   
   GTK_WIDGET_CLASS (parent_class)->hide (widget);
+
+  gxk_widget_viewable_changed (widget);
+
+  if (!(self->flags & GXK_DIALOG_PRESERVE_STATE))
+    gxk_idle_unrealize_widget (widget);
 }
 
 static gboolean
@@ -476,6 +543,8 @@ gxk_dialog_key_press_event (GtkWidget   *widget,
 			    GdkEventKey *event)
 {
   GxkDialog *dialog = GXK_DIALOG (widget);
+  GtkWindow *window = GTK_WINDOW (widget);
+  gboolean handled = FALSE;
 
   /* decide whether we close the window upon Escape:
    * - we provide Escape as a short cut for the GXK_DIALOG_DELETE_BUTTON
@@ -490,7 +559,44 @@ gxk_dialog_key_press_event (GtkWidget   *widget,
       return TRUE;
     }
 
-  return GTK_WIDGET_CLASS (parent_class)->key_press_event (widget, event);
+#if defined (__linux__)         // FIXME: use gtk_window_activate_key() once exposed
+  /* we're iverriding the GtkWindow implementation here to give
+   * the focus widget precedence over unmodified accelerators
+   * before the accelerator activation scheme.
+   */
+  if (!handled && event->state & ~GDK_SHIFT_MASK)
+    handled = _gtk_window_activate_key (window, event);
+  if (!handled)
+    {
+      GtkWidget *focus = window->focus_widget;
+      if (focus)
+        g_object_ref (focus);
+      while (!handled &&
+             focus && focus != widget &&
+             gtk_widget_get_toplevel (focus) == widget)
+        {
+          GtkWidget *parent;
+          if (GTK_WIDGET_IS_SENSITIVE (focus))
+            handled = gtk_widget_event (focus, (GdkEvent*) event);
+          parent = focus->parent;
+          if (parent)
+            g_object_ref (parent);
+          g_object_unref (focus);
+          focus = parent;
+        }
+      if (focus)
+        g_object_unref (focus);
+    }
+  if (!handled && !(event->state & ~GDK_SHIFT_MASK))
+    handled = _gtk_window_activate_key (window, event);
+  /* chain up bypassing gtk_window_key_press(), invokes binding set */
+  if (!handled)
+    handled = GTK_WIDGET_CLASS (g_type_class_peek (g_type_parent (GTK_TYPE_WINDOW)))->key_press_event (widget, event);
+#else
+  handled = GTK_WIDGET_CLASS (parent_class)->key_press_event (widget, event);
+#endif
+
+  return handled;
 }
 
 static gboolean
@@ -570,7 +676,7 @@ gxk_dialog_remove_actions (GxkDialog *dialog)
  * Add a new (stock) button to a dialog.
  */
 GtkWidget*
-gxk_dialog_action_multi (GxkDialog          *dialog,
+gxk_dialog_action_multi (GxkDialog          *self,
 			 const gchar        *action,
 			 gpointer            callback,
 			 gpointer            data,
@@ -579,26 +685,26 @@ gxk_dialog_action_multi (GxkDialog          *dialog,
 {
   GtkWidget *button = NULL;
 
-  g_return_val_if_fail (GXK_IS_DIALOG (dialog), NULL);
+  g_return_val_if_fail (GXK_IS_DIALOG (self), NULL);
   g_return_val_if_fail (action != NULL, NULL);
 
-  if (dialog->sep)
-    gtk_widget_show (dialog->sep);
-  if (dialog->hbox)
+  if (self->sep)
+    gtk_widget_show (self->sep);
+  if (self->hbox)
     {
-      GtkWidget *alignment, *hbox, *image = icon_stock_id ? gxk_stock_image (icon_stock_id, GXK_SIZE_BUTTON) : NULL;
+      GtkWidget *alignment, *hbox, *image = icon_stock_id ? gxk_stock_image (icon_stock_id, GXK_ICON_SIZE_BUTTON) : NULL;
 
       if (!image)
-	image = gxk_stock_image (action, GXK_SIZE_BUTTON);
+	image = gxk_stock_image (action, GXK_ICON_SIZE_BUTTON);
 
       /* catch installation of a Close button */
       if (strcmp (action, GTK_STOCK_CLOSE) == 0)
-	dialog->flags |= GXK_DIALOG_DELETE_BUTTON;
+	self->flags |= GXK_DIALOG_DELETE_BUTTON;
 
       /* setup button */
       button = g_object_new (GTK_TYPE_BUTTON,
 			     "can_default", TRUE,
-			     "parent", dialog->hbox,
+			     "parent", self->hbox,
 			     NULL);
       if (callback)
 	g_signal_connect_data (button, "clicked",
@@ -614,21 +720,16 @@ gxk_dialog_action_multi (GxkDialog          *dialog,
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
       gtk_box_pack_start (GTK_BOX (hbox),
 			  g_object_new (GTK_TYPE_LABEL,
-					"label", gxk_stock_action (action),
+					"label", gxk_stock_item (action),
 					"use_underline", TRUE,
 					NULL),
 			  FALSE, TRUE, 0);
       gtk_widget_show_all (button);
 
-      gtk_widget_show (dialog->hbox);
+      gtk_widget_show (self->hbox);
 
       if (multi_mode & GXK_DIALOG_MULTI_DEFAULT)
-	{
-	  if (dialog->default_widget)
-	    g_signal_handlers_disconnect_by_func (dialog->default_widget, g_nullify_pointer, &dialog->default_widget);
-	  dialog->default_widget = button;
-	  g_signal_connect_swapped (dialog->default_widget, "destroy", G_CALLBACK (g_nullify_pointer), &dialog->default_widget);
-	}
+	gxk_dialog_set_default (self, button);
     }
   return button;
 }
