@@ -17,6 +17,8 @@
  * Boston, MA 02111-1307, USA.
  */
 #include "gxkutils.h"
+#include "glewidgets.h"
+#include "gxkauxwidgets.h"
 #include "gxkcellrendererpopup.h"
 #include <string.h>
 
@@ -214,6 +216,38 @@ gxk_filename_to_utf8 (const gchar *filename)
   return NULL;
 }
 
+const gchar*
+gxk_factory_path_get_leaf (const gchar *path)
+{
+  const gchar *last = NULL, *p = path;
+  if (!path)
+    return NULL;
+  while (*p)
+    {
+      if (*p == '\\' && p[1])
+        p += 1;
+      else if (*p == '/')
+        last = p + 1;
+      p++;
+    }
+  return last ? last : path;
+}
+
+gchar*
+gxk_factory_path_unescape_uline (const gchar *path)
+{
+  gchar *str = g_strdup (path), *d = str, *p = d;
+  while (*p)
+    {
+      if (*p == '_')
+        p++;
+      *d++ = *p++;
+    }
+  *d = 0;
+  return str;
+}
+
+
 /* --- Gtk+ Utilities --- */
 /**
  * gxk_widget_viewable_changed
@@ -386,6 +420,49 @@ gxk_widget_make_sensitive (GtkWidget *widget)
     gtk_widget_set_sensitive (widget, TRUE);
 }
 
+static gboolean
+idle_showraiser (gpointer data)
+{
+  GtkWidget **widget_p = data;
+  GDK_THREADS_ENTER ();
+  if (GTK_IS_WIDGET (*widget_p))
+    {
+      GtkWidget *widget = *widget_p;
+      gtk_signal_disconnect_by_func (GTK_OBJECT (widget),
+				     GTK_SIGNAL_FUNC (gtk_widget_destroyed),
+				     widget_p);
+      gtk_widget_show (widget);
+      if (GTK_WIDGET_REALIZED (widget) && !widget->parent)
+        gdk_window_raise (widget->window);
+    }
+  g_free (widget_p);
+  GDK_THREADS_LEAVE ();
+  return FALSE;
+}
+
+/**
+ * gxk_idle_showraise
+ * @widget: a valid #GtkWidget
+ *
+ * Defers showing and raising this widget like gxk_widget_showraise()
+ * until the next idle handler is run. This is usefull if other things
+ * are pending which need to be processed first, for instance hiding
+ * other toplevels or constructing remaining parts of the widget hierarchy.
+ */
+void
+gxk_idle_showraise (GtkWidget *widget)
+{
+  GtkWidget **widget_p;
+
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  widget_p = g_new (GtkWidget*, 1);
+
+  *widget_p = widget;
+  g_object_connect (widget, "signal::destroy", gtk_widget_destroyed, widget_p, NULL);
+  gtk_idle_add_priority (GTK_PRIORITY_RESIZE - 1, idle_showraiser, widget_p);
+}
+
 static gint
 idle_shower (GtkWidget **widget_p)
 {
@@ -613,7 +690,7 @@ style_modify_fg_as_sensitive (GtkWidget *widget)
  *
  * Modify the widget and it's style, so that it is insensitive,
  * but doesn't quite look that way. Usefull for inactive title
- * menu items in menus.
+ * menu items in menus (@widget should be the menu item's label).
  */
 void
 gxk_widget_modify_as_title (GtkWidget *widget)
@@ -2057,6 +2134,760 @@ gxk_widget_proxy_requisition (GtkWidget *widget)
   g_signal_connect_after (widget, "size_request", G_CALLBACK (requisition_to_aux_info), NULL);
 }
 
+/**
+ * gxk_widget_has_ancestor
+ * @widget:   valid #GtkWidget
+ * @ancestor: valid #GtkWidget
+ * @RETURNS:  whether @ancestor is ancestor of @widget
+ *
+ * This function checks whether @widget and @ancestor are equal,
+ * or whether @ancestor is an ancestor of @widget, in the same
+ * way gtk_widget_is_ancestor() tests it.
+ */
+gboolean
+gxk_widget_has_ancestor (gpointer widget,
+                         gpointer ancestor)
+{
+  GtkWidget *w = widget, *a = ancestor;
+  g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+  g_return_val_if_fail (GTK_IS_WIDGET (ancestor), FALSE);
+
+  while (w)
+    {
+      if (w == a)
+        return TRUE;
+      w = w->parent;
+    }
+  return FALSE;
+}
+
+/**
+ * gxk_widget_regulate
+ * @widget:    valid #GtkWidget
+ * @sensitive: whether @widget should be sensitive
+ * @active:    whether @widget should be active
+ *
+ * Regulate a widgets state. The @sensitive parameter
+ * controls sensitivity like gtk_widget_set_sensitive()
+ * and @active controls whether the widget is active
+ * like gtk_toggle_button_set_active() or
+ * gtk_check_menu_item_set_active().
+ * For menu items, the menu item is also made the
+ * active widget in its parent menu, possibly affecting
+ * option menus.
+ */
+void
+gxk_widget_regulate (GtkWidget      *widget,
+                     gboolean        sensitive,
+                     gboolean        active)
+{
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+  if (((GObject*) widget)->ref_count > 0)
+    {
+      GParamSpec *pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (widget), "active");
+      g_object_freeze_notify (G_OBJECT (widget));
+      gtk_widget_set_sensitive (widget, sensitive);
+      if (pspec && pspec->value_type == G_TYPE_BOOLEAN)
+        {
+          GValue value = { 0, };
+          g_value_init (&value, G_TYPE_BOOLEAN);
+          g_value_set_boolean (&value, active);
+          g_object_set_property ((GObject*) widget, "active", &value);
+          g_value_unset (&value);
+        }
+      if (active && GTK_IS_MENU_ITEM (widget) && widget->parent && GTK_IS_MENU (widget->parent))
+        {
+          GtkMenu *menu = GTK_MENU (widget->parent);
+          guint nth = g_list_index (GTK_MENU_SHELL (menu)->children, widget);
+          GtkWidget *awidget = gtk_menu_get_attach_widget (menu);
+          gtk_menu_set_active (menu, nth);
+          if (GTK_IS_OPTION_MENU (awidget))
+            gtk_option_menu_set_history (GTK_OPTION_MENU (awidget), nth);
+          if (GXK_IS_MENU_BUTTON (awidget))
+            gxk_menu_button_update (GXK_MENU_BUTTON (awidget));
+        }
+      g_object_thaw_notify (G_OBJECT (widget));
+    }
+}
+
+/**
+ * gxk_widget_regulate_uses_active
+ * @widget:  valid #GtkWidget
+ * @RETURNS: %TRUE if gxk_widget_regulate() uses @active for @widget
+ *
+ * Check whether gxk_widget_regulate() will actually make
+ * use of its @active argument for @widget. If not,
+ * %FALSE is returned, and gxk_widget_regulate() is
+ * fully equivalent to just gtk_widget_set_sensitive().
+ */
+gboolean
+gxk_widget_regulate_uses_active (GtkWidget *widget)
+{
+  GParamSpec *pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (widget), "active");
+  return GTK_IS_MENU_ITEM (widget) || (pspec && pspec->value_type == G_TYPE_BOOLEAN);
+}
+
+/**
+ * gxk_window_get_menu_accel_group
+ * @window:  valid #GtkWindow
+ * @RETURNS: valid #GtkAccelGroup
+ *
+ * This function hands out an accel group for @window
+ * specifically targeted at holding accelerators of
+ * menu items in this window.
+ */
+GtkAccelGroup*
+gxk_window_get_menu_accel_group (GtkWindow *window)
+{
+  GtkAccelGroup *agroup = g_object_get_data (window, "GxkWindow-menu-accel-group");
+  if (!agroup)
+    {
+      agroup = gtk_accel_group_new ();
+      gtk_window_add_accel_group (window, agroup);
+      g_object_set_data_full (window, "GxkWindow-menu-accel-group", agroup, g_object_unref);
+    }
+  return agroup;
+}
+
+static GdkGeometry*
+window_get_geometry (GtkWindow *window)
+{
+  GdkGeometry *geometry = g_object_get_data (window, "gxk-GdkGeometry");
+  if (!geometry)
+    {
+      geometry = g_new0 (GdkGeometry, 1);
+      geometry->width_inc = 1;
+      geometry->height_inc = 1;
+      g_object_set_data_full (window, "gxk-GdkGeometry", geometry, g_free);
+    }
+  return geometry;
+}
+
+void
+gxk_window_set_geometry_min_width (GtkWindow       *window,
+                                   guint            min_width)
+{
+  GdkGeometry *geometry = window_get_geometry (window);
+  if (geometry->min_width != min_width)
+    {
+      geometry->min_width = min_width;
+      gtk_window_set_geometry_hints (GTK_WINDOW (window), NULL, geometry, GDK_HINT_MIN_SIZE | GDK_HINT_RESIZE_INC);
+    }
+}
+
+void
+gxk_window_set_geometry_min_height (GtkWindow       *window,
+                                    guint            min_height)
+{
+  GdkGeometry *geometry = window_get_geometry (window);
+  if (geometry->min_height != min_height)
+    {
+      geometry->min_height = min_height;
+      gtk_window_set_geometry_hints (GTK_WINDOW (window), NULL, geometry, GDK_HINT_MIN_SIZE | GDK_HINT_RESIZE_INC);
+    }
+}
+
+void
+gxk_window_set_geometry_width_inc (GtkWindow       *window,
+                                   guint            width_increment)
+{
+  GdkGeometry *geometry = window_get_geometry (window);
+  if (geometry->width_inc != width_increment)
+    {
+      geometry->width_inc = width_increment;
+      gtk_window_set_geometry_hints (GTK_WINDOW (window), NULL, geometry, GDK_HINT_MIN_SIZE | GDK_HINT_RESIZE_INC);
+    }
+}
+
+void
+gxk_window_set_geometry_height_inc (GtkWindow       *window,
+                                    guint            height_increment)
+{
+  GdkGeometry *geometry = window_get_geometry (window);
+  if (geometry->height_inc != height_increment)
+    {
+      geometry->height_inc = height_increment;
+      gtk_window_set_geometry_hints (GTK_WINDOW (window), NULL, geometry, GDK_HINT_MIN_SIZE | GDK_HINT_RESIZE_INC);
+    }
+}
+
+guint
+gxk_container_get_insertion_slot (GtkContainer *container)
+{
+  guint *slots = g_object_steal_data (container, "gxk-container-slots");
+  guint n_slots = slots ? slots[0] : 0;
+  guint n_children = 0;
+  if (GTK_IS_CONTAINER (container))
+    {
+      GList *children = gtk_container_get_children (container);
+      n_children = g_list_length (children);
+      g_list_free (children);
+    }
+  n_slots++;
+  slots = g_renew (guint, slots, 1 + n_slots);
+  slots[0] = n_slots;
+  slots[n_slots] = n_children;
+  g_object_set_data_full (container, "gxk-container-slots", slots, g_free);
+  return n_slots;
+}
+
+void
+gxk_container_slot_reorder_child (GtkContainer    *container,
+                                  GtkWidget       *widget,
+                                  guint            sloti)
+{
+  guint *slots = g_object_get_data (container, "gxk-container-slots");
+  guint n_slots = slots ? slots[0] : 0;
+  if (sloti && sloti <= n_slots)
+    {
+      guint i;
+      if (GTK_IS_MENU (container))
+        gtk_menu_reorder_child ((GtkMenu*) container, widget, slots[sloti]);
+      else if (GTK_IS_BOX (container))
+        gtk_box_reorder_child ((GtkBox*) container, widget, slots[sloti]);
+      else if (GTK_IS_WRAP_BOX (container))
+        gtk_wrap_box_reorder_child ((GtkWrapBox*) container, widget, slots[sloti]);
+      else
+        return;
+      for (i = sloti; i <= n_slots; i++)
+        slots[i]++;
+    }
+}
+
+/**
+ * gxk_grab_pointer_and_keyboard
+ * @window:       the window receiving the grab
+ * @owner_events: if %TRUE, events will be reported relative to @window
+ * @event_mask:   mask of interesting events
+ * @confine_to:   limits the pointer to the specified window
+ * @cursor:       cursor to use for the duration of the grab
+ * @time:         event time when grab is requested
+ * @RETURNS:      %TRUE if pointer and keyboard could successfully be grabbed
+ *
+ * This function grabs the pointer and keyboard simultaneously.
+ * This is recommended over plain pointer grabs, to reduce the
+ * risk of other applications (for instance the window manager)
+ * aborting the current grab and leaving the application in an
+ * invalid state.
+ */
+gboolean
+gxk_grab_pointer_and_keyboard (GdkWindow    *window,
+                               gboolean      owner_events,
+                               GdkEventMask  event_mask,
+                               GdkWindow    *confine_to,
+                               GdkCursor    *cursor,
+                               guint32       time)
+{
+  if (gdk_pointer_grab (window, owner_events, event_mask, confine_to, cursor, time) == GDK_GRAB_SUCCESS)
+    {
+      if (gdk_keyboard_grab (window, TRUE, time) == GDK_GRAB_SUCCESS)
+        return TRUE;
+      else
+        gdk_display_pointer_ungrab (gdk_drawable_get_display (window), time);
+    }
+  return FALSE;
+}
+
+/**
+ * gxk_ungrab_pointer_and_keyboard
+ * @window: window pointer was previously grabed on
+ *
+ * This function releases a pointer and keyboard grab
+ * acquired through gxk_grab_pointer_and_keyboard().
+ * The @window is used to release grabs on the correct
+ * display, see gdk_display_pointer_ungrab() and
+ * gdk_display_keyboard_ungrab() on this.
+ */
+void
+gxk_ungrab_pointer_and_keyboard (GdkWindow *window,
+                                 guint32    time)
+{
+  GdkDisplay *display = window ? gdk_drawable_get_display (window) : gdk_display_get_default();
+  gdk_display_pointer_ungrab (display, time);
+  gdk_display_keyboard_ungrab (display, time);
+}
+
+/**
+ * gxk_menu_check_sensitive
+ * @menu:    valid #GtkMenu
+ * @RETURNS: TRUE if @menu contains selectable items
+ *
+ * This function tests whether a menu contains
+ * selectable menu items. It can be used to determine
+ * sensitivity for menu items containing submenus.
+ */
+gboolean
+gxk_menu_check_sensitive (GtkMenu *menu)
+{
+  GtkMenuShell *shell = GTK_MENU_SHELL (menu);
+  GList *list;
+  for (list = shell->children; list; list = list->next)
+    {
+      GtkWidget *child = list->data;
+      if (GTK_WIDGET_VISIBLE (child) && GTK_WIDGET_IS_SENSITIVE (child))
+        return TRUE;
+    }
+  return FALSE;
+}
+
+static void
+submenu_check_sensitive (GtkMenu *menu)
+{
+  GtkWidget *widget = gtk_menu_get_attach_widget (menu);
+  if (GTK_IS_MENU_ITEM (widget))
+    gtk_widget_set_sensitive (widget, gxk_menu_check_sensitive (menu));
+}
+
+static void
+menu_refetch_accel_group (GtkMenu *menu)
+{
+  GtkWidget *toplevel = gxk_widget_get_attach_toplevel ((GtkWidget*) menu);
+  if (GTK_IS_WINDOW (toplevel))
+    gtk_menu_set_accel_group (menu, gxk_window_get_menu_accel_group ((GtkWindow*) toplevel));
+}
+
+static void     menu_propagate_hierarchy_changed (GtkMenu *menu);
+
+static void
+menu_item_propagate_hierarchy_changed (GtkMenuItem *menu_item)
+{
+  GtkWidget *menu = menu_item->submenu;
+  if (menu)
+    menu_propagate_hierarchy_changed (GTK_MENU (menu));
+}
+
+/**
+ * gxk_menu_attach_as_submenu
+ * @menu:      valid #GtkMenu
+ * @menu_item: valid #GtkMenuItem
+ *
+ * This function is a replacement for
+ * gtk_menu_item_set_submenu(). It installs
+ * the necessary hooks on the @menu to automatically
+ * update sensitivity of @menu_item in response
+ * to children being deleted or added to the @menu.
+ * The rationality behind this is to avoid empty menus
+ * being presented to the user.
+ * Also, a propagation mechanism is set up, so @menu
+ * and submenus thereof automatically fetch their
+ * accelerator groups via gxk_window_get_menu_accel_group()
+ * from the toplevel window.
+ */
+void
+gxk_menu_attach_as_submenu (GtkMenu     *menu,
+                            GtkMenuItem *menu_item)
+{
+  g_return_if_fail (GTK_IS_MENU (menu));
+  g_return_if_fail (GTK_IS_MENU_ITEM (menu_item));
+
+  gtk_menu_item_set_submenu (menu_item, GTK_WIDGET (menu));
+
+  if (!gxk_signal_handler_pending (menu_item, "hierarchy-changed", G_CALLBACK (menu_item_propagate_hierarchy_changed), NULL))
+    g_signal_connect_after (menu_item, "hierarchy-changed", G_CALLBACK (menu_item_propagate_hierarchy_changed), NULL);
+  menu_item_propagate_hierarchy_changed (menu_item);
+
+  if (!gxk_signal_handler_pending (menu, "parent-set", G_CALLBACK (submenu_check_sensitive), NULL))
+    g_object_connect (menu,
+                      "signal_after::parent-set", submenu_check_sensitive, NULL,
+                      "signal_after::add", submenu_check_sensitive, NULL,
+                      "signal_after::remove", submenu_check_sensitive, NULL,
+                      NULL);
+  submenu_check_sensitive (menu);
+}
+
+static void
+option_menu_propagate_hierarchy_changed (GtkOptionMenu *option_menu)
+{
+  GtkWidget *menu = option_menu->menu;
+  if (menu)
+    menu_propagate_hierarchy_changed (GTK_MENU (menu));
+}
+
+/**
+ * gxk_option_menu_set_menu
+ * @option_menu: valid #GtkOptionMenu
+ * @menu:        valid #GtkMenu
+ *
+ * This function is a replacement for
+ * gtk_option_menu_set_menu(). Similar to
+ * gxk_menu_attach_as_submenu(), it sets up
+ * a propagation mechanism, so @menu
+ * and submenus thereof automatically fetch their
+ * accelerator groups via gxk_window_get_menu_accel_group()
+ * from the toplevel window.
+ */
+void
+gxk_option_menu_set_menu (GtkOptionMenu *option_menu,
+                          GtkMenu       *menu)
+{
+  g_return_if_fail (GTK_IS_OPTION_MENU (option_menu));
+  g_return_if_fail (GTK_IS_MENU (menu));
+
+  gtk_option_menu_set_menu (option_menu, GTK_WIDGET (menu));
+
+  if (!gxk_signal_handler_pending (option_menu, "hierarchy-changed", G_CALLBACK (option_menu_propagate_hierarchy_changed), NULL))
+    g_signal_connect_after (option_menu, "hierarchy-changed", G_CALLBACK (option_menu_propagate_hierarchy_changed), NULL);
+  option_menu_propagate_hierarchy_changed (option_menu);
+}
+
+static void
+menu_propagate_hierarchy_changed (GtkMenu *menu)
+{
+  GList *list;
+  for (list = GTK_MENU_SHELL (menu)->children; list; list = list->next)
+    if (gxk_signal_handler_pending (list->data, "hierarchy-changed",
+                                    G_CALLBACK (menu_item_propagate_hierarchy_changed), NULL))
+      menu_item_propagate_hierarchy_changed (list->data);
+  menu_refetch_accel_group (menu);
+}
+
+static void
+menu_widget_propagate_hierarchy_changed (GtkWidget *widget)
+{
+  GList *menu_list = g_object_get_data (widget, "GxkWidget-popup-menus");
+  for (; menu_list; menu_list = menu_list->next)
+    menu_propagate_hierarchy_changed (menu_list->data);
+}
+
+static void
+popup_menus_detach (gpointer data)
+{
+  GSList *menu_list = data;
+  while (menu_list)
+    {
+      GtkMenu *menu = g_slist_pop_head (&menu_list);
+      if (gtk_menu_get_attach_widget (menu))
+        gtk_menu_detach (menu);
+    }
+}
+
+static void
+popup_menu_detacher (GtkWidget *widget,
+                     GtkMenu   *menu)
+{
+  GList *menu_list = g_object_steal_data (widget, "GxkWidget-popup-menus");
+  GtkMenuDetachFunc mdfunc;
+  if (menu_list)
+    {
+      menu_list = g_list_remove (menu_list, menu);
+      g_object_set_data_full (widget, "GxkWidget-popup-menus", menu_list, popup_menus_detach);
+    }
+  mdfunc = g_object_get_data (menu, "gxk-GtkMenuDetachFunc");
+  if (mdfunc)
+    mdfunc (widget, menu);
+}
+
+/**
+ * gxk_menu_attach_as_popup_with_func
+ * @menu:      valid #GtkMenu
+ * @menu_item: valid #GtkMenuItem
+ * @mdfunc:    a #GtkMenuDetachFunc func as in gtk_menu_attach_to_widget()
+ *
+ * Variant of gxk_menu_attach_as_popup() which preserves the #GtkMenuDetachFunc.
+ */
+void
+gxk_menu_attach_as_popup_with_func (GtkMenu          *menu,
+                                    GtkWidget        *widget,
+                                    GtkMenuDetachFunc mdfunc)
+{
+  GList *menu_list;
+  g_return_if_fail (GTK_IS_MENU (menu));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  menu_list = g_object_steal_data (widget, "GxkWidget-popup-menus");
+  menu_list = g_list_prepend (menu_list, menu);
+  g_object_set_data_full (widget, "GxkWidget-popup-menus", menu_list, popup_menus_detach);
+  g_object_set_data (menu, "gxk-GtkMenuDetachFunc", mdfunc);
+  gtk_menu_attach_to_widget (menu, widget, popup_menu_detacher);
+
+  if (!gxk_signal_handler_pending (widget, "hierarchy-changed", G_CALLBACK (menu_widget_propagate_hierarchy_changed), NULL))
+    g_signal_connect_after (widget, "hierarchy-changed", G_CALLBACK (menu_widget_propagate_hierarchy_changed), NULL);
+  menu_widget_propagate_hierarchy_changed (widget);
+}
+
+/**
+ * gxk_menu_attach_as_popup
+ * @menu:      valid #GtkMenu
+ * @menu_item: valid #GtkMenuItem
+ *
+ * This function is a replacement for gtk_menu_attach_to_widget().
+ * Similar to gxk_menu_attach_as_submenu(), it sets up a propagation
+ * mechanism, so @menu and submenus thereof automatically fetch their
+ * accelerator groups via gxk_window_get_menu_accel_group() from the
+ * toplevel window. In addition, this function allowes
+ * gxk_widget_find_level_ordered() to also consider popup menus
+ * in its search.
+ */
+void
+gxk_menu_attach_as_popup (GtkMenu         *menu,
+                          GtkWidget       *widget)
+{
+  gxk_menu_attach_as_popup_with_func (menu, widget, NULL);
+}
+
+typedef struct {
+  gint     x, y;
+  gboolean push_in;
+} PopupData;
+
+static void
+menu_position_func (GtkMenu  *menu,
+                    gint     *x,
+                    gint     *y,
+                    gboolean *push_in,
+                    gpointer  func_data)
+{
+  PopupData *pdata = func_data;
+  GtkWidget *active = gtk_menu_get_active (menu);
+  *x = pdata->x;
+  *y = pdata->y;
+  *push_in = pdata->push_in && active;
+  if (*push_in)
+    {
+      GList *list;
+      for (list = GTK_MENU_SHELL (menu)->children; list; list = list->next)
+        {
+          GtkWidget *child = list->data;
+          if (active == child)
+            break;
+          else if (GTK_WIDGET_VISIBLE (child))
+            {
+              GtkRequisition requisition;
+              gtk_widget_get_child_requisition (child, &requisition);
+              *y -= requisition.height;
+            }
+        }
+    }
+}
+
+void
+gxk_menu_popup (GtkMenu *menu,
+                gint     x,
+                gint     y,
+                gboolean push_in,
+                guint    mouse_button,
+                guint32  time)
+{
+  PopupData *pdata = g_new0 (PopupData, 1);
+  g_return_if_fail (GTK_IS_MENU (menu));
+  pdata->x = x;
+  pdata->y = y;
+  pdata->push_in = push_in;
+  gtk_menu_popup (menu, NULL, NULL,
+                  menu_position_func, pdata,
+                  mouse_button, time);
+}
+
+static GtkWidget*
+widget_find_level_ordered (GtkWidget   *widget,
+                           const gchar *name)
+{
+  GList *children = g_list_prepend (NULL, widget);
+  while (children)
+    {
+      GList *list, *newlist = NULL;
+      for (list = children; list; list = list->next)
+        {
+          GtkWidget *child = list->data;
+          if (child->name && strcmp (child->name, name) == 0)
+            {
+              g_list_free (children);
+              return child;
+            }
+        }
+      /* none found, search next level */
+      for (list = children; list; list = list->next)
+        {
+          GList *extra_children;
+          widget = list->data;
+          if (GTK_IS_CONTAINER (widget))
+            newlist = g_list_concat (gtk_container_get_children (GTK_CONTAINER (widget)), newlist);
+          if (GTK_IS_MENU_ITEM (widget))
+            {
+              GtkMenuItem *mitem = GTK_MENU_ITEM (widget);
+              if (mitem->submenu)
+                newlist = g_list_prepend (newlist, mitem->submenu);
+            }
+          extra_children = g_object_get_data (widget, "GxkWidget-popup-menus");
+          if (extra_children)
+            newlist = g_list_concat (g_list_copy (extra_children), newlist);
+        }
+      g_list_free (children);
+      children = newlist;
+    }
+  return NULL;
+}
+
+/**
+ * gxk_widget_find_level_ordered
+ * @toplevel: valid #GtkWidget
+ * @name:     name of the widget being looked for
+ * @RETURNS:  a widget named @name or %NULL
+ *
+ * Search for a widget named @name, child of @toplevel.
+ * The search is ordered by looking at all children of
+ * a container before increasing depth.
+ * This function also considers submenus in menu items
+ * "children", as well as popup menus attached via
+ * gxk_menu_attach_as_popup() (not ones attached via
+ * gtk_menu_attach_to_widget() though, since Gtk+ doesn't
+ * store/export the neccessary information).
+ */
+GtkWidget*
+gxk_widget_find_level_ordered (GtkWidget   *toplevel,
+                               const gchar *name)
+{
+  g_return_val_if_fail (GTK_IS_WIDGET (toplevel), NULL);
+  g_return_val_if_fail (name != NULL, NULL);
+
+  return widget_find_level_ordered (toplevel, name);
+}
+
+/**
+ * gxk_widget_get_attach_toplevel
+ * @widget: valid #GtkWidget
+ *
+ * This function returns the topmost container widget
+ * for @widget, much like gtk_widget_get_toplevel().
+ * The only difference is that for menus, not the immediate
+ * parent is returned (the #GtkWindow used to display a
+ * menu) but the tree walk continues on the menu item
+ * using the menu as submenu.
+ * For example, for a window containing a menubar with
+ * submenus, gtk_widget_get_toplevel() invoked on one
+ * of the menu items will return the #GtkWindow widgets
+ * for the corresponding submenus, while
+ * gxk_widget_get_attach_toplevel() will return the
+ * actual #GtkWindow containing the menubar.
+ */
+GtkWidget*
+gxk_widget_get_attach_toplevel (GtkWidget *widget)
+{
+  GtkWidget *parent;
+  do {
+    parent = widget->parent;
+    if (GTK_IS_MENU (widget))
+      parent = gtk_menu_get_attach_widget ((GtkMenu*) widget);
+    widget = parent ? parent : widget;
+  } while (parent);
+  return widget;
+}
+
+static void
+widget_add_font_requisition (GtkWidget      *widget,
+                             GtkRequisition *requisition)
+{
+  PangoContext *context = gtk_widget_get_pango_context (widget);
+  PangoFontMetrics *metrics = pango_context_get_metrics (context, widget->style->font_desc,
+                                                         pango_context_get_language (context));
+  gdouble digit_width = pango_font_metrics_get_approximate_digit_width (metrics);
+  gdouble char_width = pango_font_metrics_get_approximate_char_width (metrics);
+  gdouble points = digit_width * g_object_get_long (widget, "GxkWidget-font-digits") +
+                   char_width * g_object_get_long (widget, "GxkWidget-font-chars");
+  requisition->width += PANGO_PIXELS (points);
+  pango_font_metrics_unref (metrics);
+}
+
+/**
+ * gxk_widget_add_font_requisition
+ * @widget:   valid #GtkWidget
+ * @n_chars:  number of characters to request space for
+ * @n_digits: number of digits to request space for
+ *
+ * This function adds up extra space to the widget size
+ * requisition. The space is an approximation of the space
+ * required by @n_chars characters and @n_digits digits
+ * written with the widgets font.
+ */
+void
+gxk_widget_add_font_requisition (GtkWidget       *widget,
+                                 guint            n_chars,
+                                 guint            n_digits)
+{
+  g_object_set_long (widget, "GxkWidget-font-chars", n_chars);
+  g_object_set_long (widget, "GxkWidget-font-digits", n_digits);
+  if ((n_chars || n_digits) &&
+      !gxk_signal_handler_pending (widget, "size-request", G_CALLBACK (widget_add_font_requisition), NULL))
+    g_signal_connect_after (widget, "size-request", G_CALLBACK (widget_add_font_requisition), NULL);
+  gtk_widget_queue_resize (widget);
+}
+
+/**
+ * gxk_widget_get_options
+ * @widget:   valid #GtkWidget
+ * @RETURNS:  custom options set on the widget
+ *
+ * This function returns the set of custom options
+ * currently set on the widget.
+ */
+const gchar*
+gxk_widget_get_options (gpointer widget)
+{
+  g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
+  return g_object_get_data (widget, "GxkWidget-options");
+}
+
+/**
+ * gxk_widget_add_option
+ * @widget:   valid #GtkWidget
+ * @option:   option to add to widget
+ * @value:    value of @option (currently just "+" and "-" are supported)
+ *
+ * Add/set a custom @option of @widget to a particular @value.
+ * Custom options on widgets are used to attach extra information
+ * to widgets which may be usefull to otherwise disjoint code
+ * portions. The actual options are implemented by means of
+ * g_option_concat(), g_option_check() and g_option_get().
+ */
+void
+gxk_widget_add_option (gpointer         widget,
+                       const gchar     *option,
+                       const gchar     *value)
+{
+  const gchar *options;
+  guint append = 0;
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+  g_return_if_fail (option != NULL && !strchr (option, ':'));
+  g_return_if_fail (value == NULL || !strcmp (value, "-") || !strcmp (value, "+"));
+  options = g_object_get_data (widget, "GxkWidget-options");
+  if (!options)
+    options = "";
+  if (value && strcmp (value, "-") == 0 &&
+      g_option_check (options, option))
+    append = 2;
+  else if ((!value || strcmp (value, "+") == 0) &&
+           !g_option_check (options, option))
+    append = 1;
+  if (append)
+    {
+      guint l = strlen (options);
+      gchar *s = g_strconcat (options,
+                              options[l] == ':' ? "" : ":",
+                              option, /* append >= 1 */
+                              append >= 2 ? value : "",
+                              NULL);
+      g_object_set_data_full (widget, "GxkWidget-options", s, g_free);
+    }
+}
+
+/**
+ * gxk_widget_check_option
+ * @widget:   valid #GtkWidget
+ * @option:   option to check for
+ * @RETURNS:  whether @option is set
+ *
+ * Test whether the custom @option is set on @widget.
+ */
+gboolean
+gxk_widget_check_option (gpointer         widget,
+                         const gchar     *option)
+{
+  const gchar *options;
+  g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+  options = g_object_get_data (widget, "GxkWidget-options");
+  return g_option_check (options, option);
+}
+
 GtkWidget*
 gxk_file_selection_split (GtkFileSelection *fs,
 			  GtkWidget       **bbox_p)
@@ -2148,3 +2979,46 @@ gxk_file_selection_heal (GtkFileSelection *fs)
 
   return main_box;
 }
+
+/* --- zlib support --- */
+#include <zlib.h>
+gchar*
+gxk_zfile_uncompress (guint                uncompressed_size,
+                      const unsigned char *cdata,
+		      guint                cdata_size)
+{
+  uLongf dlen = uncompressed_size;
+  guint len = dlen + 1;
+  guint8 *text = g_malloc (len);
+  gint result;
+  const gchar *err;
+
+  result = uncompress (text, &dlen, cdata, cdata_size);
+  switch (result)
+    {
+    case Z_OK:
+      if (dlen == uncompressed_size)
+	{
+	  err = NULL;
+	  break;
+	}
+      /* fall through */
+    case Z_DATA_ERROR:
+      err = "internal data corruption";
+      break;
+    case Z_MEM_ERROR:
+      err = "out of memory";
+      break;
+    case Z_BUF_ERROR:
+      err = "insufficient buffer size";
+      break;
+    default:
+      err = "unknown error";
+      break;
+    }
+  if (err)
+    g_error ("while decompressing (%p, %u): %s", cdata, cdata_size, err);
+
+  text[dlen] = 0;
+  return text;
+}
