@@ -184,6 +184,31 @@ static GEnumValue bse_midi_event_type_values[] = {
   { BSE_MIDI_SONG_STOP, "BSE_MIDI_SONG_STOP", "song-stop" },
   { BSE_MIDI_ACTIVE_SENSING, "BSE_MIDI_ACTIVE_SENSING", "active-sensing" },
   { BSE_MIDI_SYSTEM_RESET, "BSE_MIDI_SYSTEM_RESET", "system-reset" },
+  { BSE_MIDI_SEQUENCE_NUMBER, "BSE_MIDI_SEQUENCE_NUMBER", "sequence-number" },
+  { BSE_MIDI_TEXT_EVENT, "BSE_MIDI_TEXT_EVENT", "text-event" },
+  { BSE_MIDI_COPYRIGHT_NOTICE, "BSE_MIDI_COPYRIGHT_NOTICE", "copyright-notice" },
+  { BSE_MIDI_TRACK_NAME, "BSE_MIDI_TRACK_NAME", "track-name" },
+  { BSE_MIDI_INSTRUMENT_NAME, "BSE_MIDI_INSTRUMENT_NAME", "instrument-name" },
+  { BSE_MIDI_LYRIC, "BSE_MIDI_LYRIC", "lyric" },
+  { BSE_MIDI_MARKER, "BSE_MIDI_MARKER", "marker" },
+  { BSE_MIDI_CUE_POINT, "BSE_MIDI_CUE_POINT", "cue-point" },
+  { BSE_MIDI_TEXT_EVENT_08, "BSE_MIDI_TEXT_EVENT_08", "text-event-08" },
+  { BSE_MIDI_TEXT_EVENT_09, "BSE_MIDI_TEXT_EVENT_09", "text-event-09" },
+  { BSE_MIDI_TEXT_EVENT_0A, "BSE_MIDI_TEXT_EVENT_0A", "text-event-0a" },
+  { BSE_MIDI_TEXT_EVENT_0B, "BSE_MIDI_TEXT_EVENT_0B", "text-event-0b" },
+  { BSE_MIDI_TEXT_EVENT_0C, "BSE_MIDI_TEXT_EVENT_0C", "text-event-0c" },
+  { BSE_MIDI_TEXT_EVENT_0D, "BSE_MIDI_TEXT_EVENT_0D", "text-event-0d" },
+  { BSE_MIDI_TEXT_EVENT_0E, "BSE_MIDI_TEXT_EVENT_0E", "text-event-0e" },
+  { BSE_MIDI_TEXT_EVENT_0F, "BSE_MIDI_TEXT_EVENT_0F", "text-event-0f" },
+  { BSE_MIDI_CHANNEL_PREFIX, "BSE_MIDI_CHANNEL_PREFIX", "channel-prefix" },
+  { BSE_MIDI_END_OF_TRACK, "BSE_MIDI_END_OF_TRACK", "end-of-track" },
+  { BSE_MIDI_SET_TEMPO, "BSE_MIDI_SET_TEMPO", "set-tempo" },
+  { BSE_MIDI_SMPTE_OFFSET, "BSE_MIDI_SMPTE_OFFSET", "smpte-offset" },
+  { BSE_MIDI_TIME_SIGNATURE, "BSE_MIDI_TIME_SIGNATURE", "time-signature" },
+  { BSE_MIDI_KEY_SIGNATURE, "BSE_MIDI_KEY_SIGNATURE", "key-signature" },
+  { BSE_MIDI_SEQUENCER_SPECIFIC, "BSE_MIDI_SEQUENCER_SPECIFIC", "sequencer-specific" },
+  { BSE_MIDI_MULTI_SYS_EX_START, "BSE_MIDI_MULTI_SYS_EX_START", "multi-sys-ex-start" },
+  { BSE_MIDI_MULTI_SYS_EX_NEXT, "BSE_MIDI_MULTI_SYS_EX_NEXT", "multi-sys-ex-next" },
   { BSE_MIDI_X_CONTINUOUS_CHANGE, "BSE_MIDI_X_CONTINUOUS_CHANGE", "x-continuous-change" },
   { 0, NULL, NULL }
 };
@@ -231,5 +256,20 @@ static GEnumValue bse_standard_osc_wave_type_values[] = {
 };
 
 
+/* --- bsemididecoder.h --- */
+#include	"bsemididecoder.h"
+/* BseMidiDecoderState
+ */
+static GEnumValue bse_midi_decoder_state_values[] = {
+  { BSE_MIDI_DECODER_ZERO, "BSE_MIDI_DECODER_ZERO", "zero" },
+  { BSE_MIDI_DECODER_DELTA_TIME, "BSE_MIDI_DECODER_DELTA_TIME", "delta-time" },
+  { BSE_MIDI_DECODER_EVENT, "BSE_MIDI_DECODER_EVENT", "event" },
+  { BSE_MIDI_DECODER_VLENGTH, "BSE_MIDI_DECODER_VLENGTH", "vlength" },
+  { BSE_MIDI_DECODER_DATA, "BSE_MIDI_DECODER_DATA", "data" },
+  { BSE_MIDI_DECODER_DONE, "BSE_MIDI_DECODER_DONE", "done" },
+  { 0, NULL, NULL }
+};
+
+
 /* Generated data ends here */
 
