@@ -35,9 +35,12 @@ struct _BseExportNode {
   BseExportNode    *next;
   BseExportNodeType ntype;
   const char       *name;
+  const char       *options;
   const char       *category;
-  const guint8     *pixstream;
   const char       *blurb;
+  const char       *authors;
+  const char       *license;
+  const guint8     *pixstream;
   GType             type;
 };
 typedef struct {
