@@ -46,6 +46,10 @@ extern GType BSE_TYPE_ID (BseSSequencerJobType);
 #define BSE_TYPE_STANDARD_OSC_WAVE_TYPE	    (BSE_TYPE_ID (BseStandardOscWaveType))
 extern GType BSE_TYPE_ID (BseStandardOscWaveType);
 
+/* --- bsemididecoder.h --- */
+#define BSE_TYPE_MIDI_DECODER_STATE	    (BSE_TYPE_ID (BseMidiDecoderState))
+extern GType BSE_TYPE_ID (BseMidiDecoderState);
+
 /* Generated data ends here */
 
 
@@ -490,7 +494,7 @@ struct _BseTrackPart {
 struct _BseSongTiming {
   SfiInt tick;
   SfiReal bpm;
-  SfiInt nominator;
+  SfiInt numerator;
   SfiInt denominator;
   SfiInt tpqn;
   SfiInt tpt;
