@@ -21,16 +21,10 @@ trigger_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
  {
 #line 31 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("action", "Action", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 30 "bsejanitor.proc"
-  proc->help = "Trigger an installed user action of this janitor.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 36 "bsejanitor.proc"
  }
 static BseErrorType
@@ -64,16 +58,10 @@ get_script_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 56 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(out_pspecs++)    = sfi_pspec_string ("script_name", "Script Name", NULL,
-			     NULL, SFI_PARAM_DEFAULT);
+			     NULL, SFI_PARAM_STANDARD);
 }
-#line 55 "bsejanitor.proc"
-  proc->help = "Retrieve the script name of this janitor.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 61 "bsejanitor.proc"
  }
 static BseErrorType
@@ -106,16 +94,10 @@ get_proc_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 80 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(out_pspecs++)    = sfi_pspec_string ("proc_name", "Proc Name", NULL,
-			     NULL, SFI_PARAM_DEFAULT);
+			     NULL, SFI_PARAM_STANDARD);
 }
-#line 79 "bsejanitor.proc"
-  proc->help = "Retrieve the procedure name of this janitor.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 85 "bsejanitor.proc"
  }
 static BseErrorType
@@ -148,16 +130,10 @@ n_actions_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
  {
 #line 104 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("n_actions", "N Actions", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 103 "bsejanitor.proc"
-  proc->help = "Retrieve number of user actions of this janitor.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 109 "bsejanitor.proc"
  }
 static BseErrorType
@@ -190,18 +166,12 @@ get_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
  {
 #line 128 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("nth_action", "Nth Action", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("action", "Action", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 127 "bsejanitor.proc"
-  proc->help = "Retrieve an action of this janitor.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 135 "bsejanitor.proc"
  }
 static BseErrorType
@@ -238,18 +208,12 @@ get_action_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 158 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("nth_action", "Nth Action", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("action-name", "Action Name", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 157 "bsejanitor.proc"
-  proc->help = "Retrieve the name of an action of this janitor.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 165 "bsejanitor.proc"
  }
 static BseErrorType
@@ -286,18 +250,12 @@ get_action_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
  {
 #line 188 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("nth_action", "Nth Action", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("action-blurb", "Action Blurb", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 187 "bsejanitor.proc"
-  proc->help = "Retrieve the help string of an action of this janitor.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 195 "bsejanitor.proc"
  }
 static BseErrorType
@@ -334,14 +292,8 @@ kill_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_ps
  {
 #line 218 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
 }
-#line 217 "bsejanitor.proc"
-  proc->help = "Kill a currently running janitor.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 221 "bsejanitor.proc"
  }
 static BseErrorType
@@ -374,20 +326,14 @@ add_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
  {
 #line 240 "bsejanitor.proc"
   *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("action", "Action", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("blurb", "Blurb", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 239 "bsejanitor.proc"
-  proc->help = "Install a user action for script control.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 249 "bsejanitor.proc"
  }
 static BseErrorType
@@ -428,16 +374,10 @@ remove_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 275 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("action", "Action", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 274 "bsejanitor.proc"
-  proc->help = "Remove a previously installed user action from script control.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 280 "bsejanitor.proc"
  }
 static BseErrorType
@@ -476,14 +416,8 @@ bse_janitor_get_specific_setup (BseProcedureClass *proc, GParamSpec **in_pspecs,
  {
 #line 304 "bsejanitor.proc"
   *(out_pspecs++)   = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
 }
-#line 303 "bsejanitor.proc"
-  proc->help = "Retrieve the connection dependant janitor object.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
 #line 307 "bsejanitor.proc"
  }
 static BseErrorType
@@ -514,18 +448,12 @@ set_msg_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out
  {
 #line 325 "bsejanitor.proc"
   *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_genum ("msg_type", "Message Type", NULL,
 				BSE_TYPE_USER_MSG_TYPE, BSE_USER_MSG_INFO,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("message", "Message", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
-#line 324 "bsejanitor.proc"
-  proc->help = "Alter script status message.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
+			    NULL, SFI_PARAM_STANDARD);
 #line 332 "bsejanitor.proc"
 }  }
 static BseErrorType
@@ -573,16 +501,10 @@ progress_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **ou
  {
 #line 365 "bsejanitor.proc"
   *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_real ("progress", "Progress", NULL,
 			  -1, -1, 1.0, 0.1,
-			  SFI_PARAM_DEFAULT);
-#line 364 "bsejanitor.proc"
-  proc->help = "Indicate progress (from 0.0 to 1.0 or -1 for unknown amount).";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
+			  SFI_PARAM_STANDARD);
 #line 370 "bsejanitor.proc"
 }  }
 static BseErrorType
@@ -621,18 +543,12 @@ exit_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_ps
  {
 #line 394 "bsejanitor.proc"
   *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
-				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_JANITOR, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_genum ("msg_type", "Message Type", NULL,
 				BSE_TYPE_USER_MSG_TYPE, BSE_USER_MSG_INFO,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("message", "Message", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
-#line 393 "bsejanitor.proc"
-  proc->help = "Exit a script, leaving a message.";
-#line 25 "bsejanitor.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsejanitor.proc"
-  proc->license = "GNU General Public License";
+			    NULL, SFI_PARAM_STANDARD);
 #line 401 "bsejanitor.proc"
 }  }
 static BseErrorType
@@ -669,72 +585,156 @@ exit_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_trigger_action = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+trigger-action", "/Methods/BseJanitor/General/Trigger Action", NULL },
+    "BseJanitor+trigger-action", 
+    NULL,
+    "/Methods/BseJanitor/General/Trigger Action",
+    "Trigger an installed user action of this janitor.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, trigger_action_setup, trigger_action_exec, 
 };
 static BseExportNodeProc __enode_get_script_name = {
   { (BseExportNode*) &__enode_trigger_action, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+get-script-name", "/Methods/BseJanitor/General/Get Script Name", NULL },
+    "BseJanitor+get-script-name", 
+    NULL,
+    "/Methods/BseJanitor/General/Get Script Name",
+    "Retrieve the script name of this janitor.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_script_name_setup, get_script_name_exec, 
 };
 static BseExportNodeProc __enode_get_proc_name = {
   { (BseExportNode*) &__enode_get_script_name, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+get-proc-name", "/Methods/BseJanitor/General/Get Proc Name", NULL },
+    "BseJanitor+get-proc-name", 
+    NULL,
+    "/Methods/BseJanitor/General/Get Proc Name",
+    "Retrieve the procedure name of this janitor.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_proc_name_setup, get_proc_name_exec, 
 };
 static BseExportNodeProc __enode_n_actions = {
   { (BseExportNode*) &__enode_get_proc_name, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+n-actions", "/Methods/BseJanitor/General/N Actions", NULL },
+    "BseJanitor+n-actions", 
+    NULL,
+    "/Methods/BseJanitor/General/N Actions",
+    "Retrieve number of user actions of this janitor.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, n_actions_setup, n_actions_exec, 
 };
 static BseExportNodeProc __enode_get_action = {
   { (BseExportNode*) &__enode_n_actions, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+get-action", "/Methods/BseJanitor/General/Get Action", NULL },
+    "BseJanitor+get-action", 
+    NULL,
+    "/Methods/BseJanitor/General/Get Action",
+    "Retrieve an action of this janitor.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_action_setup, get_action_exec, 
 };
 static BseExportNodeProc __enode_get_action_name = {
   { (BseExportNode*) &__enode_get_action, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+get-action-name", "/Methods/BseJanitor/General/Get Action Name", NULL },
+    "BseJanitor+get-action-name", 
+    NULL,
+    "/Methods/BseJanitor/General/Get Action Name",
+    "Retrieve the name of an action of this janitor.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_action_name_setup, get_action_name_exec, 
 };
 static BseExportNodeProc __enode_get_action_blurb = {
   { (BseExportNode*) &__enode_get_action_name, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+get-action-blurb", "/Methods/BseJanitor/General/Get Action Blurb", NULL },
+    "BseJanitor+get-action-blurb", 
+    NULL,
+    "/Methods/BseJanitor/General/Get Action Blurb",
+    "Retrieve the help string of an action of this janitor.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_action_blurb_setup, get_action_blurb_exec, 
 };
 static BseExportNodeProc __enode_kill = {
   { (BseExportNode*) &__enode_get_action_blurb, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+kill", "/Methods/BseJanitor/General/Kill", NULL },
+    "BseJanitor+kill", 
+    NULL,
+    "/Methods/BseJanitor/General/Kill",
+    "Kill a currently running janitor.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, kill_setup, kill_exec, 
 };
 static BseExportNodeProc __enode_add_action = {
   { (BseExportNode*) &__enode_kill, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+add-action", "/Methods/BseJanitor/General/Add Action", NULL },
+    "BseJanitor+add-action", 
+    NULL,
+    "/Methods/BseJanitor/General/Add Action",
+    "Install a user action for script control.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, add_action_setup, add_action_exec, 
 };
 static BseExportNodeProc __enode_remove_action = {
   { (BseExportNode*) &__enode_add_action, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+remove-action", "/Methods/BseJanitor/General/Remove Action", NULL },
+    "BseJanitor+remove-action", 
+    NULL,
+    "/Methods/BseJanitor/General/Remove Action",
+    "Remove a previously installed user action from script control.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, remove_action_setup, remove_action_exec, 
 };
 static BseExportNodeProc __enode_bse_janitor_get_specific = {
   { (BseExportNode*) &__enode_remove_action, BSE_EXPORT_NODE_PROC,
-    "bse-janitor-get-specific", "/Proc/Janitor/Get Specific", NULL },
+    "bse-janitor-get-specific", 
+    NULL,
+    "/Proc/Janitor/Get Specific",
+    "Retrieve the connection dependant janitor object.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, bse_janitor_get_specific_setup, bse_janitor_get_specific_exec, 
 };
 static BseExportNodeProc __enode_set_msg = {
   { (BseExportNode*) &__enode_bse_janitor_get_specific, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+set-msg", "/Methods/BseJanitor/General/Set Msg", NULL },
+    "BseJanitor+set-msg", 
+    NULL,
+    "/Methods/BseJanitor/General/Set Msg",
+    "Alter script status message.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, set_msg_setup, set_msg_exec, 
 };
 static BseExportNodeProc __enode_progress = {
   { (BseExportNode*) &__enode_set_msg, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+progress", "/Methods/BseJanitor/General/Progress", NULL },
+    "BseJanitor+progress", 
+    NULL,
+    "/Methods/BseJanitor/General/Progress",
+    "Indicate progress (from 0.0 to 1.0 or -1 for unknown amount).",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, progress_setup, progress_exec, 
 };
 static BseExportNodeProc __enode_exit = {
   { (BseExportNode*) &__enode_progress, BSE_EXPORT_NODE_PROC,
-    "BseJanitor+exit", "/Methods/BseJanitor/General/Exit", NULL },
+    "BseJanitor+exit", 
+    NULL,
+    "/Methods/BseJanitor/General/Exit",
+    "Exit a script, leaving a message.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, exit_setup, exit_exec, 
 };
 BseExportNode* bse__builtin_init_bsejanitor_gen_proc_c (void);
