@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "bsemain.h"
-#include <bse/bseconfig.h>	/* for *_VERSION and *_AGE */
+#include "topconfig.h"
 #include "bseserver.h"
 #include "bsessequencer.h"
 #include "bsejanitor.h"
@@ -40,7 +40,7 @@ static void	bse_async_parse_args	(gint	       *argc_p,
 /* --- variables --- */
 GMainContext            *bse_main_context = NULL;
 SfiMutex	         bse_main_sequencer_mutex = { 0, };
-gboolean	         bse_main_developer_extensions = FALSE;
+gboolean	         bse_main_debug_extensions = FALSE;
 SfiThread               *bse_main_thread = NULL;
 static volatile gboolean bse_initialization_stage = 0;
 /* from bse.h */
@@ -65,17 +65,20 @@ bse_init_async (gint    *argc,
   bse_initialization_stage++;
   if (bse_initialization_stage != 1)
     g_error ("%s() may only be called once", "bse_init_async");
+
+  bindtextdomain (BSE_GETTEXT_DOMAIN, BST_PATH_LOCALE);
+  bind_textdomain_codeset (BSE_GETTEXT_DOMAIN, "UTF-8");
   
   /* this function is running in the user thread and needs to start the main BSE thread */
   
   /* initialize submodules */
   sfi_init ();
   /* paranoid assertions */
-  g_assert (BSE_BYTE_ORDER == BSE_LITTLE_ENDIAN || BSE_BYTE_ORDER == BSE_BIG_ENDIAN);
+  g_assert (G_BYTE_ORDER == G_LITTLE_ENDIAN || G_BYTE_ORDER == G_BIG_ENDIAN);
   /* early argument handling */
   if (argc && argv)
     {
-      if (*argc)
+      if (*argc && !g_get_prgname ())
 	g_set_prgname (**argv);
       bse_async_parse_args (argc, argv, config);
     }
@@ -187,6 +190,8 @@ bse_init_core (void)
   bse_globals_init ();
   _bse_init_categories ();
   bse_type_init ();
+  bse_cxx_init ();
+  bse_cxx_checks ();
   
   /* FIXME: global spawn dir is evil */
   {
@@ -211,7 +216,7 @@ bse_init_core (void)
   
   /* remaining BSE components */
   _bse_midi_init ();
-  bse_plugins_init ();
+  bse_plugin_init_builtins ();
   /* make sure the server is alive */
   bse_server_get ();
 }
@@ -221,25 +226,47 @@ bse_init_intern (gint    *argc,
 		 gchar ***argv,
 		 SfiRec  *config)
 {
+  SfiRec *unref_me = NULL;
   if (bse_initialization_stage != 0)
     g_error ("%s() may only be called once", "bse_init_intern");
   bse_initialization_stage++;
   if (bse_initialization_stage != 1)
     g_error ("%s() may only be called once", "bse_init_intern");
+
+  bindtextdomain (BSE_GETTEXT_DOMAIN, BST_PATH_LOCALE);
+  bind_textdomain_codeset (BSE_GETTEXT_DOMAIN, "UTF-8");
   
   /* initialize submodules */
   sfi_init ();
+  if (!config)
+    config = unref_me = sfi_rec_new();
   /* paranoid assertions */
-  g_assert (BSE_BYTE_ORDER == BSE_LITTLE_ENDIAN || BSE_BYTE_ORDER == BSE_BIG_ENDIAN);
+  g_assert (G_BYTE_ORDER == G_LITTLE_ENDIAN || G_BYTE_ORDER == G_BIG_ENDIAN);
   /* early argument handling */
   if (argc && argv)
     {
-      if (*argc)
+      if (*argc && !g_get_prgname ())
 	g_set_prgname (**argv);
       bse_async_parse_args (argc, argv, config);
     }
   
   bse_init_core ();
+
+  /* initialize core plugins */
+  if (sfi_rec_get_bool (config, "load-core-plugins"))
+    {
+      SfiRing *ring = bse_plugin_path_list_files ();
+      while (ring)
+        {
+          gchar *name = sfi_ring_pop_head (&ring);
+          const char *error = bse_plugin_check_load (name);
+          if (error)
+            sfi_warn ("while loading \"%s\": %s", name, error);
+          g_free (name);
+        }
+    }
+  if (unref_me)
+    sfi_rec_unref (unref_me);
 }
 
 static void
@@ -337,6 +364,6 @@ bse_async_parse_args (gint    *argc_p,
   if (e)
     *argc_p = e;
 
-  if (config && sfi_rec_get_bool (config, "developer-extensions"))
-    bse_main_developer_extensions = TRUE;
+  if (config && sfi_rec_get_bool (config, "debug-extensions"))
+    bse_main_debug_extensions = TRUE;
 }
