@@ -26,24 +26,24 @@
 
 
 /* --- prototypes --- */
-static void	 bse_midi_voice_input_init		(BseMidiVoiceInput	 *self);
-static void	 bse_midi_voice_input_class_init	(BseMidiVoiceInputClass	 *class);
-static void      bse_midi_voice_input_destroy		(BseObject               *object);
-static void	 bse_midi_voice_input_context_create	(BseSource		 *source,
-							 guint			  context_handle,
-							 GslTrans		 *trans);
-static void	 bse_midi_voice_input_context_dismiss	(BseSource		 *source,
-							 guint			  context_handle,
-							 GslTrans		 *trans);
-static void	 bse_midi_voice_switch_init		(BseMidiVoiceSwitch	 *self);
-static void	 bse_midi_voice_switch_class_init	(BseMidiVoiceSwitchClass *class);
-static void      bse_midi_voice_switch_destroy		(BseObject               *object);
-static void	 bse_midi_voice_switch_context_create	(BseSource		 *source,
-							 guint			  context_handle,
-							 GslTrans		 *trans);
-static void	 bse_midi_voice_switch_context_dismiss	(BseSource		 *source,
-							 guint			  context_handle,
-							 GslTrans		 *trans);
+static void bse_midi_voice_input_init             (BseMidiVoiceInput        *self);
+static void bse_midi_voice_input_class_init       (BseMidiVoiceInputClass   *class);
+static void bse_midi_voice_input_dispose          (GObject                  *object);
+static void bse_midi_voice_input_context_create   (BseSource                *source,
+                                                   guint                     context_handle,
+                                                   GslTrans                 *trans);
+static void bse_midi_voice_input_context_dismiss  (BseSource                *source,
+                                                   guint                     context_handle,
+                                                   GslTrans                 *trans);
+static void bse_midi_voice_switch_init            (BseMidiVoiceSwitch       *self);
+static void bse_midi_voice_switch_class_init      (BseMidiVoiceSwitchClass  *class);
+static void bse_midi_voice_switch_dispose         (GObject                  *object);
+static void bse_midi_voice_switch_context_create  (BseSource                *source,
+                                                   guint                     context_handle,
+                                                   GslTrans                 *trans);
+static void bse_midi_voice_switch_context_dismiss (BseSource                *source,
+                                                   guint                     context_handle,
+                                                   GslTrans                 *trans);
 
 
 /* --- variables --- */
@@ -65,7 +65,7 @@ BSE_BUILTIN_TYPE (BseMidiVoiceInput)
     0 /* n_preallocs */,
     (GInstanceInitFunc) bse_midi_voice_input_init,
   };
-
+  
   return bse_type_register_static (BSE_TYPE_SOURCE,
 				   "BseMidiVoiceInput",
 				   "Internal MIDI Voice glue object (input)",
@@ -85,7 +85,7 @@ BSE_BUILTIN_TYPE (BseMidiVoiceSwitch)
     0 /* n_preallocs */,
     (GInstanceInitFunc) bse_midi_voice_switch_init,
   };
-
+  
   return bse_type_register_static (BSE_TYPE_SOURCE,
 				   "BseMidiVoiceSwitch",
 				   "Internal MIDI Voice glue object (switch)",
@@ -95,17 +95,17 @@ BSE_BUILTIN_TYPE (BseMidiVoiceSwitch)
 static void
 bse_midi_voice_input_class_init (BseMidiVoiceInputClass *class)
 {
-  BseObjectClass *object_class = BSE_OBJECT_CLASS (class);
+  GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   BseSourceClass *source_class = BSE_SOURCE_CLASS (class);
   guint channel_id;
   
   voice_input_parent_class = g_type_class_peek_parent (class);
-
-  object_class->destroy = bse_midi_voice_input_destroy;
-
+  
+  gobject_class->dispose = bse_midi_voice_input_dispose;
+  
   source_class->context_create = bse_midi_voice_input_context_create;
   source_class->context_dismiss = bse_midi_voice_input_context_dismiss;
-
+  
   channel_id = bse_source_class_add_ochannel (source_class, "Freq Out", NULL);
   g_assert (channel_id == BSE_MIDI_VOICE_INPUT_OCHANNEL_FREQUENCY);
   channel_id = bse_source_class_add_ochannel (source_class, "Gate Out", NULL);
@@ -119,17 +119,17 @@ bse_midi_voice_input_class_init (BseMidiVoiceInputClass *class)
 static void
 bse_midi_voice_switch_class_init (BseMidiVoiceSwitchClass *class)
 {
-  BseObjectClass *object_class = BSE_OBJECT_CLASS (class);
+  GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   BseSourceClass *source_class = BSE_SOURCE_CLASS (class);
   guint channel_id;
   
   voice_switch_parent_class = g_type_class_peek_parent (class);
-
-  object_class->destroy = bse_midi_voice_switch_destroy;
-
+  
+  gobject_class->dispose = bse_midi_voice_switch_dispose;
+  
   source_class->context_create = bse_midi_voice_switch_context_create;
   source_class->context_dismiss = bse_midi_voice_switch_context_dismiss;
-
+  
   channel_id = bse_source_class_add_ichannel (source_class, "Left In", NULL);
   g_assert (channel_id == BSE_MIDI_VOICE_SWITCH_ICHANNEL_LEFT);
   channel_id = bse_source_class_add_ichannel (source_class, "Right In", NULL);
@@ -155,57 +155,42 @@ bse_midi_voice_switch_init (BseMidiVoiceSwitch *self)
 }
 
 void
-bse_midi_voice_input_set_midi_receiver (BseMidiVoiceInput *self,
-					BseMidiReceiver   *midi_receiver,
-					guint              midi_channel)
+bse_midi_voice_input_set_voice_switch (BseMidiVoiceInput  *self,
+				       BseMidiVoiceSwitch *voice_switch)
 {
   g_return_if_fail (BSE_IS_MIDI_VOICE_INPUT (self));
   g_return_if_fail (!BSE_SOURCE_PREPARED (self));
+  if (voice_switch)
+    g_return_if_fail (BSE_IS_MIDI_VOICE_SWITCH (voice_switch));
 
-  if (self->midi_receiver)
-    bse_midi_receiver_unref (self->midi_receiver);
-  self->midi_receiver = midi_receiver;
-  self->midi_channel = midi_channel;
-  if (self->midi_receiver)
-    bse_midi_receiver_ref (self->midi_receiver);
-}
-
-void
-bse_midi_voice_switch_set_voice_input (BseMidiVoiceSwitch *self,
-				       BseMidiVoiceInput  *voice_input)
-{
-  g_return_if_fail (BSE_IS_MIDI_VOICE_SWITCH (self));
-  g_return_if_fail (!BSE_SOURCE_PREPARED (self));
-  if (voice_input)
-    g_return_if_fail (BSE_IS_MIDI_VOICE_INPUT (voice_input));
-
-  if (self->voice_input)
-    g_object_unref (self->voice_input);
-  self->voice_input = voice_input;
-  if (self->voice_input)
-    g_object_ref (self->voice_input);
+  if (self->voice_switch)
+    g_object_unref (self->voice_switch);
+  self->voice_switch = voice_switch;
+  if (self->voice_switch)
+    g_object_ref (self->voice_switch);
 }
 
 static void
-bse_midi_voice_input_destroy (BseObject *object)
+bse_midi_voice_input_dispose (GObject *object)
 {
   BseMidiVoiceInput *self = BSE_MIDI_VOICE_INPUT (object);
-
-  bse_midi_voice_input_set_midi_receiver (self, NULL, 0);
-
-  /* chain parent class' destroy handler */
-  BSE_OBJECT_CLASS (voice_input_parent_class)->destroy (object);
+  
+  bse_midi_voice_input_set_voice_switch (self, NULL);
+  
+  /* chain parent class' handler */
+  G_OBJECT_CLASS (voice_input_parent_class)->dispose (object);
 }
 
 static void
-bse_midi_voice_switch_destroy (BseObject *object)
+bse_midi_voice_switch_dispose (GObject *object)
 {
   BseMidiVoiceSwitch *self = BSE_MIDI_VOICE_SWITCH (object);
 
-  bse_midi_voice_switch_set_voice_input (self, NULL);
-
-  /* chain parent class' destroy handler */
-  BSE_OBJECT_CLASS (voice_switch_parent_class)->destroy (object);
+  if (self->midi_voices)
+    g_warning ("disposing voice-switch with active midi voices");
+  
+  /* chain parent class' handler */
+  G_OBJECT_CLASS (voice_switch_parent_class)->dispose (object);
 }
 
 static void
@@ -214,50 +199,27 @@ bse_midi_voice_input_context_create (BseSource *source,
 				     GslTrans  *trans)
 {
   BseMidiVoiceInput *self = BSE_MIDI_VOICE_INPUT (source);
-  BseMidiReceiver *midi_receiver;
-  guint voice;
-
-  bse_midi_voice_input_ref_midi_voice (self, context_handle,
-				       &midi_receiver, &voice, trans);
+  BseMidiContext mcontext = bse_midi_voice_switch_ref_poly_voice (self->voice_switch, context_handle, trans);
+  // FIXME: handle no voice-switch
 
   /* we simply wrap the module from BseMidiReceiver */
   bse_source_set_context_omodule (source, context_handle,
-				  bse_midi_receiver_get_note_module (midi_receiver, voice));
+				  bse_midi_receiver_create_sub_voice (mcontext.midi_receiver,
+                                                                      mcontext.midi_channel,
+                                                                      mcontext.voice_id, trans));
 
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (voice_input_parent_class)->context_create (source, context_handle, trans);
 }
 
-static void
-bse_midi_voice_switch_context_create (BseSource *source,
-				     guint      context_handle,
-				     GslTrans  *trans)
-{
-  BseMidiVoiceSwitch *self = BSE_MIDI_VOICE_SWITCH (source);
-  BseMidiReceiver *midi_receiver;
-  guint voice;
-
-  g_return_if_fail (self->voice_input != NULL);
-
-  bse_midi_voice_input_ref_midi_voice (self->voice_input, context_handle,
-				       &midi_receiver, &voice, trans);
-
-  /* we simply wrap the modules from BseMidiReceiver */
-  bse_source_set_context_imodule (source, context_handle,
-				  bse_midi_receiver_get_input_module (midi_receiver, voice));
-  bse_source_set_context_omodule (source, context_handle,
-				  bse_midi_receiver_get_output_module (midi_receiver, voice));
-
-  /* chain parent class' handler */
-  BSE_SOURCE_CLASS (voice_switch_parent_class)->context_create (source, context_handle, trans);
-}
-
 static void
 bse_midi_voice_input_context_dismiss (BseSource *source,
 				      guint      context_handle,
 				      GslTrans  *trans)
 {
   BseMidiVoiceInput *self = BSE_MIDI_VOICE_INPUT (source);
+  BseMidiContext mcontext = bse_midi_voice_switch_peek_poly_voice (self->voice_switch, context_handle);
+  GslModule *module;
 
   /* the GslModule isn't ours, so theoretically we would just need
    * to disconnect and not discard it.
@@ -266,119 +228,166 @@ bse_midi_voice_input_context_dismiss (BseSource *source,
    * BseSource to discard the foreign module.
    */
 
+  module = bse_source_get_context_omodule (source, context_handle);
+  bse_midi_receiver_discard_sub_voice (mcontext.midi_receiver, mcontext.midi_channel, mcontext.voice_id, module, trans);
   bse_source_set_context_omodule (source, context_handle, NULL);
-
-  bse_midi_voice_input_unref_midi_voice (self, context_handle, trans);
+  
+  bse_midi_voice_switch_unref_poly_voice (self->voice_switch, context_handle, trans);
 
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (voice_input_parent_class)->context_dismiss (source, context_handle, trans);
 }
 
 static void
-bse_midi_voice_switch_context_dismiss (BseSource *source,
+bse_midi_voice_switch_context_create (BseSource *source,
 				      guint      context_handle,
 				      GslTrans  *trans)
 {
   BseMidiVoiceSwitch *self = BSE_MIDI_VOICE_SWITCH (source);
+  BseMidiContext mcontext = bse_midi_voice_switch_ref_poly_voice (self, context_handle, trans);
 
-  g_return_if_fail (self->voice_input != NULL);
+  /* we simply wrap the modules from BseMidiReceiver */
+  bse_source_set_context_imodule (source, context_handle,
+                                  bse_midi_receiver_get_poly_voice_input (mcontext.midi_receiver,
+                                                                          mcontext.midi_channel, mcontext.voice_id));
+  bse_source_set_context_omodule (source, context_handle,
+				  bse_midi_receiver_get_poly_voice_output (mcontext.midi_receiver,
+                                                                           mcontext.midi_channel, mcontext.voice_id));
+  
+  /* chain parent class' handler */
+  BSE_SOURCE_CLASS (voice_switch_parent_class)->context_create (source, context_handle, trans);
+}
 
+static void
+bse_midi_voice_switch_context_dismiss (BseSource *source,
+				       guint      context_handle,
+				       GslTrans  *trans)
+{
+  BseMidiVoiceSwitch *self = BSE_MIDI_VOICE_SWITCH (source);
+  
   /* the GslModules aren't ours, so we need to disconnect the input module
    * and prevent discarding the modules.
    */
-
+  
   gsl_trans_add (trans, gsl_job_kill_inputs (bse_source_get_context_imodule (source, context_handle)));
   bse_source_set_context_imodule (source, context_handle, NULL);
   bse_source_set_context_omodule (source, context_handle, NULL);
-
-  bse_midi_voice_input_unref_midi_voice (self->voice_input, context_handle, trans);
-
+  
+  bse_midi_voice_switch_unref_poly_voice (self, context_handle, trans);
+  
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (voice_switch_parent_class)->context_dismiss (source, context_handle, trans);
 }
 
+void
+bse_midi_voice_switch_set_midi_channel (BseMidiVoiceSwitch *self,
+                                        guint               midi_channel)
+{
+  g_return_if_fail (BSE_IS_MIDI_VOICE_SWITCH (self));
+  g_return_if_fail (!BSE_SOURCE_PREPARED (self));
+  
+  self->midi_channel = midi_channel;
+}
+
 typedef struct {
   guint		   context_handle;
   guint		   ref_count;
-  BseMidiReceiver *midi_receiver;
-  guint            voice;
+  guint            voice_id;
 } MidiVoice;
 
-void
-bse_midi_voice_input_ref_midi_voice (BseMidiVoiceInput *self,
-				     guint              context_handle,
-				     BseMidiReceiver  **midi_receiver_p,
-				     guint             *voice_p,
-				     GslTrans	       *trans)
+BseMidiContext
+bse_midi_voice_switch_ref_poly_voice (BseMidiVoiceSwitch     *self,
+                                      guint                   context_handle,
+                                      GslTrans               *trans)
 {
-  GslRing *ring;
+  BseMidiContext mcontext = { 0, };
   MidiVoice *mvoice;
+  GSList *slist;
 
-  g_return_if_fail (BSE_IS_MIDI_VOICE_INPUT (self));
-  g_return_if_fail (BSE_SOURCE_PREPARED (self));
-  g_return_if_fail (midi_receiver_p && voice_p);
-  g_return_if_fail (trans != NULL);
+  g_return_val_if_fail (BSE_IS_MIDI_VOICE_SWITCH (self), mcontext);
+  g_return_val_if_fail (BSE_SOURCE_PREPARED (self), mcontext);
+  g_return_val_if_fail (trans != NULL, mcontext);
 
-  for (ring = self->midi_voices; ring; ring = gsl_ring_walk (self->midi_voices, ring))
+  mcontext = bse_snet_get_midi_context (BSE_SNET (BSE_ITEM (self)->parent), context_handle);
+  mcontext.midi_channel = self->midi_channel;
+  for (slist = self->midi_voices; slist; slist = slist->next)
     {
-      mvoice = ring->data;
+      mvoice = slist->data;
       if (mvoice->context_handle == context_handle)
 	break;
     }
-  if (!ring)
+  if (!slist)
     {
-      guint midi_channel;
-      mvoice = gsl_new_struct (MidiVoice, 1);
+      mvoice = sfi_new_struct (MidiVoice, 1);
       mvoice->context_handle = context_handle;
       mvoice->ref_count = 1;
-      if (self->midi_receiver)
-	{
-	  mvoice->midi_receiver = bse_midi_receiver_ref (self->midi_receiver);
-	  midi_channel = self->midi_channel;
-	}
-      else
-	mvoice->midi_receiver = bse_midi_receiver_ref (bse_snet_get_midi_receiver (BSE_SNET (BSE_ITEM (self)->parent),
-										   context_handle, &midi_channel));
-      mvoice->voice = bse_midi_receiver_create_voice (mvoice->midi_receiver, midi_channel, trans);
-      self->midi_voices = gsl_ring_prepend (self->midi_voices, mvoice);
+      mvoice->voice_id = bse_midi_receiver_create_poly_voice (mcontext.midi_receiver, mcontext.midi_channel, trans);
+      self->midi_voices = g_slist_prepend (self->midi_voices, mvoice);
     }
   else
     mvoice->ref_count++;
-  *midi_receiver_p = mvoice->midi_receiver;
-  *voice_p = mvoice->voice;
+  mcontext.voice_id = mvoice->voice_id;
+  return mcontext;
 }
 
-void
-bse_midi_voice_input_unref_midi_voice (BseMidiVoiceInput *self,
-				       guint              context_handle,
-				       GslTrans		 *trans)
+BseMidiContext
+bse_midi_voice_switch_peek_poly_voice (BseMidiVoiceSwitch     *self,
+                                       guint                   context_handle)
 {
-  GslRing *ring;
+  BseMidiContext mcontext = { 0, };
   MidiVoice *mvoice;
+  GSList *slist;
 
-  g_return_if_fail (BSE_IS_MIDI_VOICE_INPUT (self));
-  g_return_if_fail (BSE_SOURCE_PREPARED (self));
-  g_return_if_fail (trans != NULL);
+  g_return_val_if_fail (BSE_IS_MIDI_VOICE_SWITCH (self), mcontext);
+  g_return_val_if_fail (BSE_SOURCE_PREPARED (self), mcontext);
 
-  for (ring = self->midi_voices; ring; ring = gsl_ring_walk (self->midi_voices, ring))
+  for (slist = self->midi_voices; slist; slist = slist->next)
     {
-      mvoice = ring->data;
+      mvoice = slist->data;
       if (mvoice->context_handle == context_handle)
 	break;
     }
-  if (!ring)
+  if (slist)
+    {
+      mcontext = bse_snet_get_midi_context (BSE_SNET (BSE_ITEM (self)->parent), context_handle);
+      mcontext.midi_channel = self->midi_channel;
+      mcontext.voice_id = mvoice->voice_id;
+    }
+  return mcontext;
+}
+
+void
+bse_midi_voice_switch_unref_poly_voice (BseMidiVoiceSwitch *self,
+                                        guint               context_handle,
+                                        GslTrans           *trans)
+{
+  BseMidiContext mcontext;
+  MidiVoice *mvoice;
+  GSList *slist;
+
+  g_return_if_fail (BSE_IS_MIDI_VOICE_SWITCH (self));
+  g_return_if_fail (BSE_SOURCE_PREPARED (self));
+  g_return_if_fail (trans != NULL);
+
+  mcontext = bse_snet_get_midi_context (BSE_SNET (BSE_ITEM (self)->parent), context_handle);
+  mcontext.midi_channel = self->midi_channel;
+  for (slist = self->midi_voices; slist; slist = slist->next)
+    {
+      mvoice = slist->data;
+      if (mvoice->context_handle == context_handle)
+	break;
+    }
+  if (!slist)
     g_warning ("module %s has no midi voice for context %u",
-	       bse_object_debug_name (self),
-	       context_handle);
+	       bse_object_debug_name (self), context_handle);
   else
     {
       mvoice->ref_count--;
       if (!mvoice->ref_count)
 	{
-	  self->midi_voices = gsl_ring_remove_node (self->midi_voices, ring);
-	  bse_midi_receiver_discard_voice (mvoice->midi_receiver, mvoice->voice, trans);
-	  bse_midi_receiver_unref (mvoice->midi_receiver);
-	  gsl_delete_struct (MidiVoice, mvoice);
+          self->midi_voices = g_slist_remove (self->midi_voices, mvoice);
+	  bse_midi_receiver_discard_poly_voice (mcontext.midi_receiver, mcontext.midi_channel, mvoice->voice_id, trans);
+	  sfi_delete_struct (MidiVoice, mvoice);
 	}
     }
 }
