@@ -1,5 +1,5 @@
 /* BSE - Bedevilled Sound Engine
- * Copyright (C) 1997-1999, 2000-2002 Tim Janik
+ * Copyright (C) 1997-1999, 2000-2003 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,8 +58,9 @@ static void		bse_object_do_set_uname		(BseObject	*object,
 							 const gchar	*uname);
 static void		bse_object_store_private	(BseObject	*object,
 							 BseStorage	*storage);
-static BseTokenType	bse_object_restore_private	(BseObject     *object,
-							 BseStorage    *storage);
+static SfiTokenType	bse_object_restore_private	(BseObject     *object,
+							 BseStorage    *storage,
+                                                         GScanner      *scanner);
 static BseIcon*		bse_object_do_get_icon		(BseObject	*object);
 static guint		eclosure_hash			(gconstpointer	 c);
 static gint		eclosure_equals			(gconstpointer	 c1,
@@ -95,52 +96,10 @@ BSE_BUILTIN_TYPE (BseObject)
     (GInstanceInitFunc) bse_object_init,
   };
   
-  return bse_type_register_static (G_TYPE_OBJECT,
-				   "BseObject",
-				   "BSE Object Hierarchy base type",
-				   &object_info);
-}
-
-void
-bse_object_complete_info (const BseExportSpec *spec,
-			  GTypeInfo	    *info)
-{
-  const BseExportObject *ospec = &spec->s_object;
-  
-  *info = *ospec->object_info;
-}
-
-const gchar*
-bse_object_type_register (const gchar *name,
-			  const gchar *parent_name,
-			  const gchar *blurb,
-			  BsePlugin   *plugin,
-			  GType	      *ret_type)
-{
-  GType	  type;
-  
-  g_return_val_if_fail (ret_type != NULL, bse_error_blurb (BSE_ERROR_INTERNAL));
-  *ret_type = 0;
-  g_return_val_if_fail (name != NULL, bse_error_blurb (BSE_ERROR_INTERNAL));
-  g_return_val_if_fail (parent_name != NULL, bse_error_blurb (BSE_ERROR_INTERNAL));
-  g_return_val_if_fail (plugin != NULL, bse_error_blurb (BSE_ERROR_INTERNAL));
-  
-  type = g_type_from_name (name);
-  if (type)
-    return "Object already registered";
-  type = g_type_from_name (parent_name);
-  if (!type)
-    return "Parent type unknown";
-  if (!BSE_TYPE_IS_OBJECT (type))
-    return "Parent type is non-object type";
-  
-  type = bse_type_register_dynamic (type,
-				    name,
-				    blurb,
-				    plugin);
-  *ret_type = type;
-  
-  return NULL;
+  return bse_type_register_abstract (G_TYPE_OBJECT,
+                                     "BseObject",
+                                     "BSE Object Hierarchy base type",
+                                     &object_info);
 }
 
 static void
@@ -183,7 +142,7 @@ bse_object_class_init (BseObjectClass *class)
 			      PROP_UNAME,
 			      sfi_pspec_string ("uname", "Name", "Unique name of this object",
 						NULL,
-						SFI_PARAM_GUI SFI_PARAM_LAX_VALIDATION
+						SFI_PARAM_GUI ":lax-validation"
 						/* watch out, unames are specially
 						 * treated within the various
 						 * objects, specifically BseItem
@@ -193,7 +152,7 @@ bse_object_class_init (BseObjectClass *class)
 			      PROP_BLURB,
 			      sfi_pspec_string ("blurb", "Comment", NULL,
 						NULL,
-						SFI_PARAM_DEFAULT));
+						SFI_PARAM_STANDARD ":skip-default"));
   
   object_signals[SIGNAL_RELEASE] = bse_object_class_add_signal (class, "release",
 								G_TYPE_NONE, 0);
@@ -351,6 +310,9 @@ bse_object_do_set_property (GObject      *gobject,
 		  *p++ = '?';
 		  p = strchr (p, ':');
 		}
+              /* initial character must be >= \007 */
+              if (string[0] > 0 && string[0] < 7)
+                string[0] = '_';
 	    }
 	  BSE_OBJECT_GET_CLASS (object)->set_uname (object, string);
 	  g_free (string);
@@ -393,6 +355,18 @@ bse_object_do_get_property (GObject     *gobject,
     }
 }
 
+void
+bse_object_class_add_grouped_property (BseObjectClass *class,
+                                       guint	       property_id,
+                                       GParamSpec     *pspec)
+{
+  g_return_if_fail (BSE_IS_OBJECT_CLASS (class));
+  g_return_if_fail (G_IS_PARAM_SPEC (pspec));
+  g_return_if_fail (property_id > 0);
+  
+  g_object_class_install_property (G_OBJECT_CLASS (class), property_id, pspec);
+}
+
 void
 bse_object_class_add_property (BseObjectClass *class,
 			       const gchar    *property_group,
@@ -402,10 +376,9 @@ bse_object_class_add_property (BseObjectClass *class,
   g_return_if_fail (BSE_IS_OBJECT_CLASS (class));
   g_return_if_fail (G_IS_PARAM_SPEC (pspec));
   g_return_if_fail (sfi_pspec_get_group (pspec) == NULL);
-  g_return_if_fail (property_id > 0);
   
   sfi_pspec_set_group (pspec, property_group);
-  g_object_class_install_property (G_OBJECT_CLASS (class), property_id, pspec);
+  bse_object_class_add_grouped_property (class, property_id, pspec);
 }
 
 static void
@@ -681,11 +654,12 @@ bse_object_store_private (BseObject	*object,
 {
 }
 
-static BseTokenType
+static SfiTokenType
 bse_object_restore_private (BseObject  *object,
-			    BseStorage *storage)
+			    BseStorage *storage,
+                            GScanner   *scanner)
 {
-  return BSE_TOKEN_UNMATCHED;
+  return SFI_TOKEN_UNMATCHED;
 }
 
 typedef struct {
@@ -734,7 +708,10 @@ eclosure_marshal (GClosure       *closure,
 		  gpointer        marshal_data)
 {
   EClosure *e = (EClosure*) closure;
-  g_signal_emit (e->closure.data, e->dest_signal, e->dest_detail);
+  if (e->dest_signal)
+    g_signal_emit (e->closure.data, e->dest_signal, e->dest_detail);
+  else
+    g_object_notify (e->closure.data, g_quark_to_string (e->dest_detail));
 }
 
 void
@@ -744,8 +721,8 @@ bse_object_reemit_signal (gpointer     src_object,
 			  const gchar *dest_signal)
 {
   EClosure key;
-  if (g_signal_parse_name (dest_signal, G_OBJECT_TYPE (dest_object), &key.dest_signal, &key.dest_detail, TRUE) &&
-      g_signal_parse_name (src_signal, G_OBJECT_TYPE (src_object), &key.src_signal, &key.src_detail, TRUE))
+  if (g_signal_parse_name (src_signal, G_OBJECT_TYPE (src_object), &key.src_signal, &key.src_detail, TRUE) &&
+      g_signal_parse_name (dest_signal, G_OBJECT_TYPE (dest_object), &key.dest_signal, &key.dest_detail, TRUE))
     {
       EClosure *e;
       key.closure.data = dest_object;
@@ -754,12 +731,14 @@ bse_object_reemit_signal (gpointer     src_object,
       if (!e)
 	{
 	  GSignalQuery query;
+          gboolean property_notify = key.dest_detail && strncmp (dest_signal, "notify", 6) == 0;
 	  g_signal_query (key.dest_signal, &query);
 	  if (!(query.return_type == G_TYPE_NONE &&
-		query.n_params == 0 &&
-		(query.signal_flags & G_SIGNAL_ACTION ||
-		 strcmp (query.signal_name, "notify") == 0 ||
-		 strncmp (query.signal_name, "notify::", 8) == 0)))
+		((query.n_params == 0 &&
+                  query.signal_flags & G_SIGNAL_ACTION) ||
+		 (property_notify &&
+                  g_object_class_find_property (G_OBJECT_GET_CLASS (dest_object),
+                                                g_quark_to_string (key.dest_detail))))))
 	    {
 	      g_warning ("%s: invalid signal for reemission: \"%s\"", G_STRLOC, dest_signal);
 	      return;
@@ -768,7 +747,7 @@ bse_object_reemit_signal (gpointer     src_object,
 	  e->erefs = 1;
 	  e->closure.data = dest_object;
 	  e->src_object = src_object;
-	  e->dest_signal = key.dest_signal;
+	  e->dest_signal = property_notify ? 0 : key.dest_signal;
 	  e->dest_detail = key.dest_detail;
 	  e->src_signal = key.src_signal;
 	  e->src_detail = key.src_detail;
@@ -798,9 +777,11 @@ bse_object_remove_reemit (gpointer     src_object,
   if (g_signal_parse_name (dest_signal, G_OBJECT_TYPE (dest_object), &key.dest_signal, &key.dest_detail, TRUE) &&
       g_signal_parse_name (src_signal, G_OBJECT_TYPE (src_object), &key.src_signal, &key.src_detail, TRUE))
     {
+      gboolean property_notify = key.dest_detail && strncmp (dest_signal, "notify", 6) == 0;
       EClosure *e;
       key.closure.data = dest_object;
       key.src_object = src_object;
+      key.dest_signal = property_notify ? 0 : key.dest_signal;
       e = g_hash_table_lookup (eclosures_ht, &key);
       if (e)
 	{
@@ -819,7 +800,7 @@ bse_object_remove_reemit (gpointer     src_object,
 	    }
 	}
       else
-	g_warning ("%s: no reemission for object \"%s\" signal \"%s\" to object \"%s\" signal \"%s\"",
+	g_warning ("%s: no reemission for object %s signal \"%s\" to object %s signal \"%s\"",
 		   G_STRLOC, bse_object_debug_name (src_object), src_signal,
 		   bse_object_debug_name (dest_object), dest_signal);
     }
