@@ -115,20 +115,20 @@ bse_pcm_input_class_init (BsePcmInputClass *class)
 					      bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB),
 					      0, bse_dB_to_factor (BSE_MAX_VOLUME_dB),
 					      0.1,
-					      SFI_PARAM_STORAGE));
+					      SFI_PARAM_STORAGE ":skip-default")); // FIXME: don't skip-default
   bse_object_class_add_param (object_class, "Adjustments",
 			      PARAM_MVOLUME_dB,
 			      sfi_pspec_real ("gain_volume_dB", "Input Gain [dB]", NULL,
 					      BSE_DFL_MASTER_VOLUME_dB,
 					      BSE_MIN_VOLUME_dB, BSE_MAX_VOLUME_dB,
 					      BSE_GCONFIG (step_volume_dB),
-					      SFI_PARAM_GUI SFI_PARAM_HINT_DIAL));
+					      SFI_PARAM_GUI ":dial"));
   bse_object_class_add_param (object_class, "Adjustments",
 			      PARAM_MVOLUME_PERC,
 			      sfi_pspec_int ("gain_volume_perc", "input Gain [%]", NULL,
 					     bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB) * 100,
 					     0, bse_dB_to_factor (BSE_MAX_VOLUME_dB) * 100,
-					     1, SFI_PARAM_GUI SFI_PARAM_HINT_DIAL));
+					     1, SFI_PARAM_GUI ":dial"));
   
   ochannel_id = bse_source_class_add_ochannel (source_class, "Left Audio Out", "Left channel output");
   g_assert (ochannel_id == BSE_PCM_INPUT_OCHANNEL_LEFT);
