@@ -76,17 +76,17 @@ BsePlugin*	bse_plugin_lookup		(const gchar	*name);
   static BseExportIdentity __bse_export_identity =                                      \
                              BSE_EXPORT_IDENTITY (BSE_PLUGIN_NAME, __enode_chain_head); \
   BseExportIdentity *const BSE_EXPORT_IDENTITY_SYMBOL = &__bse_export_identity
-#define BSE_REGISTER_OBJECT_P(PREV,ObjectType,ParentType,category,pix,blurb,cinit,cfina,iinit) \
+#define BSE_REGISTER_OBJECT_P(PREV,ObjectType,ParentType,category,blurb,pix,cinit,cfina,iinit) \
   static BseExportNodeClass __enode_ ## ObjectType = {                                  \
-    { PREV, BSE_EXPORT_NODE_CLASS, #ObjectType, category, pix, blurb },                 \
+    { PREV, BSE_EXPORT_NODE_CLASS, #ObjectType, NULL, category, blurb, NULL, NULL, pix }, \
     #ParentType, sizeof (ObjectType ## Class), (GClassInitFunc) cinit,                  \
     (GClassFinalizeFunc) cfina, sizeof (ObjectType), (GInstanceInitFunc) iinit,         \
   };                                                                                    \
   static BseExportNode __enode_chain_head = {                                           \
     (BseExportNode*) &__enode_ ## ObjectType, BSE_EXPORT_NODE_LINK,                     \
   }
-#define BSE_REGISTER_OBJECT(ObjectType,ParentType,category,pix,blurb,cinit,cfina,iinit) \
-  BSE_REGISTER_OBJECT_P (NULL, ObjectType, ParentType, category, pix, blurb, cinit, cfina, iinit)
+#define BSE_REGISTER_OBJECT(ObjectType,ParentType,category,blurb,pix,cinit,cfina,iinit) \
+  BSE_REGISTER_OBJECT_P (NULL, ObjectType, ParentType, category, blurb, pix, cinit, cfina, iinit)
 #define BSE_EXPORT_TYPE_ID(EType)       (__enode_ ## EType . node.type)
 
 
