@@ -29,18 +29,12 @@ use_new_project_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 39 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Project Name", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++) = bse_param_spec_object ("project", "Project", NULL,
-				 BSE_TYPE_PROJECT, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_PROJECT, SFI_PARAM_STANDARD);
 }
-#line 38 "bseserver.proc"
-  proc->help = "Create a new project, owned by the caller (name is modified to be unique if necessary)";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 46 "bseserver.proc"
  }
 static BseErrorType
@@ -93,16 +87,10 @@ get_midi_notifier_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParam
  {
 #line 83 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = bse_param_spec_object ("midi_notifier", "Midi Notifier", NULL,
-				 BSE_TYPE_MIDI_NOTIFIER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_MIDI_NOTIFIER, SFI_PARAM_STANDARD);
 }
-#line 82 "bseserver.proc"
-  proc->help = "Retrieve the global midi notifier object.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 88 "bseserver.proc"
  }
 static BseErrorType
@@ -148,18 +136,12 @@ can_load_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **ou
  {
 #line 120 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("file_name", "File Name", "The file to find a loader for",
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_bool ("can-load", NULL, NULL,
-			  FALSE, SFI_PARAM_DEFAULT);
+			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 119 "bseserver.proc"
-  proc->help = "Check whether a loader can be found for a wave file";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 127 "bseserver.proc"
  }
 static BseErrorType
@@ -197,18 +179,12 @@ describe_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 151 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(in_pspecs++)    = bse_pspec_note_simple ("note", "Note", NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = bse_pspec_note_simple ("note", "Note", NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_fine_tune ("fine_tune", "Fine Tune", NULL);
   *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
-			 BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_DEFAULT);
+                                BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
 }
-#line 150 "bseserver.proc"
-  proc->help = "Describe a note, providing information about its octave, semitone, frequency, etc.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 158 "bseserver.proc"
  }
 static BseErrorType
@@ -243,20 +219,14 @@ note_from_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
  {
 #line 179 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_real ("freq", "Frequency", NULL,
 			  BSE_KAMMER_FREQUENCY_f,
 			  0, BSE_MAX_FREQUENCY_f,
-			  10.0, SFI_PARAM_DEFAULT);
+			  10.0, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
-			 BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_DEFAULT);
+                                BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
 }
-#line 178 "bseserver.proc"
-  proc->help = "Describe a note, given its frequency.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 188 "bseserver.proc"
  }
 static BseErrorType
@@ -292,18 +262,12 @@ note_from_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
  {
 #line 210 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("name", "Name", NULL,
-			    "", SFI_PARAM_DEFAULT);
+			    "", SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
-			 BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_DEFAULT);
+                                BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
 }
-#line 209 "bseserver.proc"
-  proc->help = "Describe a note, given its name and octave offset.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 217 "bseserver.proc"
  }
 static BseErrorType
@@ -339,21 +303,15 @@ construct_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
  {
 #line 239 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("semitone", NULL, NULL,
 			 9, 0, 11, 1,
-			 SFI_PARAM_DEFAULT);
+			 SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_octave ("octave", NULL, NULL);
   *(in_pspecs++)    = bse_param_spec_fine_tune ("fine_tune", "Fine Tune", NULL);
   *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
-			 BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_DEFAULT);
+                                BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
 }
-#line 238 "bseserver.proc"
-  proc->help = "Describe a note, given its semitone, octave and fine tune.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 249 "bseserver.proc"
  }
 static BseErrorType
@@ -391,17 +349,11 @@ n_scripts_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
  {
 #line 273 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("n_connections", NULL, "Number of Connections",
 			 0, 0, G_MAXINT, 1,
-			 SFI_PARAM_DEFAULT);
+			 SFI_PARAM_STANDARD);
 }
-#line 272 "bseserver.proc"
-  proc->help = "Return the number of scripts currently running on this server.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 279 "bseserver.proc"
  }
 static BseErrorType
@@ -442,16 +394,10 @@ preferences_locked_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPara
  {
 #line 305 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_bool ("locked", NULL, NULL,
-			  FALSE, SFI_PARAM_DEFAULT);
+			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 304 "bseserver.proc"
-  proc->help = "Returns whether the bse-preferences property is currently locked against modifications or not.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 310 "bseserver.proc"
  }
 static BseErrorType
@@ -503,14 +449,14 @@ register_scripts (gpointer data)
   ScriptRegistration *scr = g_object_get_data (server, "script-registration-queue");
   BseJanitor *janitor = NULL;
   BseErrorType error;
-
+  
   if (!scr)
     {
       bse_server_registration (server, BSE_REGISTER_DONE, NULL, NULL);
       return FALSE;
     }
   g_object_set_data (server, "script-registration-queue", scr->next);
-
+  
   error = scr->register_func (scr->script, &janitor);
   if (!janitor)
     bse_server_registration (server, BSE_REGISTER_SCRIPT, scr->script, bse_error_blurb (error));
@@ -528,14 +474,8 @@ register_scripts_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
  {
 #line 373 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 372 "bseserver.proc"
-  proc->help = "Register external scripts.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 376 "bseserver.proc"
  }
 static BseErrorType
@@ -551,19 +491,19 @@ register_scripts_exec (BseProcedureClass *proc,
   BseServer *server	       = bse_value_get_object (in_values++);
   ScriptRegistration *scr_list = NULL;
   SfiRing *ring;
-
+  
 #line 386 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
-
+  
   if (registration_done)
     {
       bse_server_registration (server, BSE_REGISTER_DONE, NULL, NULL);
       return BSE_ERROR_NONE;
     }
   registration_done = TRUE;
-
+  
   ring = bse_script_path_list_files ();
   while (ring)
     {
@@ -573,10 +513,10 @@ register_scripts_exec (BseProcedureClass *proc,
       scr->next = scr_list;
       scr_list = scr;
     }
-
+  
   g_object_set_data (server, "script-registration-queue", scr_list);
   bse_idle_normal (register_scripts, server);
-
+  
   return BSE_ERROR_NONE;
 }
 
@@ -586,7 +526,7 @@ register_core_plugins (gpointer data)
   BseServer *server = data;
   SfiRing *plugins = g_object_get_data (server, "plugin-registration-queue");
   const gchar *error;
-
+  
   if (plugins)
     {
       gchar *name = sfi_ring_pop_head (&plugins);
@@ -610,14 +550,8 @@ register_core_plugins_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GP
  {
 #line 438 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 437 "bseserver.proc"
-  proc->help = "Register core plugins.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 441 "bseserver.proc"
  }
 static BseErrorType
@@ -632,24 +566,24 @@ register_core_plugins_exec (BseProcedureClass *proc,
   
   BseServer *server	= bse_value_get_object (in_values++);
   SfiRing *ring;
-
+  
 #line 450 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
-
+  
   if (registration_done)
     {
       bse_server_registration (server, BSE_REGISTER_DONE, NULL, NULL);
       return BSE_ERROR_NONE;
     }
   registration_done = TRUE;
-
+  
   ring = bse_plugin_path_list_files ();
   g_object_set_data (server, "plugin-registration-queue", ring);
-
+  
   bse_idle_normal (register_core_plugins, server);
-
+  
   return BSE_ERROR_NONE;
 }
 
@@ -659,14 +593,14 @@ register_ladspa_plugins (gpointer data)
   BseServer *server = data;
   SfiRing *lplugins = g_object_get_data (server, "ladspa-registration-queue");
   const gchar *error;
-
+  
   if (g_object_get_data (server, "plugin-registration-queue"))
     {
 #line 478 "bseserver.proc"
       
       return TRUE;
     }
-
+  
   if (lplugins)
     {
       gchar *name = sfi_ring_pop_head (&lplugins);
@@ -690,14 +624,8 @@ register_ladspa_plugins_setup (BseProcedureClass *proc, GParamSpec **in_pspecs,
  {
 #line 500 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 499 "bseserver.proc"
-  proc->help = "Register LADSPA (Linux Audio Developer's Simple Plugin API) plugins.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 503 "bseserver.proc"
  }
 static BseErrorType
@@ -712,24 +640,24 @@ register_ladspa_plugins_exec (BseProcedureClass *proc,
   
   BseServer *server	= bse_value_get_object (in_values++);
   SfiRing *ring;
-
+  
 #line 512 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
-
+  
   if (registration_done)
     {
       bse_server_registration (server, BSE_REGISTER_DONE, NULL, NULL);
       return BSE_ERROR_NONE;
     }
   registration_done = TRUE;
-
+  
   ring = bse_ladspa_plugin_path_list_files ();
   g_object_set_data (server, "ladspa-registration-queue", ring);
-
+  
   bse_idle_normal (register_ladspa_plugins, server);
-
+  
   return BSE_ERROR_NONE;
 }
 
@@ -745,14 +673,8 @@ save_preferences_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
  {
 #line 538 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 537 "bseserver.proc"
-  proc->help = "Request the bse-preferences property to be saved into BSE's configuration file.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 541 "bseserver.proc"
  }
 static BseErrorType
@@ -775,7 +697,7 @@ save_preferences_exec (BseProcedureClass *proc,
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
-
+  
   file_name = g_strconcat (g_get_home_dir (), "/.bserc", NULL);
   fd = open (file_name,
 #line 559 "bseserver.proc"
@@ -784,10 +706,10 @@ save_preferences_exec (BseProcedureClass *proc,
   g_free (file_name);
   if (fd < 0)
     return BSE_ERROR_NONE;
-
+  
   wstore = sfi_wstore_new ();
   sfi_wstore_printf (wstore, "; rc-file for BSE v%s\n", BSE_VERSION);
-
+  
 #line 568 "bseserver.proc"
   
   sfi_wstore_puts (wstore, "\n; BseGConfig Dump\n");
@@ -797,13 +719,13 @@ save_preferences_exec (BseProcedureClass *proc,
   sfi_value_free (value);
   sfi_rec_unref (rec);
   sfi_wstore_puts (wstore, "\n");
-
+  
 #line 577 "bseserver.proc"
   
   sfi_wstore_flush_fd (wstore, fd);
   sfi_wstore_destroy (wstore);
   close (fd);
-
+  
   return BSE_ERROR_NONE;
 }
 
@@ -814,15 +736,9 @@ get_version_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec *
  {
 #line 587 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("version", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("version", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 586 "bseserver.proc"
-  proc->help = "Retrieve BSE version.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 591 "bseserver.proc"
  }
 static BseErrorType
@@ -843,15 +759,9 @@ get_demo_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 601 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 600 "bseserver.proc"
-  proc->help = "Retrieve demo search path.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 605 "bseserver.proc"
  }
 static BseErrorType
@@ -872,15 +782,9 @@ get_sample_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 615 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 614 "bseserver.proc"
-  proc->help = "Retrieve sample search path.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 619 "bseserver.proc"
  }
 static BseErrorType
@@ -901,15 +805,9 @@ get_custom_effect_dir_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GP
  {
 #line 629 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("directory", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("directory", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 628 "bseserver.proc"
-  proc->help = "Retrieve user specific effects directory.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 633 "bseserver.proc"
  }
 static BseErrorType
@@ -932,15 +830,9 @@ get_effect_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 645 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 644 "bseserver.proc"
-  proc->help = "Retrieve effect search path.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 649 "bseserver.proc"
  }
 static BseErrorType
@@ -961,15 +853,9 @@ get_custom_instrument_dir_setup (BseProcedureClass *proc, GParamSpec **in_pspecs
  {
 #line 659 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("directory", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("directory", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 658 "bseserver.proc"
-  proc->help = "Retrieve user specific instruments directory.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 663 "bseserver.proc"
  }
 static BseErrorType
@@ -992,15 +878,9 @@ get_instrument_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPar
  {
 #line 675 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 674 "bseserver.proc"
-  proc->help = "Retrieve instrument search path.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 679 "bseserver.proc"
  }
 static BseErrorType
@@ -1021,15 +901,9 @@ get_script_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 689 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 688 "bseserver.proc"
-  proc->help = "Retrieve script search path.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 693 "bseserver.proc"
  }
 static BseErrorType
@@ -1050,15 +924,9 @@ get_plugin_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 703 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 702 "bseserver.proc"
-  proc->help = "Retrieve plugin search path.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 707 "bseserver.proc"
  }
 static BseErrorType
@@ -1079,15 +947,9 @@ get_ladspa_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 717 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 716 "bseserver.proc"
-  proc->help = "Retrieve ladspa search path.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 721 "bseserver.proc"
  }
 static BseErrorType
@@ -1110,15 +972,9 @@ get_mp3_version_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 733 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_string ("version", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("version", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 732 "bseserver.proc"
-  proc->help = "Retrieve BSE MP3 handler version.";
-#line 33 "bseserver.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 34 "bseserver.proc"
-  proc->license = "GNU General Public License";
 #line 737 "bseserver.proc"
  }
 static BseErrorType
@@ -1137,122 +993,266 @@ get_mp3_version_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_use_new_project = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseServer+use-new-project", "/Methods/BseServer/General/Use New Project", NULL },
+    "BseServer+use-new-project", 
+    NULL,
+    "/Methods/BseServer/General/Use New Project",
+    "Create a new project, owned by the caller (name is modified to be unique if necessary)",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, use_new_project_setup, use_new_project_exec, 
 };
 static BseExportNodeProc __enode_get_midi_notifier = {
   { (BseExportNode*) &__enode_use_new_project, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-midi-notifier", "/Methods/BseServer/General/Get Midi Notifier", NULL },
+    "BseServer+get-midi-notifier", 
+    NULL,
+    "/Methods/BseServer/General/Get Midi Notifier",
+    "Retrieve the global midi notifier object.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_midi_notifier_setup, get_midi_notifier_exec, 
 };
 static BseExportNodeProc __enode_can_load = {
   { (BseExportNode*) &__enode_get_midi_notifier, BSE_EXPORT_NODE_PROC,
-    "BseServer+can-load", "/Methods/BseServer/General/Can Load", NULL },
+    "BseServer+can-load", 
+    NULL,
+    "/Methods/BseServer/General/Can Load",
+    "Check whether a loader can be found for a wave file",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, can_load_setup, can_load_exec, 
 };
 static BseExportNodeProc __enode_describe_note = {
   { (BseExportNode*) &__enode_can_load, BSE_EXPORT_NODE_PROC,
-    "BseServer+describe-note", "/Methods/BseServer/General/Describe Note", NULL },
+    "BseServer+describe-note", 
+    NULL,
+    "/Methods/BseServer/General/Describe Note",
+    "Describe a note, providing information about its octave, semitone, frequency, etc.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, describe_note_setup, describe_note_exec, 
 };
 static BseExportNodeProc __enode_note_from_freq = {
   { (BseExportNode*) &__enode_describe_note, BSE_EXPORT_NODE_PROC,
-    "BseServer+note-from-freq", "/Methods/BseServer/General/Note From Freq", NULL },
+    "BseServer+note-from-freq", 
+    NULL,
+    "/Methods/BseServer/General/Note From Freq",
+    "Describe a note, given its frequency.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, note_from_freq_setup, note_from_freq_exec, 
 };
 static BseExportNodeProc __enode_note_from_string = {
   { (BseExportNode*) &__enode_note_from_freq, BSE_EXPORT_NODE_PROC,
-    "BseServer+note-from-string", "/Methods/BseServer/General/Note From String", NULL },
+    "BseServer+note-from-string", 
+    NULL,
+    "/Methods/BseServer/General/Note From String",
+    "Describe a note, given its name and octave offset.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, note_from_string_setup, note_from_string_exec, 
 };
 static BseExportNodeProc __enode_construct_note = {
   { (BseExportNode*) &__enode_note_from_string, BSE_EXPORT_NODE_PROC,
-    "BseServer+construct-note", "/Methods/BseServer/General/Construct Note", NULL },
+    "BseServer+construct-note", 
+    NULL,
+    "/Methods/BseServer/General/Construct Note",
+    "Describe a note, given its semitone, octave and fine tune.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, construct_note_setup, construct_note_exec, 
 };
 static BseExportNodeProc __enode_n_scripts = {
   { (BseExportNode*) &__enode_construct_note, BSE_EXPORT_NODE_PROC,
-    "BseServer+n-scripts", "/Methods/BseServer/General/N Scripts", NULL },
+    "BseServer+n-scripts", 
+    NULL,
+    "/Methods/BseServer/General/N Scripts",
+    "Return the number of scripts currently running on this server.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, n_scripts_setup, n_scripts_exec, 
 };
 static BseExportNodeProc __enode_preferences_locked = {
   { (BseExportNode*) &__enode_n_scripts, BSE_EXPORT_NODE_PROC,
-    "BseServer+preferences-locked", "/Methods/BseServer/General/Preferences Locked", NULL },
+    "BseServer+preferences-locked", 
+    NULL,
+    "/Methods/BseServer/General/Preferences Locked",
+    "Returns whether the bse-preferences property is currently locked against modifications or not.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, preferences_locked_setup, preferences_locked_exec, 
 };
 static BseExportNodeProc __enode_register_scripts = {
   { (BseExportNode*) &__enode_preferences_locked, BSE_EXPORT_NODE_PROC,
-    "BseServer+register-scripts", "/Methods/BseServer/General/Register Scripts", NULL },
+    "BseServer+register-scripts", 
+    NULL,
+    "/Methods/BseServer/General/Register Scripts",
+    "Register external scripts.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, register_scripts_setup, register_scripts_exec, 
 };
 static BseExportNodeProc __enode_register_core_plugins = {
   { (BseExportNode*) &__enode_register_scripts, BSE_EXPORT_NODE_PROC,
-    "BseServer+register-core-plugins", "/Methods/BseServer/General/Register Core Plugins", NULL },
+    "BseServer+register-core-plugins", 
+    NULL,
+    "/Methods/BseServer/General/Register Core Plugins",
+    "Register core plugins.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, register_core_plugins_setup, register_core_plugins_exec, 
 };
 static BseExportNodeProc __enode_register_ladspa_plugins = {
   { (BseExportNode*) &__enode_register_core_plugins, BSE_EXPORT_NODE_PROC,
-    "BseServer+register-ladspa-plugins", "/Methods/BseServer/General/Register Ladspa Plugins", NULL },
+    "BseServer+register-ladspa-plugins", 
+    NULL,
+    "/Methods/BseServer/General/Register Ladspa Plugins",
+    "Register LADSPA (Linux Audio Developer's Simple Plugin API) plugins.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, register_ladspa_plugins_setup, register_ladspa_plugins_exec, 
 };
 static BseExportNodeProc __enode_save_preferences = {
   { (BseExportNode*) &__enode_register_ladspa_plugins, BSE_EXPORT_NODE_PROC,
-    "BseServer+save-preferences", "/Methods/BseServer/General/Save Preferences", NULL },
+    "BseServer+save-preferences", 
+    NULL,
+    "/Methods/BseServer/General/Save Preferences",
+    "Request the bse-preferences property to be saved into BSE's configuration file.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, save_preferences_setup, save_preferences_exec, 
 };
 static BseExportNodeProc __enode_get_version = {
   { (BseExportNode*) &__enode_save_preferences, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-version", "/Methods/BseServer/General/Get Version", NULL },
+    "BseServer+get-version", 
+    NULL,
+    "/Methods/BseServer/General/Get Version",
+    "Retrieve BSE version.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_version_setup, get_version_exec, 
 };
 static BseExportNodeProc __enode_get_demo_path = {
   { (BseExportNode*) &__enode_get_version, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-demo-path", "/Methods/BseServer/General/Get Demo Path", NULL },
+    "BseServer+get-demo-path", 
+    NULL,
+    "/Methods/BseServer/General/Get Demo Path",
+    "Retrieve demo search path.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_demo_path_setup, get_demo_path_exec, 
 };
 static BseExportNodeProc __enode_get_sample_path = {
   { (BseExportNode*) &__enode_get_demo_path, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-sample-path", "/Methods/BseServer/General/Get Sample Path", NULL },
+    "BseServer+get-sample-path", 
+    NULL,
+    "/Methods/BseServer/General/Get Sample Path",
+    "Retrieve sample search path.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_sample_path_setup, get_sample_path_exec, 
 };
 static BseExportNodeProc __enode_get_custom_effect_dir = {
   { (BseExportNode*) &__enode_get_sample_path, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-custom-effect-dir", "/Methods/BseServer/General/Get Custom Effect Dir", NULL },
+    "BseServer+get-custom-effect-dir", 
+    NULL,
+    "/Methods/BseServer/General/Get Custom Effect Dir",
+    "Retrieve user specific effects directory.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_custom_effect_dir_setup, get_custom_effect_dir_exec, 
 };
 static BseExportNodeProc __enode_get_effect_path = {
   { (BseExportNode*) &__enode_get_custom_effect_dir, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-effect-path", "/Methods/BseServer/General/Get Effect Path", NULL },
+    "BseServer+get-effect-path", 
+    NULL,
+    "/Methods/BseServer/General/Get Effect Path",
+    "Retrieve effect search path.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_effect_path_setup, get_effect_path_exec, 
 };
 static BseExportNodeProc __enode_get_custom_instrument_dir = {
   { (BseExportNode*) &__enode_get_effect_path, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-custom-instrument-dir", "/Methods/BseServer/General/Get Custom Instrument Dir", NULL },
+    "BseServer+get-custom-instrument-dir", 
+    NULL,
+    "/Methods/BseServer/General/Get Custom Instrument Dir",
+    "Retrieve user specific instruments directory.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_custom_instrument_dir_setup, get_custom_instrument_dir_exec, 
 };
 static BseExportNodeProc __enode_get_instrument_path = {
   { (BseExportNode*) &__enode_get_custom_instrument_dir, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-instrument-path", "/Methods/BseServer/General/Get Instrument Path", NULL },
+    "BseServer+get-instrument-path", 
+    NULL,
+    "/Methods/BseServer/General/Get Instrument Path",
+    "Retrieve instrument search path.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_instrument_path_setup, get_instrument_path_exec, 
 };
 static BseExportNodeProc __enode_get_script_path = {
   { (BseExportNode*) &__enode_get_instrument_path, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-script-path", "/Methods/BseServer/General/Get Script Path", NULL },
+    "BseServer+get-script-path", 
+    NULL,
+    "/Methods/BseServer/General/Get Script Path",
+    "Retrieve script search path.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_script_path_setup, get_script_path_exec, 
 };
 static BseExportNodeProc __enode_get_plugin_path = {
   { (BseExportNode*) &__enode_get_script_path, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-plugin-path", "/Methods/BseServer/General/Get Plugin Path", NULL },
+    "BseServer+get-plugin-path", 
+    NULL,
+    "/Methods/BseServer/General/Get Plugin Path",
+    "Retrieve plugin search path.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_plugin_path_setup, get_plugin_path_exec, 
 };
 static BseExportNodeProc __enode_get_ladspa_path = {
   { (BseExportNode*) &__enode_get_plugin_path, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-ladspa-path", "/Methods/BseServer/General/Get Ladspa Path", NULL },
+    "BseServer+get-ladspa-path", 
+    NULL,
+    "/Methods/BseServer/General/Get Ladspa Path",
+    "Retrieve ladspa search path.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_ladspa_path_setup, get_ladspa_path_exec, 
 };
 static BseExportNodeProc __enode_get_mp3_version = {
   { (BseExportNode*) &__enode_get_ladspa_path, BSE_EXPORT_NODE_PROC,
-    "BseServer+get-mp3-version", "/Methods/BseServer/General/Get Mp3 Version", NULL },
+    "BseServer+get-mp3-version", 
+    NULL,
+    "/Methods/BseServer/General/Get Mp3 Version",
+    "Retrieve BSE MP3 handler version.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_mp3_version_setup, get_mp3_version_exec, 
 };
 BseExportNode* bse__builtin_init_bseserver_gen_proc_c (void);
