@@ -20,15 +20,9 @@ supports_user_synths_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPa
  {
 #line 31 "bsesnet.proc"
   *(in_pspecs++) = bse_param_spec_object ("snet", "Synth Net", NULL,
-				 BSE_TYPE_SNET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SNET, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_bool ("user_synth", "User Synth", NULL,
-			  FALSE, SFI_PARAM_DEFAULT);
-#line 30 "bsesnet.proc"
-  proc->help = "Check whether users may edit synthesis modules of this network";
-#line 25 "bsesnet.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsesnet.proc"
-  proc->license = "GNU Lesser General Public License";
+			  FALSE, SFI_PARAM_STANDARD);
 #line 35 "bsesnet.proc"
 }  }
 static BseErrorType
@@ -61,18 +55,12 @@ can_create_source_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParam
  {
 #line 54 "bsesnet.proc"
   *(in_pspecs++) = bse_param_spec_object ("snet", "Synth Net", NULL,
-				 BSE_TYPE_SNET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SNET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("module_type", "Module Type", NULL,
-			    "", SFI_PARAM_DEFAULT);
+			    "", SFI_PARAM_STANDARD);
   *(out_pspecs++) = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, 0,
-				SFI_PARAM_DEFAULT);
-#line 53 "bsesnet.proc"
-  proc->help = "Check whether inserting a new module into a synthesis network is possible";
-#line 25 "bsesnet.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsesnet.proc"
-  proc->license = "GNU Lesser General Public License";
+				SFI_PARAM_STANDARD);
 #line 61 "bsesnet.proc"
 }  }
 static BseErrorType
@@ -116,17 +104,11 @@ create_source_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 90 "bsesnet.proc"
   *(in_pspecs++) = bse_param_spec_object ("snet", "Synth Net", NULL,
-				 BSE_TYPE_SNET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SNET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("module_type", "Module Type", NULL,
-			    "", SFI_PARAM_DEFAULT);
+			    "", SFI_PARAM_STANDARD);
   *(out_pspecs++) = bse_param_spec_object ("module", "New Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
-#line 89 "bsesnet.proc"
-  proc->help = "Insert a new module into a synthesis network";
-#line 25 "bsesnet.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsesnet.proc"
-  proc->license = "GNU Lesser General Public License";
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
 #line 96 "bsesnet.proc"
 }  }
 static BseErrorType
@@ -173,18 +155,12 @@ remove_source_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 128 "bsesnet.proc"
   *(in_pspecs++) = bse_param_spec_object ("snet", "Synth Net", NULL,
-				 BSE_TYPE_SNET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SNET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, 0,
-				SFI_PARAM_DEFAULT);
-#line 127 "bsesnet.proc"
-  proc->help = "Remove an existing module from its synthesis network";
-#line 25 "bsesnet.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 26 "bsesnet.proc"
-  proc->license = "GNU Lesser General Public License";
+				SFI_PARAM_STANDARD);
 #line 135 "bsesnet.proc"
 }  }
 static BseErrorType
@@ -233,22 +209,46 @@ remove_source_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_supports_user_synths = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseSNet+supports-user-synths", "/Methods/BseSNet/General/Supports User Synths", NULL },
+    "BseSNet+supports-user-synths", 
+    NULL,
+    "/Methods/BseSNet/General/Supports User Synths",
+    "Check whether users may edit synthesis modules of this network",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, supports_user_synths_setup, supports_user_synths_exec, 
 };
 static BseExportNodeProc __enode_can_create_source = {
   { (BseExportNode*) &__enode_supports_user_synths, BSE_EXPORT_NODE_PROC,
-    "BseSNet+can-create-source", "/Methods/BseSNet/General/Can Create Source", NULL },
+    "BseSNet+can-create-source", 
+    NULL,
+    "/Methods/BseSNet/General/Can Create Source",
+    "Check whether inserting a new module into a synthesis network is possible",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, can_create_source_setup, can_create_source_exec, 
 };
 static BseExportNodeProc __enode_create_source = {
   { (BseExportNode*) &__enode_can_create_source, BSE_EXPORT_NODE_PROC,
-    "BseSNet+create-source", "/Methods/BseSNet/General/Create Source", NULL },
+    "BseSNet+create-source", 
+    NULL,
+    "/Methods/BseSNet/General/Create Source",
+    "Insert a new module into a synthesis network",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, create_source_setup, create_source_exec, 
 };
 static BseExportNodeProc __enode_remove_source = {
   { (BseExportNode*) &__enode_create_source, BSE_EXPORT_NODE_PROC,
-    "BseSNet+remove-source", "/Methods/BseSNet/General/Remove Source", NULL },
+    "BseSNet+remove-source", 
+    NULL,
+    "/Methods/BseSNet/General/Remove Source",
+    "Remove an existing module from its synthesis network",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, remove_source_setup, remove_source_exec, 
 };
 BseExportNode* bse__builtin_init_bsesnet_gen_proc_c (void);
