@@ -150,6 +150,7 @@ bse_source_class_base_init (BseSourceClass *class)
   class->channel_defs.ochannel_idents = NULL;
   class->channel_defs.ochannel_names = NULL;
   class->channel_defs.ochannel_blurbs = NULL;
+  class->gsl_class = NULL;
 }
 
 static void
@@ -186,6 +187,8 @@ bse_source_class_base_finalize (BseSourceClass *class)
   class->channel_defs.ochannel_idents = NULL;
   class->channel_defs.ochannel_names = NULL;
   class->channel_defs.ochannel_blurbs = NULL;
+  g_free (class->gsl_class);
+  class->gsl_class = NULL;
 }
 
 static void
@@ -216,12 +219,12 @@ bse_source_class_init (BseSourceClass *class)
 			      PROP_POS_X,
 			      sfi_pspec_real ("pos_x", "Position X", NULL,
 					      0, -SFI_MAXREAL, SFI_MAXREAL, 10,
-					      SFI_PARAM_STORAGE));
+					      SFI_PARAM_STORAGE ":skip-default"));
   bse_object_class_add_param (object_class, "Position",
 			      PROP_POS_Y,
 			      sfi_pspec_real ("pos_y", "Position Y", NULL,
 					      0, -SFI_MAXREAL, SFI_MAXREAL, 10,
-					      SFI_PARAM_STORAGE));
+					      SFI_PARAM_STORAGE ":skip-default"));
 
   source_signals[SIGNAL_IO_CHANGED] = bse_object_class_add_signal (object_class, "io_changed",
 								   G_TYPE_NONE, 0);
@@ -478,6 +481,16 @@ bse_source_class_add_ochannel (BseSourceClass *source_class,
   return bse_source_class_add_ochannel_ident (source_class, name, name, blurb);
 }
 
+void
+bse_source_class_cache_gsl_class (BseSourceClass *source_class,
+                                  const GslClass *gsl_class)
+{
+  g_return_if_fail (source_class->gsl_class == NULL);
+  g_return_if_fail (gsl_class != NULL);
+
+  source_class->gsl_class = g_memdup (gsl_class, sizeof (*gsl_class));
+}
+
 guint
 bse_source_find_ochannel (BseSource   *source,
 			  const gchar *ochannel_cname)
@@ -1002,10 +1015,10 @@ bse_source_flow_access_module (BseSource    *source,
       GslTrans *my_trans = trans ? trans : gsl_trans_open ();
 
       if (m1)
-	gsl_trans_add (my_trans, gsl_flow_job_access (m1, tick_stamp, access_func, data,
+	gsl_trans_add (my_trans, gsl_job_flow_access (m1, tick_stamp, access_func, data,
 						      m2 ? NULL : data_free_func));
       if (m2)
-	gsl_trans_add (my_trans, gsl_flow_job_access (m2, tick_stamp, access_func, data,
+	gsl_trans_add (my_trans, gsl_job_flow_access (m2, tick_stamp, access_func, data,
 						      data_free_func));
       if (!trans)
 	gsl_trans_commit (my_trans);
@@ -1046,7 +1059,7 @@ bse_source_flow_access_modules (BseSource    *source,
       GSList *slist;
       
       for (slist = modules; slist; slist = slist->next)
-	gsl_trans_add (my_trans, gsl_flow_job_access (slist->data, tick_stamp, access_func, data,
+	gsl_trans_add (my_trans, gsl_job_flow_access (slist->data, tick_stamp, access_func, data,
 						      slist->next ? NULL : data_free_func));
       if (!trans)
 	gsl_trans_commit (my_trans);
@@ -1626,7 +1639,7 @@ bse_source_input_backup_to_undo (BseSource      *source,
   ustack = bse_item_undo_open (source, "unset-input %s", bse_object_debug_name (source));
 
   storage = g_object_new (BSE_TYPE_STORAGE, NULL);
-  bse_storage_prepare_write (storage, BSE_STORAGE_SKIP_DEFAULTS | BSE_STORAGE_DBLOCK_CONTAINED);
+  bse_storage_prepare_write (storage, BSE_STORAGE_DBLOCK_CONTAINED);
 
   bse_storage_break (storage);
   bse_storage_printf (storage,
