@@ -87,17 +87,13 @@ BSE_BUILTIN_TYPE (BseSubOPort)
     OUTPORT_IMAGE_WIDTH, OUTPORT_IMAGE_HEIGHT,
     OUTPORT_IMAGE_RLE_PIXEL_DATA,
   };
-  guint type_id;
-  
-  type_id = bse_type_register_static (BSE_TYPE_SOURCE,
-                                      "BseSubOPort",
-                                      "Virtual output port connector, used to provide a synthesis network "
-                                      "with output signals from other synthesis networks",
-                                      &type_info);
-  bse_categories_register_icon ("/Modules/Virtualization/Virtual Output",
-                                type_id,
-                                &pixdata);
-  return type_id;
+  GType type = bse_type_register_static (BSE_TYPE_SOURCE,
+                                         "BseSubOPort",
+                                         "Virtual output port connector, used to provide a synthesis network "
+                                         "with output signals from other synthesis networks",
+                                         &type_info);
+  bse_categories_register_icon ("/Modules/Virtualization/Virtual Output", type, &pixdata);
+  return type;
 }
 
 static void
@@ -134,7 +130,7 @@ bse_sub_oport_class_init (BseSubOPortClass *class)
                                   sfi_pspec_string (string, name,
 						    "The port name is a unique name to establish input<->output "
 						    "port relationships",
-						    value, SFI_PARAM_DEFAULT));
+						    value, SFI_PARAM_STANDARD ":skip-default"));
       g_free (string);
       g_free (name);
       g_free (value);
