@@ -46,7 +46,7 @@ enum {
   PROP_SYNTH_NET,
   PROP_WAVE,
   PROP_MIDI_CHANNEL,
-  PROP_N_SYNTH_VOICES,
+  PROP_N_VOICES,
   PROP_POST_NET
 };
 
@@ -124,19 +124,19 @@ bse_track_class_init (BseTrackClass *class)
   bse_object_class_add_param (object_class, "Adjustments",
 			      PROP_MUTED,
 			      sfi_pspec_bool ("muted", "Muted", NULL,
-					      FALSE, SFI_PARAM_DEFAULT));
+					      FALSE, SFI_PARAM_STANDARD ":skip-default"));
   bse_object_class_add_param (object_class, "Synth Input",
 			      PROP_SYNTH_NET,
 			      bse_param_spec_object ("snet", "Custom Synth Net", "Synthesis network to be used as instrument",
 						     BSE_TYPE_CSYNTH,
-						     SFI_PARAM_DEFAULT));
+						     SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, "Synth Input",
 			      PROP_WAVE,
 			      bse_param_spec_object ("wave", "Custom Wave", "Wave to be used as instrument",
 						     BSE_TYPE_WAVE,
-						     SFI_PARAM_DEFAULT));
+						     SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, "Synth Input",
-			      PROP_N_SYNTH_VOICES,
+			      PROP_N_VOICES,
 			      sfi_pspec_int ("n_voices", "Max Voixes", "Maximum number of voices for simultaneous playback",
 					     8, 1, 256, 1,
 					     SFI_PARAM_GUI SFI_PARAM_STORAGE ":scale"));
@@ -145,13 +145,13 @@ bse_track_class_init (BseTrackClass *class)
                               sfi_pspec_int ("midi_channel", "MIDI Channel",
                                              "Midi channel assigned to this track, 0 uses private per-track channel",
                                              0, 0, BSE_MIDI_MAX_CHANNELS, 1,
-                                             SFI_PARAM_GUI SFI_PARAM_STORAGE ":scale"));
+                                             SFI_PARAM_GUI SFI_PARAM_STORAGE ":scale:skip-default"));
   bse_object_class_add_param (object_class, "Synth Postprocess",
 			      PROP_POST_NET,
 			      bse_param_spec_object ("pnet", "Custom Postprocess Net",
                                                      "Synthesis network to postprocess track sound",
 						     BSE_TYPE_CSYNTH,
-						     SFI_PARAM_DEFAULT));
+						     SFI_PARAM_STANDARD));
   signal_changed = bse_object_class_add_asignal (object_class, "changed", G_TYPE_NONE, 0);
 }
 
@@ -477,7 +477,7 @@ bse_track_set_property (GObject      *object,
 	    }
 	}
       break;
-    case PROP_N_SYNTH_VOICES:
+    case PROP_N_VOICES:
       if (!self->postprocess || !BSE_SOURCE_PREPARED (self->postprocess))
         self->max_voices = sfi_value_get_int (value);
       break;
@@ -539,7 +539,7 @@ bse_track_get_property (GObject    *object,
     case PROP_WAVE:
       bse_value_set_object (value, self->wave);
       break;
-    case PROP_N_SYNTH_VOICES:
+    case PROP_N_VOICES:
       sfi_value_set_int (value, self->max_voices);
       break;
     case PROP_MIDI_CHANNEL:
