@@ -124,6 +124,10 @@
 #define bse_gconfig_free beast__bse_gconfig_free
 #define bse_midi_signal_type_to_choice beast__bse_midi_signal_type_to_choice
 #define bse_midi_signal_type_from_choice beast__bse_midi_signal_type_from_choice
+#define bse_biquad_filter_type_to_choice beast__bse_biquad_filter_type_to_choice
+#define bse_biquad_filter_type_from_choice beast__bse_biquad_filter_type_from_choice
+#define bse_biquad_filter_norm_to_choice beast__bse_biquad_filter_norm_to_choice
+#define bse_biquad_filter_norm_from_choice beast__bse_biquad_filter_norm_from_choice
 #define bse_registration_type_to_choice beast__bse_registration_type_to_choice
 #define bse_registration_type_from_choice beast__bse_registration_type_from_choice
 #define bse_user_msg_type_to_choice beast__bse_user_msg_type_to_choice
@@ -132,6 +136,9 @@
 #define bse_error_type_from_choice beast__bse_error_type_from_choice
 #define bse_project_state_to_choice beast__bse_project_state_to_choice
 #define bse_project_state_from_choice beast__bse_project_state_from_choice
+#define bse_standard_osc_wave_type_to_choice beast__bse_standard_osc_wave_type_to_choice
+#define bse_standard_osc_wave_type_from_choice beast__bse_standard_osc_wave_type_from_choice
+#define bse_item_add_parasite beast__bse_item_add_parasite
 #define bse_item_check_is_a beast__bse_item_check_is_a
 #define bse_item_clear_undo beast__bse_item_clear_undo
 #define bse_item_common_ancestor beast__bse_item_common_ancestor
@@ -140,19 +147,24 @@
 #define bse_item_get_icon beast__bse_item_get_icon
 #define bse_item_get_name beast__bse_item_get_name
 #define bse_item_get_name_or_type beast__bse_item_get_name_or_type
+#define bse_item_get_parasite beast__bse_item_get_parasite
 #define bse_item_get_parent beast__bse_item_get_parent
 #define bse_item_get_project beast__bse_item_get_project
 #define bse_item_get_seqid beast__bse_item_get_seqid
 #define bse_item_get_type beast__bse_item_get_type
+#define bse_item_get_type_authors beast__bse_item_get_type_authors
 #define bse_item_get_type_blurb beast__bse_item_get_type_blurb
+#define bse_item_get_type_license beast__bse_item_get_type_license
 #define bse_item_get_type_name beast__bse_item_get_type_name
 #define bse_item_get_uname_path beast__bse_item_get_uname_path
 #define bse_item_group_undo beast__bse_item_group_undo
 #define bse_item_internal beast__bse_item_internal
+#define bse_item_list_parasites beast__bse_item_list_parasites
 #define bse_item_list_proxies beast__bse_item_list_proxies
 #define bse_item_redo beast__bse_item_redo
 #define bse_item_redo_depth beast__bse_item_redo_depth
 #define bse_item_set_name beast__bse_item_set_name
+#define bse_item_set_parasite beast__bse_item_set_parasite
 #define bse_item_undo beast__bse_item_undo
 #define bse_item_undo_depth beast__bse_item_undo_depth
 #define bse_item_ungroup_undo beast__bse_item_ungroup_undo
@@ -195,6 +207,7 @@
 #define bse_song_remove_part beast__bse_song_remove_part
 #define bse_song_remove_track beast__bse_song_remove_track
 #define bse_song_synthesize_note beast__bse_song_synthesize_note
+#define bse_project_import_midi_file beast__bse_project_import_midi_file
 #define bse_project_restore_from_file beast__bse_project_restore_from_file
 #define bse_project_store_bse beast__bse_project_store_bse
 #define bse_project_activate beast__bse_project_activate
@@ -334,6 +347,7 @@
 #define bse_sample_file_info beast__bse_sample_file_info
 #define bse_string_extract_number beast__bse_string_extract_number
 #define bse_type_blurb beast__bse_type_blurb
+#define bse_type_options beast__bse_type_options
 
 typedef struct _BseIntSeq BseIntSeq;
 typedef struct _BseNoteSeq BseNoteSeq;
@@ -533,6 +547,21 @@ typedef enum {
 const gchar* bse_midi_signal_type_to_choice (BseMidiSignalType value);
 BseMidiSignalType bse_midi_signal_type_from_choice (const gchar *choice);
 
+typedef enum {
+  BSE_BIQUAD_FILTER_RESONANT_LOWPASS = 1,
+  BSE_BIQUAD_FILTER_RESONANT_HIGHPASS = 2,
+} BseBiquadFilterType;
+const gchar* bse_biquad_filter_type_to_choice (BseBiquadFilterType value);
+BseBiquadFilterType bse_biquad_filter_type_from_choice (const gchar *choice);
+
+typedef enum {
+  BSE_BIQUAD_FILTER_NORM_PASSBAND = 1,
+  BSE_BIQUAD_FILTER_NORM_RESONANCE_GAIN = 2,
+  BSE_BIQUAD_FILTER_NORM_PEAK_GAIN = 3,
+} BseBiquadFilterNorm;
+const gchar* bse_biquad_filter_norm_to_choice (BseBiquadFilterNorm value);
+BseBiquadFilterNorm bse_biquad_filter_norm_from_choice (const gchar *choice);
+
 typedef enum {
   BSE_REGISTER_PLUGIN = 1,
   BSE_REGISTER_SCRIPT = 2,
@@ -621,6 +650,20 @@ typedef enum {
 const gchar* bse_project_state_to_choice (BseProjectState value);
 BseProjectState bse_project_state_from_choice (const gchar *choice);
 
+typedef enum {
+  BSE_STANDARD_OSC_SINE = 1,
+  BSE_STANDARD_OSC_TRIANGLE = 2,
+  BSE_STANDARD_OSC_SAW_RISE = 3,
+  BSE_STANDARD_OSC_SAW_FALL = 4,
+  BSE_STANDARD_OSC_PEAK_RISE = 5,
+  BSE_STANDARD_OSC_PEAK_FALL = 6,
+  BSE_STANDARD_OSC_MOOG_SAW = 7,
+  BSE_STANDARD_OSC_SQUARE = 8,
+  BSE_STANDARD_OSC_PULSE = 9,
+} BseStandardOscWaveType;
+const gchar* bse_standard_osc_wave_type_to_choice (BseStandardOscWaveType value);
+BseStandardOscWaveType bse_standard_osc_wave_type_from_choice (const gchar *choice);
+
 struct _BseIntSeq {
   guint n_ints;
   SfiInt* ints;
@@ -715,7 +758,7 @@ struct _BseTrackPart {
 struct _BseSongTiming {
   SfiInt tick;
   SfiReal bpm;
-  SfiInt nominator;
+  SfiInt numerator;
   SfiInt denominator;
   SfiInt tpqn;
   SfiInt tpt;
@@ -882,10 +925,13 @@ void bse_gconfig_free (BseGConfig* rec);
 
 
 extern SfiChoiceValues bse_midi_signal_type_values;
+extern SfiChoiceValues bse_biquad_filter_type_values;
+extern SfiChoiceValues bse_biquad_filter_norm_values;
 extern SfiChoiceValues bse_registration_type_values;
 extern SfiChoiceValues bse_user_msg_type_values;
 extern SfiChoiceValues bse_error_type_values;
 extern SfiChoiceValues bse_project_state_values;
+extern SfiChoiceValues bse_standard_osc_wave_type_values;
 extern SfiRecFields bse_part_note_fields;
 extern SfiRecFields bse_part_control_fields;
 extern SfiRecFields bse_note_description_fields;
@@ -940,6 +986,7 @@ extern SfiRecFields bse_gconfig_fields;
 #define BSE_IS_PCM_DEVICE(proxy) bse_proxy_is_a ((proxy), "BsePcmDevice")
 #define BSE_IS_PCM_DEVICE_OSS(proxy) bse_proxy_is_a ((proxy), "BsePcmDeviceOSS")
 
+void bse_item_add_parasite (SfiProxy bse_item_object, const gchar* path, SfiRec* parasite);
 SfiBool bse_item_check_is_a (SfiProxy bse_item_object, const gchar* type_name);
 void bse_item_clear_undo (SfiProxy bse_item_object);
 SfiProxy bse_item_common_ancestor (SfiProxy bse_item_object, SfiProxy item2);
@@ -948,19 +995,24 @@ void bse_item_fixme_set_parasite (SfiProxy bse_item_object, const gchar* name, S
 BseIcon* bse_item_get_icon (SfiProxy bse_item_object);
 const gchar* bse_item_get_name (SfiProxy bse_item_object);
 const gchar* bse_item_get_name_or_type (SfiProxy bse_item_object);
+SfiRec* bse_item_get_parasite (SfiProxy bse_item_object, const gchar* path);
 SfiProxy bse_item_get_parent (SfiProxy bse_item_object);
 SfiProxy bse_item_get_project (SfiProxy bse_item_object);
 SfiInt bse_item_get_seqid (SfiProxy bse_item_object);
 const gchar* bse_item_get_type (SfiProxy bse_item_object);
+const gchar* bse_item_get_type_authors (SfiProxy bse_item_object);
 const gchar* bse_item_get_type_blurb (SfiProxy bse_item_object);
+const gchar* bse_item_get_type_license (SfiProxy bse_item_object);
 const gchar* bse_item_get_type_name (SfiProxy bse_item_object);
 const gchar* bse_item_get_uname_path (SfiProxy bse_item_object);
 void bse_item_group_undo (SfiProxy bse_item_object, const gchar* name);
 SfiBool bse_item_internal (SfiProxy bse_item_object);
+BseStringSeq* bse_item_list_parasites (SfiProxy bse_item_object, const gchar* path);
 BseProxySeq* bse_item_list_proxies (SfiProxy bse_item_object, const gchar* property_name);
 void bse_item_redo (SfiProxy bse_item_object);
 SfiInt bse_item_redo_depth (SfiProxy bse_item_object);
 void bse_item_set_name (SfiProxy bse_item_object, const gchar* name);
+void bse_item_set_parasite (SfiProxy bse_item_object, const gchar* path, SfiRec* parasite);
 void bse_item_undo (SfiProxy bse_item_object);
 SfiInt bse_item_undo_depth (SfiProxy bse_item_object);
 void bse_item_ungroup_undo (SfiProxy bse_item_object);
@@ -1003,6 +1055,7 @@ BseSongTiming* bse_song_get_timing (SfiProxy bse_song_object, SfiInt tick);
 void bse_song_remove_part (SfiProxy bse_song_object, SfiProxy part);
 void bse_song_remove_track (SfiProxy bse_song_object, SfiProxy track);
 void bse_song_synthesize_note (SfiProxy bse_song_object, SfiProxy track, SfiInt duration, SfiInt note, SfiInt fine_tune, SfiReal velocity);
+BseErrorType bse_project_import_midi_file (SfiProxy bse_project_object, const gchar* file_name);
 BseErrorType bse_project_restore_from_file (SfiProxy bse_project_object, const gchar* file_name);
 BseErrorType bse_project_store_bse (SfiProxy bse_project_object, SfiProxy super, const gchar* file_name, SfiBool self_contained);
 BseErrorType bse_project_activate (SfiProxy bse_project_object);
@@ -1142,6 +1195,7 @@ SfiBool bse_proxy_check (SfiProxy item, const gchar* type_name);
 BseSampleFileInfo* bse_sample_file_info (const gchar* file_name);
 SfiReal bse_string_extract_number (const gchar* string, const gchar* format, SfiReal aux_base, SfiReal dflt);
 const gchar* bse_type_blurb (const gchar* type);
+const gchar* bse_type_options (const gchar* type);
 
 
 /*-------- end ../sfi/sfidl generated code --------*/
