@@ -53,9 +53,10 @@ static void	 bse_adder_update_modules	(BseAdder	*self,
 
 /* --- Export to BSE --- */
 #include "./icons/sum.c"
-BSE_REGISTER_OBJECT (BseAdder, BseSource, "/Modules/Routing/Adder", sum_icon,
+BSE_REGISTER_OBJECT (BseAdder, BseSource, "/Modules/Routing/Adder",
                      "The Adder is a very simplisitic prototype mixer that just sums up "
                      "incomiong signals (it does allow for switching to subtract mode though)",
+                     sum_icon,
                      bse_adder_class_init, bse_adder_class_finalize, bse_adder_init);
 BSE_DEFINE_EXPORTS (BSE_PLUGIN_NAME);
 
@@ -94,7 +95,7 @@ bse_adder_class_init (BseAdderClass *class)
 						   "Use subtraction to combine sample"
 						   "values (instead of addition)",
 						   FALSE,
-						   SFI_PARAM_DEFAULT));
+						   SFI_PARAM_STANDARD ":skip-default"));
   
   channel = bse_source_class_add_jchannel (source_class, "Audio In1", "Audio Input 1");
   g_assert (channel == BSE_ADDER_JCHANNEL_AUDIO1);
