@@ -51,22 +51,17 @@ static void	bse_sequencer_reset		(BseSource		*source);
 static void	bse_sequencer_update_modules	(BseSequencer		*seq);
 
 
+/* --- Export to BSE --- */
+#include "./icons/sequencer.c"
+BSE_REGISTER_OBJECT (BseSequencer, BseSource, "/Modules/Other Sources/Sequencer",
+                     "The Sequencer produces a frequency signal according to a sequence of notes",
+                     sequencer_icon,
+                     bse_sequencer_class_init, NULL, bse_sequencer_init);
+BSE_DEFINE_EXPORTS (BSE_PLUGIN_NAME);
+
+
 /* --- variables --- */
-static GType		 type_id_sequencer = 0;
 static gpointer		 parent_class = NULL;
-static const GTypeInfo type_info_sequencer = {
-  sizeof (BseSequencerClass),
-  
-  (GBaseInitFunc) NULL,
-  (GBaseFinalizeFunc) NULL,
-  (GClassInitFunc) bse_sequencer_class_init,
-  (GClassFinalizeFunc) NULL,
-  NULL /* class_data */,
-  
-  sizeof (BseSequencer),
-  0 /* n_preallocs */,
-  (GInstanceInitFunc) bse_sequencer_init,
-};
 
 
 /* --- functions --- */
@@ -92,22 +87,22 @@ bse_sequencer_class_init (BseSequencerClass *class)
 			      PARAM_LENGTH,
 			      sfi_pspec_int ("length", "Length", NULL,
 					     8, 1, 128, 4,
-					     SFI_PARAM_GUI SFI_PARAM_HINT_SCALE));
+					     SFI_PARAM_GUI ":scale"));
   bse_object_class_add_param (object_class, "Sequence",
 			      PARAM_NOTES,
 			      bse_param_spec_boxed ("notes", "Notes", NULL,
 						    BSE_TYPE_NOTE_SEQUENCE,
-						    "note-sequence:" SFI_PARAM_DEFAULT));
+						    "note-sequence:" SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, "Sequence",
 			      PARAM_TRANSPOSE,
 			      sfi_pspec_int ("transpose", "Transpose", NULL,
 					     0, -36, +36, 3,
-					     SFI_PARAM_DEFAULT SFI_PARAM_HINT_SCALE));
+					     SFI_PARAM_STANDARD ":scale:skip-default"));
   bse_object_class_add_param (object_class, "Sequence",
 			      PARAM_COUNTER,
 			      sfi_pspec_real ("counter", "Timing [ms]", NULL,
 					      100, 0, 1000, 5,
-					      SFI_PARAM_DEFAULT SFI_PARAM_HINT_SCALE SFI_PARAM_FLOAT));
+					      SFI_PARAM_STANDARD ":f:scale"));
   
   ochannel = bse_source_class_add_ochannel (source_class, "Freq Out", "Frequency Signal");
   g_assert (ochannel == BSE_SEQUENCER_OCHANNEL_FREQ);
@@ -392,19 +387,3 @@ bse_sequencer_reset (BseSource *source)
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->reset (source);
 }
-
-/* --- Export to BSE --- */
-#include "./icons/sequencer.c"
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_OBJECTS = {
-  { &type_id_sequencer, "BseSequencer", "BseSource",
-    "The Sequencer produces a frequency signal according to a sequence of notes",
-    &type_info_sequencer,
-    "/Modules/Other Sources/Sequencer",
-    { SEQUENCER_IMAGE_BYTES_PER_PIXEL | BSE_PIXDATA_1BYTE_RLE,
-      SEQUENCER_IMAGE_WIDTH, SEQUENCER_IMAGE_HEIGHT,
-      SEQUENCER_IMAGE_RLE_PIXEL_DATA, },
-  },
-  { NULL, },
-};
-BSE_EXPORTS_END;
