@@ -126,15 +126,460 @@ g_strdup_lstrip (const gchar *string)
   return NULL;
 }
 
+gchar*
+g_strconcat_with_null (const gchar *string1, ...)
+{
+  gsize   l;
+  va_list args;
+  gchar   *s;
+  gchar   *concat;
+  gchar   *ptr;
+
+  if (!string1)
+    return NULL;
+
+  l = 1 + strlen (string1);
+  va_start (args, string1);
+  s = va_arg (args, gchar*);
+  while (s)
+    {
+      l += strlen (s);
+      s = va_arg (args, gchar*);
+    }
+  va_end (args);
+
+  concat = g_new (gchar, l);
+  ptr = concat;
+
+  ptr = g_stpcpy (ptr, string1);
+  va_start (args, string1);
+  s = va_arg (args, gchar*);
+  while (s)
+    {
+      ptr = g_stpcpy (ptr, s);
+      s = va_arg (args, gchar*);
+    }
+  va_end (args);
+
+  return concat;
+}
+
+const gchar*
+g_intern_string (const gchar *string)
+{
+  return string ? g_quark_to_string (g_quark_from_string (string)) : NULL;
+}
+
+const gchar*
+g_intern_static_string (const gchar   *string)
+{
+  return string ? g_quark_to_string (g_quark_from_static_string (string)) : NULL;
+}
+
+static gchar*
+delim_concat_varargs (const gchar *first_string,
+                      gchar        delim,
+                      va_list      var_args)
+{
+  GString *gstring;
+  gchar *s;
+
+  if (!first_string)
+    return NULL;
+
+  gstring = g_string_new (first_string);
+  s = va_arg (var_args, gchar*);
+  while (s)
+    {
+      if (s[0])
+        {
+          if (gstring->len && gstring->str[gstring->len - 1] != delim &&
+              s[0] != delim && delim)
+            g_string_append_c (gstring, delim);
+          g_string_append (gstring, s);
+        }
+      s = va_arg (var_args, gchar*);
+    }
+
+  return g_string_free (gstring, FALSE);
+}
+
+const gchar*
+g_intern_strconcat (const gchar *first_string,
+                    ...)
+{
+  const gchar *c = NULL;
+  if (first_string)
+    {
+      gchar *s;
+      va_list args;
+      va_start (args, first_string);
+      s = delim_concat_varargs (first_string, 0, args);
+      va_end (args);
+      c = g_intern_string (s);
+      g_free (s);
+    }
+  return c;
+}
+
+gchar*
+g_path_concat (const gchar *first_path,
+               ...)
+{
+  va_list args;
+  gchar *s;
+  va_start (args, first_path);
+  s = delim_concat_varargs (first_path, G_SEARCHPATH_SEPARATOR, args);
+  va_end (args);
+  return s;
+}
+
+
+/* --- string options --- */
+gchar*
+g_option_concat (const gchar *first_option,
+                 ...)
+{
+  va_list args;
+  gchar *s;
+  va_start (args, first_option);
+  s = delim_concat_varargs (first_option, ':', args);
+  va_end (args);
+  return s;
+}
+
+static const gchar*
+g_option_find_value (const gchar *option_string,
+                     const gchar *option)
+{
+  const gchar *p, *match = NULL;
+  gint l = strlen (option);
+
+  g_return_val_if_fail (l > 0, NULL);
+
+  if (!option_string)
+    return NULL;        /* option not found */
+
+  /* try first match */
+  p = strstr (option_string, option);
+  if (p && (p == option_string || p[-1] == ':') &&
+      (p[l] == '-' || p[l] == '+' || p[l] == ':' || p[l] == 0))
+    match = p;
+  /* allow later matches to override */
+  while (p)
+    {
+      p = strstr (p + l, option);
+      if (p && p[-1] == ':' &&
+          (p[l] == '-' || p[l] == '+' || p[l] == ':' || p[l] == 0))
+        match = p;
+    }
+  return match ? match + l : NULL;
+}
+
+gchar*
+g_option_get (const gchar *option_string,
+              const gchar *option)
+{
+  const gchar *value = NULL;
+
+  if (option && option[0])
+    value = g_option_find_value (option_string, option);
+
+  if (!value)
+    return NULL;                        /* option not present */
+  else switch (value[0])
+    {
+      gchar *s;
+    case ':':   return g_strdup ("1");  /* option was present, no modifier */
+    case 0:     return g_strdup ("1");  /* option was present, no modifier */
+    case '+':   return g_strdup ("1");  /* option was present, enable modifier */
+    case '-':   return NULL;            /* option was present, disable modifier */
+    case '=':                           /* option present with assignment */
+      value++;
+      s = strchr (value, ':');
+      return s ? g_strndup (value, s - value) : g_strdup (value);
+    default:    return NULL;            /* anything else, undefined */
+    }
+}
+
+gboolean
+g_option_check (const gchar *option_string,
+                const gchar *option)
+{
+  const gchar *value = NULL;
+
+  if (option && option[0])
+    value = g_option_find_value (option_string, option);
+
+  if (!value)
+    return FALSE;                       /* option not present */
+  else switch (value[0])
+    {
+      gchar *s;
+    case ':':   return TRUE;            /* option was present, no modifier */
+    case 0:     return TRUE;            /* option was present, no modifier */
+    case '+':   return TRUE;            /* option was present, enable modifier */
+    case '-':   return FALSE;           /* option was present, disable modifier */
+    case '=':                           /* option present with assignment */
+      value++;
+      s = strchr (value, ':');
+      if (!s || s == value)             /* empty assignment */
+        return FALSE;
+      else switch (s[0])
+        {
+        case '0': case 'f': case 'F':
+        case 'n': case 'N':             /* false assigments */
+          return FALSE;
+        default: return TRUE;           /* anything else holds true */
+        }
+    default:    return FALSE;           /* anything else, undefined */
+    }
+}
+
+
+/* --- GParamSpec options --- */
+static GQuark quark_pspec_options = 0;
+static guint
+pspec_flags (const gchar *poptions)
+{
+  guint flags = 0;
+  if (poptions)
+    {
+      if (g_option_check (poptions, "r"))
+        flags |= G_PARAM_READABLE;
+      if (g_option_check (poptions, "w"))
+        flags |= G_PARAM_WRITABLE;
+      if (g_option_check (poptions, "construct"))
+        flags |= G_PARAM_CONSTRUCT;
+      if (g_option_check (poptions, "construct-only"))
+        flags |= G_PARAM_CONSTRUCT_ONLY;
+      if (g_option_check (poptions, "lax-validation"))
+        flags |= G_PARAM_LAX_VALIDATION;
+    }
+  return flags;
+}
+
+void
+g_param_spec_set_options (GParamSpec  *pspec,
+                          const gchar *options)
+{
+  if (!quark_pspec_options)
+    quark_pspec_options = g_quark_from_static_string ("GParamSpec-options");
+  g_return_if_fail (G_IS_PARAM_SPEC (pspec));
+  if (options)
+    g_param_spec_set_qdata (pspec, quark_pspec_options, (gchar*) g_intern_string (options));
+  /* pspec->flags &= ~G_PARAM_MASK; */
+  pspec->flags |= pspec_flags (options);
+}
+
+gboolean
+g_param_spec_check_option (GParamSpec  *pspec,
+                           const gchar *option)
+{
+  const gchar *poptions;
+  g_return_val_if_fail (G_IS_PARAM_SPEC (pspec), FALSE);
+  poptions = g_param_spec_get_options (pspec);
+  return g_option_check (poptions, option);
+}
+
+void
+g_param_spec_add_option (GParamSpec  *pspec,
+                         const gchar *option,
+                         const gchar *value)
+{
+  const gchar *options;
+  guint append = 0;
+  g_return_if_fail (G_IS_PARAM_SPEC (pspec));
+  g_return_if_fail (option != NULL && !strchr (option, ':'));
+  g_return_if_fail (value == NULL || !strcmp (value, "-") || !strcmp (value, "+"));
+  options = g_param_spec_get_options (pspec);
+  if (!options)
+    options = "";
+  if (value && strcmp (value, "-") == 0 &&
+      g_option_check (options, option))
+    append = 2;
+  else if ((!value || strcmp (value, "+") == 0) &&
+           !g_option_check (options, option))
+    append = 1;
+  if (append)
+    {
+      guint l = strlen (options);
+      gchar *s = g_strconcat (options,
+                              options[l] == ':' ? "" : ":",
+                              option, /* append >= 1 */
+                              append >= 2 ? value : "",
+                              NULL);
+      g_param_spec_set_options (pspec, s);
+      g_free (s);
+    }
+}
+
+gboolean
+g_param_spec_provides_options (GParamSpec  *pspec,
+                               const gchar *options)
+{
+  const gchar *p;
+  g_return_val_if_fail (G_IS_PARAM_SPEC (pspec), FALSE);
+  g_return_val_if_fail (options != NULL, FALSE);
+ recurse:
+  while (options[0] == ':')
+    options++;
+  if (!options[0])
+    return TRUE;
+  p = strchr (options, ':');
+  if (p)
+    {
+      gchar *h = g_strndup (options, p - options);
+      gboolean match = g_param_spec_check_option (pspec, h);
+      g_free (h);
+      if (!match)
+        return FALSE;
+      options = p + 1;
+      goto recurse;
+    }
+  else
+    return g_param_spec_check_option (pspec, options);
+}
+
+const gchar*
+g_param_spec_get_options (GParamSpec *pspec)
+{
+  const gchar *options;
+  g_return_val_if_fail (G_IS_PARAM_SPEC (pspec), NULL);
+  options = g_param_spec_get_qdata (pspec, quark_pspec_options);
+  return options ? options : "";
+}
+
+static GQuark quark_pspec_istepping = 0;
+static GQuark quark_pspec_istepping64 = 0;
+
+void
+g_param_spec_set_istepping (GParamSpec  *pspec,
+                            guint64      stepping)
+{
+  if (!quark_pspec_istepping)
+    {
+      quark_pspec_istepping = g_quark_from_static_string ("GParamSpec-istepping");
+      quark_pspec_istepping64 = g_quark_from_static_string ("GParamSpec-istepping64");
+    }
+  g_return_if_fail (G_IS_PARAM_SPEC (pspec));
+  if (stepping >> 32)
+    {
+      guint64 *istepping64 = g_new (guint64, 1);
+      *istepping64 = stepping;
+      g_param_spec_set_qdata_full (pspec, quark_pspec_istepping64, istepping64, g_free);
+      g_param_spec_set_qdata (pspec, quark_pspec_istepping, 0);
+    }
+  else
+    {
+      g_param_spec_set_qdata (pspec, quark_pspec_istepping64, NULL);
+      g_param_spec_set_qdata (pspec, quark_pspec_istepping, (void*) (guint32) stepping);
+    }
+}
+
+guint64
+g_param_spec_get_istepping (GParamSpec *pspec)
+{
+  guint64 stepping;
+  g_return_val_if_fail (G_IS_PARAM_SPEC (pspec), 0);
+  stepping = (guint32) g_param_spec_get_qdata (pspec, quark_pspec_istepping);
+  if (!stepping)
+    {
+      guint64 *istepping64 = g_param_spec_get_qdata (pspec, quark_pspec_istepping64);
+      stepping = istepping64 ? *istepping64 : 0;
+    }
+  return stepping;
+}
+
+static GQuark quark_pspec_fstepping = 0;
+
+void
+g_param_spec_set_fstepping (GParamSpec  *pspec,
+                            gdouble      stepping)
+{
+  if (!quark_pspec_fstepping)
+    quark_pspec_fstepping = g_quark_from_static_string ("GParamSpec-fstepping");
+  g_return_if_fail (G_IS_PARAM_SPEC (pspec));
+  if (stepping)
+    {
+      gdouble *fstepping = g_new (gdouble, 1);
+      *fstepping = stepping;
+      g_param_spec_set_qdata_full (pspec, quark_pspec_fstepping, fstepping, g_free);
+    }
+  else
+    g_param_spec_set_qdata (pspec, quark_pspec_fstepping, NULL);
+}
+
+gdouble
+g_param_spec_get_fstepping (GParamSpec *pspec)
+{
+  gdouble *fstepping;
+  g_return_val_if_fail (G_IS_PARAM_SPEC (pspec), 0);
+  fstepping = g_param_spec_get_qdata (pspec, quark_pspec_fstepping);
+  return fstepping ? *fstepping : 0;
+}
+
+typedef struct {
+  gdouble center;
+  gdouble base;
+  gdouble n_steps;
+} LogScale;
+
+static GQuark quark_pspec_log_scale = 0;
+
+void
+g_param_spec_set_log_scale (GParamSpec  *pspec,
+                            gdouble      center,
+                            gdouble      base,
+                            gdouble      n_steps)
+{
+  if (!quark_pspec_log_scale)
+    quark_pspec_log_scale = g_quark_from_static_string ("GParamSpec-log-scale");
+  g_return_if_fail (G_IS_PARAM_SPEC (pspec));
+  if (n_steps > 0 && base > 0)
+    {
+      LogScale *lscale = g_new0 (LogScale, 1);
+      lscale->center = center;
+      lscale->base = base;
+      lscale->n_steps = n_steps;
+      g_param_spec_set_qdata_full (pspec, quark_pspec_log_scale, lscale, g_free);
+      g_param_spec_add_option (pspec, "log-scale", "+");
+    }
+  else
+    g_param_spec_set_qdata (pspec, quark_pspec_log_scale, NULL);
+}
+
+gboolean
+g_param_spec_get_log_scale (GParamSpec  *pspec,
+                            gdouble     *center,
+                            gdouble     *base,
+                            gdouble     *n_steps)
+{
+  LogScale *lscale;
+  g_return_val_if_fail (G_IS_PARAM_SPEC (pspec), FALSE);
+  lscale = g_param_spec_get_qdata (pspec, quark_pspec_log_scale);
+  if (lscale)
+    {
+      if (center)
+        *center = lscale->center;
+      if (base)
+        *base = lscale->base;
+      if (n_steps)
+        *n_steps = lscale->n_steps;
+      return TRUE;
+    }
+  return FALSE;
+}
+
 
 /* --- list extensions --- */
 gpointer
 g_slist_pop_head (GSList **slist_p)
 {
   gpointer data;
-
+  
   g_return_val_if_fail (slist_p != NULL, NULL);
-
+  
   if (!*slist_p)
     return NULL;
   data = (*slist_p)->data;
@@ -338,79 +783,6 @@ g_type_name_to_type_macro (const gchar *type_name)
 }
 
 
-/* --- double array --- */
-GDArray*
-g_darray_new (guint prealloc)
-{
-  GDArray *darray = g_new0 (GDArray, 1);
-
-  darray->n_prealloced = prealloc;
-  darray->values = g_new0 (gdouble, darray->n_prealloced);
-
-  return darray;
-}
-
-void
-g_darray_free (GDArray *darray)
-{
-  g_return_if_fail (darray != NULL);
-
-  g_free (darray->values);
-  g_free (darray);
-}
-
-gdouble
-g_darray_get (GDArray *darray,
-	      guint    index)
-{
-  g_return_val_if_fail (darray != NULL, 0);
-  g_return_val_if_fail (index < darray->n_values, 0);
-
-  return darray->values[index];
-}
-
-void
-g_darray_insert (GDArray *darray,
-		 guint    index,
-		 gdouble  value)
-{
-  guint i;
-
-  g_return_if_fail (darray != NULL);
-  g_return_if_fail (index <= darray->n_values);
-
-  i = darray->n_values;
-  i = darray->n_values += 1;
-  if (darray->n_values > darray->n_prealloced)
-    {
-      darray->n_prealloced = darray->n_values;
-      darray->values = g_renew (gdouble, darray->values, darray->n_prealloced);
-    }
-  g_memmove (darray->values + index + 1,
-	     darray->values + index,
-	     i - index);
-  darray->values[index] = value;
-}
-
-void
-g_darray_append (GDArray *darray,
-		 gdouble  value)
-{
-  g_darray_insert (darray, darray->n_values, value);
-}
-
-void
-g_darray_set (GDArray *darray,
-	      guint    index,
-	      gdouble  value)
-{
-  g_return_if_fail (darray != NULL);
-  g_return_if_fail (index < darray->n_values);
-
-  darray->values[index] = value;
-}
-
-
 /* --- simple main loop source --- */
 typedef struct {
   GSource         source;
