@@ -33,6 +33,21 @@ G_BEGIN_DECLS
 #else
 #define G_HASH_LONG(l)	(l)
 #endif
+#if (GLIB_SIZEOF_VOID_P > 4)
+#define G_HASH_POINTER(p)	((guint32) (((gsize) (p)) + (((gsize) (p)) >> 32)))
+#else
+#define G_HASH_POINTER(p)       ((guint32) (gsize) (p))
+#endif
+/* Provide a string identifying the current function, non-concatenatable */
+#ifndef G_STRFUNC
+#  if defined (__GNUC__)
+#    define G_STRFUNC     ((const char*) (__PRETTY_FUNCTION__))
+#  elif defined (G_HAVE_ISO_VARARGS)
+#    define G_STRFUNC     ((const char*) (__func__))
+#  elif
+#    define G_STRFUNC     ((const char*) ("???"))
+#  endif
+#endif
 
 
 /* --- provide (historic) aliases --- */
@@ -47,6 +62,7 @@ G_BEGIN_DECLS
 
 
 /* --- abandon typesafety for some frequently used functions --- */
+#ifndef __cplusplus
 #define g_object_notify(o,s)		  g_object_notify ((gpointer) o, s)
 #define	g_object_get_qdata(o,q)		  g_object_get_qdata ((gpointer) o, q)
 #define	g_object_set_qdata(o,q,d)	  g_object_set_qdata ((gpointer) o, q, d)
@@ -56,6 +72,7 @@ G_BEGIN_DECLS
 #define	g_object_set_data(o,k,d)	  g_object_set_data ((gpointer) o, k, d)
 #define	g_object_set_data_full(o,k,d,f)	  g_object_set_data_full ((gpointer) o, k, d, (gpointer) f)
 #define	g_object_steal_data(o,k)	  g_object_steal_data ((gpointer) o, k)
+#endif  /* !__cplusplus */
 
 
 /* --- string functions --- */
@@ -67,16 +84,52 @@ gchar*		g_strdup_stripped (const gchar	 *string);
 gchar*		g_strdup_rstrip   (const gchar	 *string);
 gchar*		g_strdup_lstrip   (const gchar	 *string);
 
-const gchar*    g_quark_intern        (const gchar   *string);
-const gchar*    g_quark_intern_static (const gchar   *string);
+const gchar*    g_intern_string         (const gchar   *string);
+const gchar*    g_intern_static_string  (const gchar   *string);
+const gchar*    g_intern_strconcat      (const gchar   *first_string,
+                                         ...);
+
+gchar*          g_strconcat_with_null  (const gchar   *string1, ...);
+#define         g_strconcat             g_strconcat_with_null
 
 gchar*          g_path_concat     (const gchar   *first_path,
                                    ...);
 
 
 /* --- string options --- */
+gchar*          g_option_concat   (const gchar   *first_option,
+                                   ...);
 gboolean        g_option_check    (const gchar   *option_string,
                                    const gchar   *option);
+gchar*          g_option_get      (const gchar   *option_string,
+                                   const gchar   *option);
+
+
+/* --- GParamSpec extensions --- */
+void         g_param_spec_set_options      (GParamSpec  *pspec,
+                                            const gchar *options);
+void         g_param_spec_add_option       (GParamSpec  *pspec,
+                                            const gchar *option,
+                                            const gchar *value);
+gboolean     g_param_spec_check_option     (GParamSpec  *pspec,
+                                            const gchar *option);
+gboolean     g_param_spec_provides_options (GParamSpec  *pspec,
+                                            const gchar *options);
+const gchar* g_param_spec_get_options      (GParamSpec  *pspec);
+void         g_param_spec_set_istepping    (GParamSpec  *pspec,
+                                            guint64      stepping);
+guint64      g_param_spec_get_istepping    (GParamSpec  *pspec);
+void         g_param_spec_set_fstepping    (GParamSpec  *pspec,
+                                            gdouble      stepping);
+gdouble      g_param_spec_get_fstepping    (GParamSpec  *pspec);
+void         g_param_spec_set_log_scale    (GParamSpec  *pspec,
+                                            gdouble      center,
+                                            gdouble      base,
+                                            gdouble      n_steps);
+gboolean     g_param_spec_get_log_scale    (GParamSpec  *pspec,
+                                            gdouble     *center,
+                                            gdouble     *base,
+                                            gdouble     *n_steps);
 
 
 /* --- list extensions --- */
@@ -110,6 +163,71 @@ GSource*	g_source_simple	(gint		 priority,
 				 ...);
 
 
+/* --- bit matrix --- */
+typedef struct {
+  guint32 width, height;
+  guint32 bits[1]; /* flexible array */
+} GBitMatrix;
+
+static inline GBitMatrix*
+g_bit_matrix_new (guint           width,
+                  guint           height)
+{
+  GBitMatrix *matrix = (GBitMatrix*) g_new0 (guint32, MAX ((width * height + 31) / 32, 1) + 2);
+  matrix->width = width;
+  matrix->height = height;
+  return matrix;
+}
+
+static inline void
+g_bit_matrix_change (GBitMatrix     *matrix,
+                     guint           x,
+                     guint           y,
+                     gboolean        bit_set)
+{
+  guint32 cons, index, shift;
+  g_return_if_fail (matrix && x < matrix->width && y < matrix->height);
+  cons = y * matrix->width + x;
+  index = cons >> 5; /* / 32 */
+  shift = cons & 0x1f;  /* % 32 */
+  if (bit_set)
+    matrix->bits[index] |= 1 << shift;
+  else
+    matrix->bits[index] &= ~(1 << shift);
+}
+
+#define g_bit_matrix_set(matrix,x,y)    g_bit_matrix_change (matrix, x, y, TRUE)
+#define g_bit_matrix_unset(matrix,x,y)  g_bit_matrix_change (matrix, x, y, FALSE)
+
+static inline guint32
+g_bit_matrix_peek (GBitMatrix     *matrix,
+                   guint           x,
+                   guint           y)
+{
+  guint32 cons = y * matrix->width + x;
+  guint32 index = cons >> 5; /* / 32 */
+  guint32 shift = cons & 0x1f;  /* % 32 */
+  return matrix->bits[index] & (1 << shift);
+}
+
+static inline gboolean
+g_bit_matrix_test (GBitMatrix *matrix,
+                   guint       x,
+                   guint       y)
+{
+  if (x < matrix->width && y < matrix->height)
+    return g_bit_matrix_peek (matrix, x, y) != 0;
+  else
+    return 0;
+}
+
+static inline void
+g_bit_matrix_free (GBitMatrix *matrix)
+{
+  g_free (matrix);
+}
+
+
 /* --- unix signal queue --- */
 #if 0
 typedef gboolean (*GUSignalFunc) (gint8          usignal,
