@@ -21,6 +21,7 @@
 
 /* no bin-compat: #include <sfi/sficomwire.h> */
 #include <sfi/sficomport.h>
+#include <sfi/sfifilecrawler.h>
 #include <sfi/sfiglue.h>
 #include <sfi/sfigluecodec.h>
 #include <sfi/sfiglueproxy.h>
@@ -29,6 +30,7 @@
 #include <sfi/sfinote.h>
 #include <sfi/sfiparams.h>
 #include <sfi/sfiprimitives.h>
+/* #include <sfi/sfisclock.h> */
 #include <sfi/sfiserial.h>
 #include <sfi/sfithreads.h>
 /* no bin-compat: #include <sfi/sfistore.h> */
