@@ -17,9 +17,14 @@
  * Boston, MA 02111-1307, USA.
  */
 #include "sfidl-options.h"
+#include "topconfig.h"
 #include <sfi/glib-extra.h>
 #include <stdio.h>
 
+/* FIXME: should be filled out and written into topconfig.h by configure */
+#define SFIDL_VERSION        BST_VERSION
+#define SFIDL_PRG_NAME	     "sfidl"
+
 using namespace Sfidl;
 
 static Options *Options_the = 0;
@@ -36,8 +41,9 @@ Options::Options ()
   generateTypeH = generateTypeC = false;
   generateBoxedTypes = generateProcedures = generateSignalStuff = false;
   generateIdlLineNumbers = false;
-  targetC = targetQt = false;
-  doHeader = doSource = doImplementation = doInterface = doHelp = false;
+  target = TARGET_C;
+  style = STYLE_DEFAULT;
+  doHeader = doSource = doImplementation = doInterface = doHelp = doExit = false;
   sfidlName = "sfidl";
 
   Options_the = this;
@@ -45,6 +51,10 @@ Options::Options ()
 
 bool Options::parse (int *argc_p, char **argv_p[])
 {
+  bool printIncludePath = false;
+  bool printVersion = false;
+  bool noStdInc = false;
+
   unsigned int argc;
   char **argv;
   unsigned int i, e;
@@ -106,9 +116,40 @@ bool Options::parse (int *argc_p, char **argv_p[])
 	}
       else if (strcmp ("--qt", argv[i]) == 0)
 	{
-	  targetQt = true;
+	  target = TARGET_QT;
 	  argv[i] = NULL;
 	}
+      else if (strcmp ("--module", argv[i]) == 0)
+	{
+	  target = TARGET_MODULE;
+          /* configure for module generation */
+          doImplementation = true;
+          doInterface = false;
+          doHeader = true;
+          doSource = false;
+	  argv[i] = NULL;
+	}
+      else if (strcmp ("--cxx", argv[i]) == 0)
+	{
+	  target = TARGET_CXX;
+	  /*
+	   * we will probably extend this to support both:
+	   * interface and implementation
+	   */
+          doImplementation = false;
+          doInterface = true;
+	  argv[i] = 0;
+	}
+      else if (strcmp ("--lower", argv[i]) == 0)
+	{
+	  style = STYLE_LOWER;
+	  argv[i] = 0;
+	}
+      else if (strcmp ("--mixed", argv[i]) == 0)
+	{
+	  style = STYLE_MIXED;
+	  argv[i] = 0;
+	}
       else if (strcmp ("--help", argv[i]) == 0)
 	{
 	  doHelp = true;
@@ -156,7 +197,6 @@ bool Options::parse (int *argc_p, char **argv_p[])
 	   strncmp ("-I", argv[i], len) == 0))
 	{
 	  char *path = argv[i] + len;
-	  const char *dir = 0;
 
 	  if (*path != 0)
 	    includePath.push_back (path);
@@ -168,6 +208,23 @@ bool Options::parse (int *argc_p, char **argv_p[])
 	    }
 	  argv[i] = NULL;
 	}
+      else if (strcmp ("--print-include-path", argv[i]) == 0)
+	{
+	  printIncludePath = true;
+	  doExit = true;
+	  argv[i] = NULL;
+	}
+      else if (strcmp ("--version", argv[i]) == 0)
+	{
+	  printVersion = true;
+	  doExit = true;
+	  argv[i] = NULL;
+	}
+      else if (strcmp ("--nostdinc", argv[i]) == 0)
+	{
+	  noStdInc = true;
+	  argv[i] = NULL;
+	}
     }
 
   /* resort argc/argv */
@@ -188,11 +245,46 @@ bool Options::parse (int *argc_p, char **argv_p[])
   if (e)
     *argc_p = e;
 
+  /* add std include path */
+  if (!noStdInc)
+    {
+      char *x = g_strdup (SFIDL_PATH_STDINC);
+      char *dir = strtok (x, G_SEARCHPATH_SEPARATOR_S);
+      while (dir && dir[0])
+	{
+	  includePath.push_back (dir);
+	  dir = strtok (NULL, G_SEARCHPATH_SEPARATOR_S);
+	}
+      g_free (x);
+    }
+
   /* option validation */
 
   if (doHelp)
     return true;
 
+  if (printIncludePath)
+    {
+      bool first = true;
+      for (std::vector<std::string>::const_iterator ii = includePath.begin(); ii != includePath.end(); ii++)
+	{
+	  if (!first)
+	    printf (":");
+	  else
+	    first = false;
+	  printf ("%s", ii->c_str());
+	}
+      printf ("\n");
+      return true;
+    }
+
+  if (printVersion)
+    {
+      printf ("%s %s\n", SFIDL_PRG_NAME, SFIDL_VERSION);
+      return true;
+    }
+
+
   // exactly one of --source | --header, --interface | --implementation
   if (((doSource?1:0) + (doHeader?1:0)) != 1)
     {
@@ -217,20 +309,34 @@ bool Options::parse (int *argc_p, char **argv_p[])
       return false;
     }
 
+  // style
+
+  if (style == STYLE_DEFAULT && target == TARGET_QT)
+    style = STYLE_MIXED;
+
+  if (style == STYLE_DEFAULT)
+    style = STYLE_LOWER;
+
   // --qt
-  if (targetQt && doImplementation)
+  if (target == TARGET_QT && doImplementation)
     {
       fprintf (stderr, "%s: --implementation is not supported for Qt\n", sfidlName.c_str());
       return false;
     }
-  targetC = !targetQt;
+
+  // --module
+  if (target == TARGET_MODULE && doInterface)
+    {
+      fprintf (stderr, "%s: --interface is not supported for Module\n", sfidlName.c_str());
+      return false;
+    }
 
   /* implications of header/source options */
   if (doHeader)
     {
       generateExtern = true;
       generateTypeH = true;
-      generateConstant = true;
+      generateConstant = false; // useless
     }
 
   if (doSource)
@@ -272,9 +378,16 @@ void Options::printUsage ()
   fprintf (stderr, "\n");
   fprintf (stderr, "options for the C++ language binding:\n");
   fprintf (stderr, " --qt                        use Qt language binding\n");
+  fprintf (stderr, " --cxx                       use C++ language binding\n");
+  fprintf (stderr, " --module                    generate skeleton Module implementation\n");
   fprintf (stderr, " --namespace <namespace>     set the namespace to use for the code\n");
+  fprintf (stderr, " --mixed                     mixed case identifiers (createMidiSynth)\n");
+  fprintf (stderr, " --lower                     lower case identifiers (create_midi_synth)\n");
   fprintf (stderr, "\n");
   fprintf (stderr, " --help                      this help\n");
+  fprintf (stderr, " --version                   print version\n");
+  fprintf (stderr, " --print-include-path        print include path\n");
+  fprintf (stderr, " --nostdinc                  don't use standard include path\n");
 }
 
 
