@@ -25,6 +25,8 @@
 namespace Sfidl {
 
 struct Options {
+  enum Target { TARGET_C, TARGET_QT, TARGET_MODULE, TARGET_CXX };
+  enum Style  { STYLE_DEFAULT, STYLE_LOWER, STYLE_MIXED };
   bool        generateExtern;
   bool        generateData;
   bool        generateConstant;
@@ -34,13 +36,14 @@ struct Options {
   bool        generateIdlLineNumbers;
   bool        generateSignalStuff;
   bool        generateProcedures;
-  bool        targetC;
-  bool        targetQt;
+  Target      target;
+  Style       style;
   bool        doHeader;
   bool        doSource;
   bool        doInterface;
   bool        doImplementation;
   bool        doHelp;
+  bool	      doExit;
   std::string prefixC;
   std::string initFunction;
   std::string namespaceQt;
