@@ -25,6 +25,8 @@
 #include "sfidl-namespace.h"
 #include "sfidl-options.h"
 #include <iostream>
+#include <set>
+#include <stack>
 
 namespace {
 using namespace Sfidl;
@@ -133,6 +135,16 @@ bool operator== (GTokenType t, ExtraToken e) { return (int) t == (int) e; }
   if (__bracket) \
     parse_or_return (')'); \
 }G_STMT_END
+#define parse_istring_or_return(str) G_STMT_START{ \
+  IString& __is = str; /* type safety - assume argument is an IString */ \
+  __is.i18n = (g_scanner_peek_next_token (scanner) == G_TOKEN_IDENTIFIER && \
+               strcmp (scanner->next_value.v_string, "_") == 0); \
+  if (__is.i18n) { \
+    parse_or_return (G_TOKEN_IDENTIFIER); \
+    peek_or_return ('('); \
+  } \
+  parse_string_or_return (__is); \
+}G_STMT_END
 #define parse_int_or_return(i) G_STMT_START{ \
   bool negate = (g_scanner_peek_next_token (scanner) == GTokenType('-')); \
   if (negate) \
@@ -185,6 +197,25 @@ bool Parser::isClass(const string& type) const
   return (i != typeMap.end()) && ((i->second & (~tdProto)) == tdClass);
 }
 
+Type Parser::typeOf(const string& type) const
+{
+  if (type == "void")	  return VOID;
+  if (type == "Bool")	  return BOOL;
+  if (type == "Int")	  return INT;
+  if (type == "Num")	  return NUM;
+  if (type == "Real")	  return REAL;
+  if (type == "String")   return STRING;
+  if (isChoice (type))	  return CHOICE;
+  if (type == "BBlock")   return BBLOCK;
+  if (type == "FBlock")   return FBLOCK;
+  if (type == "Rec")      return SFIREC;
+  if (isSequence (type))  return SEQUENCE;
+  if (isRecord (type))    return RECORD;
+  if (isClass (type))     return OBJECT;
+  g_error (("invalid type: " + type).c_str());
+  return VOID;
+}
+
 Sequence Parser::findSequence(const string& name) const
 {
   vector<Sequence>::const_iterator i;
@@ -259,6 +290,7 @@ void Parser::scannerMsgHandler (GScanner *scanner, gchar *message, gboolean is_e
 
 static bool match(vector<char>::iterator start, const char *string)
 {
+  /* FIXME: can we exceed the bounds of the input vector? */
   while(*string && *start)
     if(*string++ != *start++) return false;
 
@@ -302,20 +334,65 @@ bool Parser::haveIncluded (const string& filename) const
   return false;
 }
 
-void Parser::preprocess (const string& input_filename)
+static void collectImplIncludes (set<string>& result,
+				 const string& root,
+				 map<string, set<string> >& implIncludeMap)
+{
+  if (result.count (root) == 0)
+    {
+      result.insert (root);
+
+      set<string>::const_iterator si;
+      for (si = implIncludeMap[root].begin(); si != implIncludeMap[root].end(); si++)
+	collectImplIncludes (result, *si, implIncludeMap);
+    }
+}
+
+void Parser::preprocess (const string& filename, bool includeImpl)
+{
+  static stack<string> includeStack;
+  static map<string, set<string> > implIncludeMap;
+
+  // make a note whenever "file 1" implincludes "file 2"
+  if (!includeStack.empty() && includeImpl)
+    implIncludeMap[includeStack.top()].insert(filename);
+
+  // do the actual preprocessing on the file
+  if (!haveIncluded (filename))
+    {
+      includes.push_back (filename);
+
+      includeStack.push (filename);
+      preprocessContents (filename);
+      includeStack.pop ();
+    }
+
+  // on the outer level compute which code to build
+  if (includeStack.empty())
+    {
+      set<string> implIncludes;
+      collectImplIncludes (implIncludes, filename, implIncludeMap);
+      implIncludeMap.clear();
+
+      vector<LineInfo>::iterator li;
+      for (li = scannerLineInfo.begin(); li != scannerLineInfo.end(); li++)
+	li->isInclude = (implIncludes.count (li->filename) == 0);
+    }
+}
+
+void Parser::preprocessContents (const string& input_filename)
 {
   string filename;
+  bool includeImpl;
   enum
     {
       lineStart, idlCode, commentC, commentCxx,
       filenameFind, filenameIn1, filenameIn2,
       inString, inStringEscape
     } state = lineStart;
-  static int incdepth = 0;
 
   LineInfo linfo;
   linfo.line = 1;
-  linfo.isInclude = (incdepth != 0);
   linfo.filename = input_filename;
 
   vector<char> input;
@@ -395,22 +472,34 @@ void Parser::preprocess (const string& input_filename)
 	   || (state == filenameIn2 && *i == '>'))
 	{
 	  string location;
-	  if (state == filenameIn1) // #include "foo.idl" => search in local directory (relative to input_file)
+	  // #include "/usr/include/foo.idl" (absolute path includes)
+	  if (g_path_is_absolute (filename.c_str()))
 	    {
-	      gchar *dir = g_path_get_dirname (input_filename.c_str());
-	      if (fileExists (dir + string(G_DIR_SEPARATOR_S) + filename))
+	      if (fileExists (filename))
 		location = filename;
-	      g_free (dir);
 	    }
-	  if (location == "") // all #include directives => search includepath with standard include dirs
+	  else
 	    {
-	      for(vector<string>::const_iterator i = options.includePath.begin(); i != options.includePath.end(); i++)
+	      // #include "foo.idl" => search in local directory (relative to input_file)
+	      if (state == filenameIn1)
 		{
-		  string testFilename = *i + "/" + filename;
-		  if (fileExists (testFilename))
+		  gchar *dir = g_path_get_dirname (input_filename.c_str());
+		  if (fileExists (dir + string(G_DIR_SEPARATOR_S) + filename))
+		    location = filename;
+		  g_free (dir);
+		}
+	      // all #include directives => search includepath with standard include dirs
+	      if (location == "")
+		{
+		  vector<string>::const_iterator oi;
+		  for(oi = options.includePath.begin(); oi != options.includePath.end(); oi++)
 		    {
-		      location = testFilename;
-		      break;
+		      string testFilename = *oi + "/" + filename;
+		      if (fileExists (testFilename))
+			{
+			  location = testFilename;
+			  break;
+			}
 		    }
 		}
 	    }
@@ -419,15 +508,7 @@ void Parser::preprocess (const string& input_filename)
 	      fprintf(stderr,"include file '%s' not found\n", filename.c_str());
 	      exit(1);
 	    }
-
-	  if(!haveIncluded(location))
-	    {
-	      includes.push_back(location);
-
-	      incdepth++;
-	      preprocess (location);
-	      incdepth--;
-	    }
+	  preprocess (location, includeImpl);
 
 	  state = idlCode;
 	  i++;
@@ -443,11 +524,19 @@ void Parser::preprocess (const string& input_filename)
 	}
       else if(state == lineStart) // check if we're on lineStart
 	{
-	  if(match(i,"#include"))
+	  if(match(i,"#include-impl"))
+	    {
+	      i += 13;
+	      state = filenameFind;
+	      filename = "";
+	      includeImpl = true;
+	    }
+	  else if(match(i,"#include"))
 	    {
 	      i += 8;
 	      state = filenameFind;
 	      filename = "";
+	      includeImpl = false;
 	    }
 	  else
 	    {
@@ -506,10 +595,8 @@ bool Parser::parse (const string& filename)
   ModuleHelper::define("Num");
   ModuleHelper::define("Real");
   ModuleHelper::define("String");
-  ModuleHelper::define("Proxy"); /* FIXME: remove this as soon as "real" interface types exist */
   ModuleHelper::define("BBlock");
   ModuleHelper::define("FBlock");
-  ModuleHelper::define("PSpec");
   ModuleHelper::define("Rec");
   
   GTokenType expected_token = G_TOKEN_NONE;
@@ -859,27 +946,8 @@ GTokenType Parser::parseChoiceValue (ChoiceValue& comp, int& value, int& sequent
   return G_TOKEN_NONE;
 }
 
-GTokenType
-parse_dot_group (GScanner *scanner,
-                 string   *group)
-{
-  if (g_scanner_peek_next_token (scanner) == '$')
-    {
-      parse_or_return ('$');
-      parse_or_return (G_TOKEN_IDENTIFIER);
-      if (strcmp (scanner->value.v_identifier, "GROUP") != 0)
-        return G_TOKEN_IDENTIFIER;
-      parse_or_return ('=');
-      parse_or_return (G_TOKEN_STRING);
-      *group = scanner->value.v_string;
-      parse_or_return (';');
-    }
-  return G_TOKEN_NONE;
-}
-
 GTokenType Parser::parseRecord ()
 {
-  string group = "";
   Record record;
   DEBUG("parse record\n");
   
@@ -901,18 +969,11 @@ GTokenType Parser::parseRecord ()
       GTokenType expected_token;
       switch (g_scanner_peek_next_token (scanner))
         {
-#if 0
-        case '$':
-          expected_token = parse_dot_group (scanner, &group);
-          if (expected_token != G_TOKEN_NONE)
-            return expected_token;
-          break;
-#endif
         case G_TOKEN_IDENTIFIER:
           {
             Param def;
             
-            expected_token = parseRecordField (def, group);
+            expected_token = parseRecordField (def, "");
             if (expected_token != G_TOKEN_NONE)
               return expected_token;
             
@@ -922,29 +983,17 @@ GTokenType Parser::parseRecord ()
           break;
         case TOKEN_GROUP:
           {
-            string local_group = group;
+            IString group;
             parse_or_return (TOKEN_GROUP);
-            if (g_scanner_peek_next_token (scanner) == G_TOKEN_STRING)
-              {
-                g_scanner_get_next_token (scanner);
-                local_group = scanner->value.v_string;
-              }
+	    parse_istring_or_return (group);
             parse_or_return ('{');
             while (g_scanner_peek_next_token (scanner) != '}' && !g_scanner_eof (scanner))
               {
                 Param property;
-#if 0
-                if (g_scanner_peek_next_token (scanner) == '$')
-                  expected_token = parse_dot_group (scanner, &local_group);
-                else
-#endif
-                  {
-                    expected_token = parseRecordField (property, local_group);
-                    if (expected_token == G_TOKEN_NONE)
-                      record.contents.push_back (property);
-                  }
+                expected_token = parseRecordField (property, group);
                 if (expected_token != G_TOKEN_NONE)
                   return expected_token;
+                record.contents.push_back (property);
               }
             parse_or_return ('}');
             parse_or_return (';');
@@ -968,7 +1017,7 @@ GTokenType Parser::parseRecord ()
   return G_TOKEN_NONE;
 }
 
-GTokenType Parser::parseRecordField (Param& def, const string& group)
+GTokenType Parser::parseRecordField (Param& def, const IString& group)
 {
   /* FooVolumeType volume_type; */
   /* float         volume_perc @= ("Volume[%]", "Set how loud something is",
@@ -1018,9 +1067,9 @@ Parser::parseStream (Stream&      stream,
   parse_or_return ('=');
 
   parse_or_return ('(');
-  parse_string_or_return (stream.name);
+  parse_istring_or_return (stream.name);
   parse_or_return (',');
-  parse_string_or_return (stream.blurb);
+  parse_istring_or_return (stream.blurb);
   parse_or_return (')');
 
   parse_or_return (';');
@@ -1109,7 +1158,7 @@ GTokenType Parser::parseParamHints (Param &def)
   return G_TOKEN_NONE;
 }
 
-GTokenType Parser::parseInfoOptional (Map<string,string>& infos)
+GTokenType Parser::parseInfoOptional (Map<string,IString>& infos)
 {
   /*
    * info HELP = "don't panic";
@@ -1117,13 +1166,14 @@ GTokenType Parser::parseInfoOptional (Map<string,string>& infos)
    */
   while (g_scanner_peek_next_token (scanner) == TOKEN_INFO)
   {
-    string key, value;
+    string  key;
+    IString value;
 
     parse_or_return (TOKEN_INFO);
     parse_or_return (G_TOKEN_IDENTIFIER);
     key = scanner->value.v_identifier;
     parse_or_return ('=');
-    parse_string_or_return (value);
+    parse_istring_or_return (value);
     parse_or_return (';');
 
     infos[key] = value;
@@ -1176,7 +1226,6 @@ GTokenType Parser::parseSequence ()
 GTokenType Parser::parseClass ()
 {
   Class cdef;
-  string group = "";
   DEBUG("parse class\n");
   
   parse_or_return (TOKEN_CLASS);
@@ -1225,23 +1274,13 @@ GTokenType Parser::parseClass ()
 	      return expected_token;
 	  }
 	  break;
-#if 0
-        case '$':
-          parse_dot_group (scanner, &group);
-          break;
-#endif
-        case TOKEN_PROPERTY:
+        case TOKEN_PROPERTY: /* FIXME: remove me due to deprecated syntax */
 	  {
 	    parse_or_return (TOKEN_PROPERTY);
 
 	    Param property;
-            string local_group = group;
-            if (g_scanner_peek_next_token (scanner) == G_TOKEN_STRING)
-              {
-                g_scanner_get_next_token (scanner);
-                local_group = scanner->value.v_string;
-              }
-	    expected_token = parseRecordField (property, local_group);
+
+	    expected_token = parseRecordField (property, "");  // no i18n support, deprecated
 	    if (expected_token != G_TOKEN_NONE)
 	      return expected_token;
             
@@ -1250,29 +1289,17 @@ GTokenType Parser::parseClass ()
 	  break;
         case TOKEN_GROUP:
           {
-            string local_group = group;
+            IString group;
 	    parse_or_return (TOKEN_GROUP);
-            if (g_scanner_peek_next_token (scanner) == G_TOKEN_STRING)
-              {
-                g_scanner_get_next_token (scanner);
-                local_group = scanner->value.v_string;
-              }
+	    parse_istring_or_return (group);
 	    parse_or_return ('{');
             while (g_scanner_peek_next_token (scanner) != '}' && !g_scanner_eof (scanner))
               {
                 Param property;
-#if 0
-                if (g_scanner_peek_next_token (scanner) == '$')
-                  expected_token = parse_dot_group (scanner, &local_group);
-                else
-#endif
-                  {
-                    expected_token = parseRecordField (property, local_group);
-                    if (expected_token == G_TOKEN_NONE)
-                      cdef.properties.push_back (property);
-                  }
+                expected_token = parseRecordField (property, group);
                 if (expected_token != G_TOKEN_NONE)
                   return expected_token;
+                cdef.properties.push_back (property);
               }
             parse_or_return ('}');
             parse_or_return (';');
