@@ -211,31 +211,37 @@ GParamSpec* 	 sfi_pspec_proxy_from_object (GParamSpec *object_pspec);
 GParamSpec*      sfi_pspec_to_serializable   (GParamSpec *pspec);
 
 
-/* --- Sfi param hints --- */
-#define	SFI_PARAM_READABLE	  "r:"
-#define	SFI_PARAM_WRITABLE	  "w:"
-#define	SFI_PARAM_READWRITE	  SFI_PARAM_READABLE SFI_PARAM_WRITABLE
-#define	SFI_PARAM_LAX_VALIDATION  "lxv:"
-#define	SFI_PARAM_SERVE_GUI	  "gui:"	/* GUI representation */
-#define	SFI_PARAM_SERVE_STORAGE	  "storage:"	/* gets serialized */
-/* storage flags */
-#define	SFI_PARAM_SKIP_DEFAULT	  "skipd:"	/* don't store defaulting values */
-#define	SFI_PARAM_FLOAT		  "float:"	/* reduce precision to IEEE 754 Single */
-/* GUI hints */
-#define	SFI_PARAM_HINT_RDONLY	  "rdonly:"	/* not modifyable for GUI */
-#define	SFI_PARAM_HINT_RADIO	  "radio:"
-#define	SFI_PARAM_HINT_DIAL	  "dial:"
-#define	SFI_PARAM_HINT_SCALE	  "scale:"
-#define	SFI_PARAM_HINT_LOG_SCALE  "log-scale:"
-/* readable and writable */
-#define	SFI_PARAM_DEFAULT	  SFI_PARAM_READWRITE SFI_PARAM_SERVE_GUI SFI_PARAM_SERVE_STORAGE
-#define	SFI_PARAM_GUI		  SFI_PARAM_READWRITE SFI_PARAM_SERVE_GUI
-#define	SFI_PARAM_GUI_READABLE	  SFI_PARAM_READABLE SFI_PARAM_SERVE_GUI
-#define	SFI_PARAM_GUI_WRITABLE	  SFI_PARAM_WRITABLE SFI_PARAM_SERVE_GUI
-#define	SFI_PARAM_STORAGE	  SFI_PARAM_READWRITE SFI_PARAM_SERVE_STORAGE
-/* readable and for non-GUI writable */
-#define SFI_PARAM_DEFAULT_RDONLY  SFI_PARAM_DEFAULT SFI_PARAM_HINT_RDONLY
-#define	SFI_PARAM_GUI_RDONLY	  SFI_PARAM_GUI SFI_PARAM_HINT_RDONLY
+/* --- Sfi PSpec Options --- */
+/* conventional pspec hints:
+ * Legacy GParamFlags:
+ * "r"                  - readable (G_PARAM_READABLE)
+ * "w"                  - writable (G_PARAM_WRITABLE)
+ * "construct"          - construct (G_PARAM_CONSTRUCT)
+ * "construct-only"     - construct only (G_PARAM_CONSTRUCT_ONLY)
+ * "lax-validation"     - lax validation (G_PARAM_LAX_VALIDATION)
+ * Serialization Options:
+ * "S"                  - is serializable
+ * "f"                  - float indicator, reduce precision to IEEE 754 Single
+ * "skip-default"       - skip defaulting values upon serialization
+ * Undo/Redo Options:
+ * "skip-undo"          - no undo/redo recording
+ * GUI Options:
+ * "G"                  - is GUI representable
+ * "ro"                 - read-only, not mutable by GUI
+ * "radio"              - radio button hint
+ * "dial"               - dial knob hint
+ * "scale"              - scale adjustment hint
+ * "log-scale"          - logarithmic scale adjustment hint
+ * "trigger"            - trigger button hint
+ * "searchpath"         - indicates colon seperated directory list
+ */
+/* common option combinations: */
+#define	SFI_PARAM_READWRITE      ":r:w:"
+#define	SFI_PARAM_STORAGE	 ":r:w:S:"
+#define	SFI_PARAM_STANDARD        ":r:w:G:S:"
+#define	SFI_PARAM_GUI		 ":r:w:G:"
+#define SFI_PARAM_STANDARD_RDONLY ":r:w:G:S:ro:"
+#define	SFI_PARAM_GUI_RDONLY	 ":r:w:G:ro:"
 
 
 /* --- serializable categories --- */
@@ -288,17 +294,11 @@ const gchar*	sfi_pspec_get_group		(GParamSpec	*pspec);
 void		sfi_pspec_set_owner		(GParamSpec	*pspec,
 						 const gchar	*owner);
 const gchar*	sfi_pspec_get_owner		(GParamSpec	*pspec);
-void		sfi_pspec_set_hints		(GParamSpec	*pspec,
-						 const gchar	*hints);
-void		sfi_pspec_add_hint		(GParamSpec	*pspec,
-						 const gchar	*hint);
-void		sfi_pspec_remove_hint		(GParamSpec	*pspec,
-						 const gchar	*hint);
-gboolean	sfi_pspec_test_hint		(GParamSpec	*pspec,
-						 const gchar	*hint);
-gboolean	sfi_pspec_test_all_hints	(GParamSpec	*pspec,
-						 const gchar	*hints);
-const gchar*	sfi_pspec_get_hints		(GParamSpec	*pspec);
+#define sfi_pspec_set_options(pspec, opts)      g_param_spec_set_options (pspec, opts)
+#define sfi_pspec_add_option(pspec, opt, val)   g_param_spec_add_option (pspec, opt, val)
+#define sfi_pspec_check_option(pspec, opt)      g_param_spec_check_option (pspec, opt)
+#define sfi_pspec_provides_options(pspec, opts) g_param_spec_provides_options (pspec, opts)
+#define sfi_pspec_get_options(pspec)            g_param_spec_get_options (pspec)
 SfiBool		sfi_pspec_get_bool_default	(GParamSpec	*pspec);
 SfiInt		sfi_pspec_get_int_default	(GParamSpec	*pspec);
 void		sfi_pspec_get_int_range		(GParamSpec	*pspec,
@@ -318,17 +318,12 @@ void		sfi_pspec_get_real_range	(GParamSpec	*pspec,
 						 SfiReal        *minimum_value,
 						 SfiReal        *maximum_value,
 						 SfiReal        *stepping);
-void		sfi_pspec_set_log_scale		(GParamSpec	*pspec,
-						 SfiReal         center,
-						 SfiReal         base,
-						 SfiReal         n_steps);
-gboolean	sfi_pspec_get_log_scale		(GParamSpec	*pspec,
-						 SfiReal        *center,
-						 SfiReal        *base,
-						 SfiReal        *n_steps);
+#define sfi_pspec_set_log_scale(p, c, b, n)     g_param_spec_set_log_scale (p, c, b, n)
+#define sfi_pspec_get_log_scale(p, c, b, n)     g_param_spec_get_log_scale (p, c, b, n)
 const gchar*	sfi_pspec_get_string_default	(GParamSpec	*pspec);
 const gchar*	sfi_pspec_get_choice_default	(GParamSpec	*pspec);
 SfiChoiceValues	sfi_pspec_get_choice_values	(GParamSpec	*pspec);
+guint64         sfi_pspec_get_choice_hash       (GParamSpec     *pspec);
 GParamSpec*	sfi_pspec_get_seq_element	(GParamSpec	*pspec);
 SfiRecFields	sfi_pspec_get_rec_fields	(GParamSpec	*pspec);
 GParamSpec*	sfi_pspec_get_rec_field		(GParamSpec	*pspec,
