@@ -705,6 +705,20 @@ sfi_seq_from_strv (gchar **strv)
   return seq;
 }
 
+SfiSeq*
+sfi_seq_from_cstrv (const gchar **strv)
+{
+  SfiSeq *seq;
+  guint i;
+  if (!strv)
+    return NULL;
+
+  seq = sfi_seq_new ();
+  for (i = 0; strv[i]; i++)
+    sfi_seq_append_string (seq, strv[i]);
+  return seq;
+}
+
 
 /* --- SfiRec primitive type --- */
 SfiRec*
@@ -1297,22 +1311,30 @@ SfiRing*
 sfi_ring_prepend_uniq (SfiRing  *head,
 		       gpointer data)
 {
-  SfiRing *walk;
-  
-  for (walk = head; walk; walk = sfi_ring_walk (walk, head))
-    if (walk->data == data)
+  SfiRing *ring;
+  for (ring = head; ring; ring = sfi_ring_walk (ring, head))
+    if (ring->data == data)
       return head;
   return sfi_ring_prepend_i (head, data);
 }
 
 SfiRing*
-sfi_ring_append (SfiRing  *head,
+sfi_ring_append (SfiRing *head,
 		 gpointer data)
+{
+  SfiRing *ring = sfi_ring_prepend_i (head, data);
+  return head ? head : ring;
+}
+
+SfiRing*
+sfi_ring_append_uniq (SfiRing *head,
+                      gpointer data)
 {
   SfiRing *ring;
-  
+  for (ring = head; ring; ring = sfi_ring_walk (ring, head))
+    if (ring->data == data)
+      return head;
   ring = sfi_ring_prepend_i (head, data);
-  
   return head ? head : ring;
 }
 
